/* testcollection.c generated by valac 0.25.1.16-fa2259, the Vala compiler
 * generated from testcollection.vala, do not modify */

/* testcollection.vala
 *
 * Copyright (C) 2008  Jürg Billeter
 * Copyright (C) 2009  Didier Villevalois, Julien Peeters
 * Copyright (C) 2011-2013  Maciej Piechotka
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.

 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.

 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
 *
 * Author:
 * 	Jürg Billeter <j@bitron.ch>
 * 	Didier 'Ptitjes' Villevalois <ptitjes@free.fr>
 * 	Julien Peeters <contact@julienpeeters.fr>
 *      Maciej Piechotka <uzytkownik2@gmail.com>
 */

#include <glib.h>
#include <glib-object.h>
#include <gee.h>
#include <stdlib.h>
#include <string.h>


#define GEE_TYPE_TEST_CASE (gee_test_case_get_type ())
#define GEE_TEST_CASE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GEE_TYPE_TEST_CASE, GeeTestCase))
#define GEE_TEST_CASE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GEE_TYPE_TEST_CASE, GeeTestCaseClass))
#define GEE_IS_TEST_CASE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GEE_TYPE_TEST_CASE))
#define GEE_IS_TEST_CASE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GEE_TYPE_TEST_CASE))
#define GEE_TEST_CASE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GEE_TYPE_TEST_CASE, GeeTestCaseClass))

typedef struct _GeeTestCase GeeTestCase;
typedef struct _GeeTestCaseClass GeeTestCaseClass;
typedef struct _GeeTestCasePrivate GeeTestCasePrivate;

#define TYPE_COLLECTION_TESTS (collection_tests_get_type ())
#define COLLECTION_TESTS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_COLLECTION_TESTS, CollectionTests))
#define COLLECTION_TESTS_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_COLLECTION_TESTS, CollectionTestsClass))
#define IS_COLLECTION_TESTS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_COLLECTION_TESTS))
#define IS_COLLECTION_TESTS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_COLLECTION_TESTS))
#define COLLECTION_TESTS_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_COLLECTION_TESTS, CollectionTestsClass))

typedef struct _CollectionTests CollectionTests;
typedef struct _CollectionTestsClass CollectionTestsClass;
typedef struct _CollectionTestsPrivate CollectionTestsPrivate;
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
#define _g_free0(var) (var = (g_free (var), NULL))
typedef struct _Block1Data Block1Data;
typedef struct _Block2Data Block2Data;
typedef struct _Block3Data Block3Data;
typedef struct _Block4Data Block4Data;
typedef struct _Block5Data Block5Data;
typedef struct _Block6Data Block6Data;
#define _vala_assert(expr, msg) if G_LIKELY (expr) ; else g_assertion_message_expr (G_LOG_DOMAIN, __FILE__, __LINE__, G_STRFUNC, msg);

struct _GeeTestCase {
	GObject parent_instance;
	GeeTestCasePrivate * priv;
};

struct _GeeTestCaseClass {
	GObjectClass parent_class;
	void (*set_up) (GeeTestCase* self);
	void (*tear_down) (GeeTestCase* self);
};

struct _CollectionTests {
	GeeTestCase parent_instance;
	CollectionTestsPrivate * priv;
	GeeCollection* test_collection;
};

struct _CollectionTestsClass {
	GeeTestCaseClass parent_class;
};

typedef void (*GeeTestCaseTestMethod) (void* user_data);
struct _Block1Data {
	int _ref_count_;
	CollectionTests* self;
	gint count;
	GeeIterator* test_iterator;
};

struct _Block2Data {
	int _ref_count_;
	Block1Data * _data1_;
	gint i;
};

struct _Block3Data {
	int _ref_count_;
	CollectionTests* self;
	GeeIterator* test_iterator;
};

struct _Block4Data {
	int _ref_count_;
	CollectionTests* self;
	GeeIterator* iter;
	gint i;
	gint j;
	GeeIterator* test_iterator;
};

struct _Block5Data {
	int _ref_count_;
	CollectionTests* self;
	gboolean one;
	gboolean two;
	gboolean three;
};

struct _Block6Data {
	int _ref_count_;
	CollectionTests* self;
	gboolean one;
	gboolean two;
	gboolean three;
};


static gpointer collection_tests_parent_class = NULL;

GType gee_test_case_get_type (void) G_GNUC_CONST;
GType collection_tests_get_type (void) G_GNUC_CONST;
enum  {
	COLLECTION_TESTS_DUMMY_PROPERTY
};
CollectionTests* collection_tests_construct (GType object_type, const gchar* name);
GeeTestCase* gee_test_case_construct (GType object_type, const gchar* name);
void gee_test_case_add_test (GeeTestCase* self, const gchar* name, GeeTestCaseTestMethod test, void* test_target, GDestroyNotify test_target_destroy_notify);
void collection_tests_test_type_correctness (CollectionTests* self);
static void _collection_tests_test_type_correctness_gee_test_case_test_method (gpointer self);
void collection_tests_test_iterator_returns_all_elements_once (CollectionTests* self);
static void _collection_tests_test_iterator_returns_all_elements_once_gee_test_case_test_method (gpointer self);
void collection_tests_test_mutable_iterator (CollectionTests* self);
static void _collection_tests_test_mutable_iterator_gee_test_case_test_method (gpointer self);
void collection_tests_test_contains_size_and_is_empty (CollectionTests* self);
static void _collection_tests_test_contains_size_and_is_empty_gee_test_case_test_method (gpointer self);
void collection_tests_test_add_remove (CollectionTests* self);
static void _collection_tests_test_add_remove_gee_test_case_test_method (gpointer self);
void collection_tests_test_clear (CollectionTests* self);
static void _collection_tests_test_clear_gee_test_case_test_method (gpointer self);
void collection_tests_test_add_all (CollectionTests* self);
static void _collection_tests_test_add_all_gee_test_case_test_method (gpointer self);
void collection_tests_test_contains_all (CollectionTests* self);
static void _collection_tests_test_contains_all_gee_test_case_test_method (gpointer self);
void collection_tests_test_remove_all (CollectionTests* self);
static void _collection_tests_test_remove_all_gee_test_case_test_method (gpointer self);
void collection_tests_test_retain_all (CollectionTests* self);
static void _collection_tests_test_retain_all_gee_test_case_test_method (gpointer self);
void collection_tests_test_to_array (CollectionTests* self);
static void _collection_tests_test_to_array_gee_test_case_test_method (gpointer self);
void collection_tests_test_gobject_properties (CollectionTests* self);
static void _collection_tests_test_gobject_properties_gee_test_case_test_method (gpointer self);
void collection_tests_test_foreach (CollectionTests* self);
static void _collection_tests_test_foreach_gee_test_case_test_method (gpointer self);
void collection_tests_test_fold (CollectionTests* self);
static void _collection_tests_test_fold_gee_test_case_test_method (gpointer self);
void collection_tests_test_map (CollectionTests* self);
static void _collection_tests_test_map_gee_test_case_test_method (gpointer self);
void collection_tests_test_scan (CollectionTests* self);
static void _collection_tests_test_scan_gee_test_case_test_method (gpointer self);
void collection_tests_test_filter (CollectionTests* self);
static void _collection_tests_test_filter_gee_test_case_test_method (gpointer self);
void collection_tests_test_chop (CollectionTests* self);
static void _collection_tests_test_chop_gee_test_case_test_method (gpointer self);
gchar** test_data_get_data (int* result_length1);
guint* test_data_get_drawn_numbers (int* result_length1);
static Block1Data* block1_data_ref (Block1Data* _data1_);
static void block1_data_unref (void * _userdata_);
static gboolean __lambda5_ (CollectionTests* self, gchar* x);
static gboolean ___lambda5__gee_forall_func (gpointer g, gpointer self);
static gboolean __lambda6_ (CollectionTests* self, gchar* x);
static gboolean ___lambda6__gee_forall_func (gpointer g, gpointer self);
static gboolean __lambda7_ (Block1Data* _data1_, gchar* x);
static gboolean ___lambda7__gee_forall_func (gpointer g, gpointer self);
static gboolean __lambda8_ (Block1Data* _data1_, gchar* x);
static gboolean ___lambda8__gee_forall_func (gpointer g, gpointer self);
static gboolean __lambda9_ (Block1Data* _data1_, gchar* x);
static gboolean ___lambda9__gee_forall_func (gpointer g, gpointer self);
static gboolean __lambda10_ (Block1Data* _data1_, gchar* x);
static gboolean ___lambda10__gee_forall_func (gpointer g, gpointer self);
static Block2Data* block2_data_ref (Block2Data* _data2_);
static void block2_data_unref (void * _userdata_);
static gboolean _____lambda11_ (Block2Data* _data2_, gchar* x);
static gboolean ______lambda11__gee_forall_func (gpointer g, gpointer self);
static gboolean _____lambda12_ (Block2Data* _data2_, gchar* x);
static gboolean ______lambda12__gee_forall_func (gpointer g, gpointer self);
static gboolean _____lambda13_ (Block2Data* _data2_, gchar* x);
static gboolean ______lambda13__gee_forall_func (gpointer g, gpointer self);
static gboolean _____lambda14_ (Block2Data* _data2_, gchar* x);
static gboolean ______lambda14__gee_forall_func (gpointer g, gpointer self);
static Block3Data* block3_data_ref (Block3Data* _data3_);
static void block3_data_unref (void * _userdata_);
static gint __lambda15_ (CollectionTests* self, gchar* x, gint y);
static gpointer ___lambda15__gee_fold_func (gpointer g, gpointer a, gpointer self);
static gint __lambda16_ (CollectionTests* self, gchar* x, gint y);
static gpointer ___lambda16__gee_fold_func (gpointer g, gpointer a, gpointer self);
static gint __lambda17_ (Block3Data* _data3_, gchar* x, gint y);
static gpointer ___lambda17__gee_fold_func (gpointer g, gpointer a, gpointer self);
static gint __lambda18_ (Block3Data* _data3_, gchar* x, gint y);
static gpointer ___lambda18__gee_fold_func (gpointer g, gpointer a, gpointer self);
static gint __lambda19_ (Block3Data* _data3_, gchar* x, gint y);
static gpointer ___lambda19__gee_fold_func (gpointer g, gpointer a, gpointer self);
static gint __lambda20_ (Block3Data* _data3_, gchar* x, gint y);
static gpointer ___lambda20__gee_fold_func (gpointer g, gpointer a, gpointer self);
static Block4Data* block4_data_ref (Block4Data* _data4_);
static void block4_data_unref (void * _userdata_);
static gint __lambda21_ (CollectionTests* self, gchar* str);
static gpointer ___lambda21__gee_map_func (gpointer g, gpointer self);
static gint __lambda22_ (CollectionTests* self, gchar* str);
static gpointer ___lambda22__gee_map_func (gpointer g, gpointer self);
static gint __lambda23_ (Block4Data* _data4_, gchar* str);
static gpointer ___lambda23__gee_map_func (gpointer g, gpointer self);
static gboolean __lambda24_ (Block4Data* _data4_, gchar* str);
static gboolean ___lambda24__gee_forall_func (gpointer g, gpointer self);
static gint __lambda25_ (Block4Data* _data4_, gchar* str);
static gpointer ___lambda25__gee_map_func (gpointer g, gpointer self);
static gboolean __lambda26_ (Block4Data* _data4_, gchar* str);
static gboolean ___lambda26__gee_forall_func (gpointer g, gpointer self);
static gint __lambda27_ (Block4Data* _data4_, gchar* str);
static gpointer ___lambda27__gee_map_func (gpointer g, gpointer self);
static gboolean __lambda28_ (Block4Data* _data4_, gchar* str);
static gboolean ___lambda28__gee_forall_func (gpointer g, gpointer self);
static gint __lambda29_ (Block4Data* _data4_, gchar* str);
static gpointer ___lambda29__gee_map_func (gpointer g, gpointer self);
static gboolean __lambda30_ (Block4Data* _data4_, gchar* str);
static gboolean ___lambda30__gee_forall_func (gpointer g, gpointer self);
static gint __lambda31_ (Block4Data* _data4_, gchar* str);
static gpointer ___lambda31__gee_map_func (gpointer g, gpointer self);
static gint __lambda32_ (Block4Data* _data4_, gchar* str);
static gpointer ___lambda32__gee_map_func (gpointer g, gpointer self);
static Block5Data* block5_data_ref (Block5Data* _data5_);
static void block5_data_unref (void * _userdata_);
static gint __lambda33_ (Block5Data* _data5_, gchar* str, gint cur);
static gpointer ___lambda33__gee_fold_func (gpointer g, gpointer a, gpointer self);
static gint __lambda34_ (Block5Data* _data5_, gchar* str, gint cur);
static gpointer ___lambda34__gee_fold_func (gpointer g, gpointer a, gpointer self);
static Block6Data* block6_data_ref (Block6Data* _data6_);
static void block6_data_unref (void * _userdata_);
static gboolean __lambda35_ (Block6Data* _data6_, const gchar* str);
static gboolean ___lambda35__gee_predicate (gconstpointer g, gpointer self);
static gboolean __lambda36_ (Block6Data* _data6_, const gchar* str);
static gboolean ___lambda36__gee_predicate (gconstpointer g, gpointer self);
static void collection_tests_finalize (GObject* obj);
static void _vala_array_destroy (gpointer array, gint array_length, GDestroyNotify destroy_func);
static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func);


static void _collection_tests_test_type_correctness_gee_test_case_test_method (gpointer self) {
	collection_tests_test_type_correctness ((CollectionTests*) self);
}


static void _collection_tests_test_iterator_returns_all_elements_once_gee_test_case_test_method (gpointer self) {
	collection_tests_test_iterator_returns_all_elements_once ((CollectionTests*) self);
}


static void _collection_tests_test_mutable_iterator_gee_test_case_test_method (gpointer self) {
	collection_tests_test_mutable_iterator ((CollectionTests*) self);
}


static void _collection_tests_test_contains_size_and_is_empty_gee_test_case_test_method (gpointer self) {
	collection_tests_test_contains_size_and_is_empty ((CollectionTests*) self);
}


static void _collection_tests_test_add_remove_gee_test_case_test_method (gpointer self) {
	collection_tests_test_add_remove ((CollectionTests*) self);
}


static void _collection_tests_test_clear_gee_test_case_test_method (gpointer self) {
	collection_tests_test_clear ((CollectionTests*) self);
}


static void _collection_tests_test_add_all_gee_test_case_test_method (gpointer self) {
	collection_tests_test_add_all ((CollectionTests*) self);
}


static void _collection_tests_test_contains_all_gee_test_case_test_method (gpointer self) {
	collection_tests_test_contains_all ((CollectionTests*) self);
}


static void _collection_tests_test_remove_all_gee_test_case_test_method (gpointer self) {
	collection_tests_test_remove_all ((CollectionTests*) self);
}


static void _collection_tests_test_retain_all_gee_test_case_test_method (gpointer self) {
	collection_tests_test_retain_all ((CollectionTests*) self);
}


static void _collection_tests_test_to_array_gee_test_case_test_method (gpointer self) {
	collection_tests_test_to_array ((CollectionTests*) self);
}


static void _collection_tests_test_gobject_properties_gee_test_case_test_method (gpointer self) {
	collection_tests_test_gobject_properties ((CollectionTests*) self);
}


static void _collection_tests_test_foreach_gee_test_case_test_method (gpointer self) {
	collection_tests_test_foreach ((CollectionTests*) self);
}


static void _collection_tests_test_fold_gee_test_case_test_method (gpointer self) {
	collection_tests_test_fold ((CollectionTests*) self);
}


static void _collection_tests_test_map_gee_test_case_test_method (gpointer self) {
	collection_tests_test_map ((CollectionTests*) self);
}


static void _collection_tests_test_scan_gee_test_case_test_method (gpointer self) {
	collection_tests_test_scan ((CollectionTests*) self);
}


static void _collection_tests_test_filter_gee_test_case_test_method (gpointer self) {
	collection_tests_test_filter ((CollectionTests*) self);
}


static void _collection_tests_test_chop_gee_test_case_test_method (gpointer self) {
	collection_tests_test_chop ((CollectionTests*) self);
}


CollectionTests* collection_tests_construct (GType object_type, const gchar* name) {
	CollectionTests * self = NULL;
	const gchar* _tmp0_ = NULL;
	g_return_val_if_fail (name != NULL, NULL);
	_tmp0_ = name;
	self = (CollectionTests*) gee_test_case_construct (object_type, _tmp0_);
	gee_test_case_add_test ((GeeTestCase*) self, "[Collection] type correctness", _collection_tests_test_type_correctness_gee_test_case_test_method, g_object_ref (self), g_object_unref);
	gee_test_case_add_test ((GeeTestCase*) self, "[Collection] iterator returns all elements once", _collection_tests_test_iterator_returns_all_elements_once_gee_test_case_test_method, g_object_ref (self), g_object_unref);
	gee_test_case_add_test ((GeeTestCase*) self, "[Collection] mutable iterator", _collection_tests_test_mutable_iterator_gee_test_case_test_method, g_object_ref (self), g_object_unref);
	gee_test_case_add_test ((GeeTestCase*) self, "[Collection] contains, size and is_empty", _collection_tests_test_contains_size_and_is_empty_gee_test_case_test_method, g_object_ref (self), g_object_unref);
	gee_test_case_add_test ((GeeTestCase*) self, "[Collection] add and remove", _collection_tests_test_add_remove_gee_test_case_test_method, g_object_ref (self), g_object_unref);
	gee_test_case_add_test ((GeeTestCase*) self, "[Collection] clear", _collection_tests_test_clear_gee_test_case_test_method, g_object_ref (self), g_object_unref);
	gee_test_case_add_test ((GeeTestCase*) self, "[Collection] add_all", _collection_tests_test_add_all_gee_test_case_test_method, g_object_ref (self), g_object_unref);
	gee_test_case_add_test ((GeeTestCase*) self, "[Collection] contains_all", _collection_tests_test_contains_all_gee_test_case_test_method, g_object_ref (self), g_object_unref);
	gee_test_case_add_test ((GeeTestCase*) self, "[Collection] remove_all", _collection_tests_test_remove_all_gee_test_case_test_method, g_object_ref (self), g_object_unref);
	gee_test_case_add_test ((GeeTestCase*) self, "[Collection] retain_all", _collection_tests_test_retain_all_gee_test_case_test_method, g_object_ref (self), g_object_unref);
	gee_test_case_add_test ((GeeTestCase*) self, "[Collection] to_array", _collection_tests_test_to_array_gee_test_case_test_method, g_object_ref (self), g_object_unref);
	gee_test_case_add_test ((GeeTestCase*) self, "[Collection] GObject properties", _collection_tests_test_gobject_properties_gee_test_case_test_method, g_object_ref (self), g_object_unref);
	gee_test_case_add_test ((GeeTestCase*) self, "[Collection] foreach", _collection_tests_test_foreach_gee_test_case_test_method, g_object_ref (self), g_object_unref);
	gee_test_case_add_test ((GeeTestCase*) self, "[Collection] fold", _collection_tests_test_fold_gee_test_case_test_method, g_object_ref (self), g_object_unref);
	gee_test_case_add_test ((GeeTestCase*) self, "[Collection] map", _collection_tests_test_map_gee_test_case_test_method, g_object_ref (self), g_object_unref);
	gee_test_case_add_test ((GeeTestCase*) self, "[Collection] scan", _collection_tests_test_scan_gee_test_case_test_method, g_object_ref (self), g_object_unref);
	gee_test_case_add_test ((GeeTestCase*) self, "[Collection] filter", _collection_tests_test_filter_gee_test_case_test_method, g_object_ref (self), g_object_unref);
	gee_test_case_add_test ((GeeTestCase*) self, "[Collection] chop", _collection_tests_test_chop_gee_test_case_test_method, g_object_ref (self), g_object_unref);
	return self;
}


void collection_tests_test_type_correctness (CollectionTests* self) {
	GeeCollection* _tmp0_ = NULL;
	GeeCollection* _tmp1_ = NULL;
	GType _tmp2_ = 0UL;
	GType _tmp3_ = 0UL;
	g_return_if_fail (self != NULL);
	_tmp0_ = self->test_collection;
	_vala_assert (_tmp0_ != NULL, "test_collection != null");
	_tmp1_ = self->test_collection;
	_tmp2_ = gee_traversable_get_element_type ((GeeTraversable*) _tmp1_);
	_tmp3_ = _tmp2_;
	_vala_assert (_tmp3_ == G_TYPE_STRING, "test_collection.element_type == typeof (string)");
}


void collection_tests_test_iterator_returns_all_elements_once (CollectionTests* self) {
	GeeCollection* _tmp0_ = NULL;
	gboolean has_next = FALSE;
	GeeIterator* iterator = NULL;
	GeeCollection* _tmp1_ = NULL;
	GeeIterator* _tmp2_ = NULL;
	GeeIterator* _tmp3_ = NULL;
	gboolean _tmp4_ = FALSE;
	GeeIterator* _tmp5_ = NULL;
	gboolean _tmp6_ = FALSE;
	gchar** data = NULL;
	gint _tmp7_ = 0;
	gchar** _tmp8_ = NULL;
	gint data_length1 = 0;
	gint _data_size_ = 0;
	gchar** _tmp9_ = NULL;
	gint _tmp9__length1 = 0;
	guint* found_times = NULL;
	gchar** _tmp13_ = NULL;
	gint _tmp13__length1 = 0;
	guint* _tmp14_ = NULL;
	gint found_times_length1 = 0;
	gint _found_times_size_ = 0;
	g_return_if_fail (self != NULL);
	_tmp0_ = self->test_collection;
	_vala_assert (_tmp0_ != NULL, "test_collection != null");
	_tmp1_ = self->test_collection;
	_tmp2_ = gee_iterable_iterator ((GeeIterable*) _tmp1_);
	iterator = _tmp2_;
	_tmp3_ = iterator;
	_tmp4_ = gee_iterator_has_next (_tmp3_);
	_vala_assert (!_tmp4_, "! iterator.has_next ()");
	_tmp5_ = iterator;
	_tmp6_ = gee_iterator_next (_tmp5_);
	_vala_assert (!_tmp6_, "! iterator.next ()");
	_tmp8_ = test_data_get_data (&_tmp7_);
	data = _tmp8_;
	data_length1 = _tmp7_;
	_data_size_ = data_length1;
	_tmp9_ = data;
	_tmp9__length1 = data_length1;
	{
		gchar** el_collection = NULL;
		gint el_collection_length1 = 0;
		gint _el_collection_size_ = 0;
		gint el_it = 0;
		el_collection = _tmp9_;
		el_collection_length1 = _tmp9__length1;
		for (el_it = 0; el_it < _tmp9__length1; el_it = el_it + 1) {
			const gchar* el = NULL;
			el = el_collection[el_it];
			{
				GeeCollection* _tmp10_ = NULL;
				const gchar* _tmp11_ = NULL;
				gboolean _tmp12_ = FALSE;
				_tmp10_ = self->test_collection;
				_tmp11_ = el;
				_tmp12_ = gee_collection_add (_tmp10_, _tmp11_);
				_vala_assert (_tmp12_, "test_collection.add (el)");
			}
		}
	}
	_tmp13_ = data;
	_tmp13__length1 = data_length1;
	_tmp14_ = g_new0 (guint, _tmp13__length1);
	found_times = _tmp14_;
	found_times_length1 = _tmp13__length1;
	_found_times_size_ = found_times_length1;
	{
		guint i = 0U;
		i = (guint) 0;
		{
			gboolean _tmp15_ = FALSE;
			_tmp15_ = TRUE;
			while (TRUE) {
				guint _tmp17_ = 0U;
				GeeCollection* _tmp25_ = NULL;
				GeeIterator* _tmp26_ = NULL;
				gboolean valid = FALSE;
				GeeIterator* _tmp27_ = NULL;
				gboolean _tmp28_ = FALSE;
				gboolean _tmp29_ = FALSE;
				gboolean _tmp30_ = FALSE;
				GeeIterator* _tmp61_ = NULL;
				gboolean _tmp62_ = FALSE;
				gboolean _tmp63_ = FALSE;
				GeeIterator* _tmp64_ = NULL;
				gboolean _tmp65_ = FALSE;
				gboolean _tmp66_ = FALSE;
				gboolean _tmp67_ = FALSE;
				GeeIterator* _tmp68_ = NULL;
				gboolean _tmp69_ = FALSE;
				GeeIterator* _tmp70_ = NULL;
				gboolean _tmp71_ = FALSE;
				gboolean _tmp72_ = FALSE;
				guint* _tmp73_ = NULL;
				gint _tmp73__length1 = 0;
				if (!_tmp15_) {
					guint _tmp16_ = 0U;
					_tmp16_ = i;
					i = _tmp16_ + 1;
				}
				_tmp15_ = FALSE;
				_tmp17_ = i;
				if (!(_tmp17_ < ((guint) 2))) {
					break;
				}
				{
					guint j = 0U;
					j = (guint) 0;
					{
						gboolean _tmp18_ = FALSE;
						_tmp18_ = TRUE;
						while (TRUE) {
							guint _tmp20_ = 0U;
							guint* _tmp21_ = NULL;
							gint _tmp21__length1 = 0;
							guint* _tmp22_ = NULL;
							gint _tmp22__length1 = 0;
							guint _tmp23_ = 0U;
							guint _tmp24_ = 0U;
							if (!_tmp18_) {
								guint _tmp19_ = 0U;
								_tmp19_ = j;
								j = _tmp19_ + 1;
							}
							_tmp18_ = FALSE;
							_tmp20_ = j;
							_tmp21_ = found_times;
							_tmp21__length1 = found_times_length1;
							if (!(_tmp20_ < ((guint) _tmp21__length1))) {
								break;
							}
							_tmp22_ = found_times;
							_tmp22__length1 = found_times_length1;
							_tmp23_ = j;
							_tmp22_[_tmp23_] = (guint) 0;
							_tmp24_ = _tmp22_[_tmp23_];
						}
					}
				}
				_tmp25_ = self->test_collection;
				_tmp26_ = gee_iterable_iterator ((GeeIterable*) _tmp25_);
				_g_object_unref0 (iterator);
				iterator = _tmp26_;
				_tmp27_ = iterator;
				_tmp28_ = gee_iterator_get_valid (_tmp27_);
				_tmp29_ = _tmp28_;
				valid = _tmp29_;
				_tmp30_ = valid;
				_vala_assert (!_tmp30_, "! valid");
				while (TRUE) {
					GeeIterator* _tmp31_ = NULL;
					gboolean _tmp32_ = FALSE;
					gboolean _tmp33_ = FALSE;
					GeeIterator* _tmp34_ = NULL;
					gboolean _tmp35_ = FALSE;
					gboolean _tmp36_ = FALSE;
					gboolean _tmp37_ = FALSE;
					GeeIterator* _tmp38_ = NULL;
					gboolean _tmp39_ = FALSE;
					GeeIterator* _tmp40_ = NULL;
					gboolean _tmp41_ = FALSE;
					gboolean _tmp42_ = FALSE;
					gboolean _tmp43_ = FALSE;
					gboolean _tmp44_ = FALSE;
					gchar* element = NULL;
					GeeIterator* _tmp45_ = NULL;
					gpointer _tmp46_ = NULL;
					GeeIterator* _tmp47_ = NULL;
					gboolean _tmp48_ = FALSE;
					gboolean _tmp49_ = FALSE;
					_tmp31_ = iterator;
					_tmp32_ = gee_iterator_has_next (_tmp31_);
					has_next = _tmp32_;
					_tmp33_ = valid;
					_tmp34_ = iterator;
					_tmp35_ = gee_iterator_get_valid (_tmp34_);
					_tmp36_ = _tmp35_;
					_vala_assert (_tmp33_ == _tmp36_, "valid == iterator.valid");
					_tmp37_ = has_next;
					_tmp38_ = iterator;
					_tmp39_ = gee_iterator_next (_tmp38_);
					_vala_assert (_tmp37_ == _tmp39_, "has_next == iterator.next ()");
					_tmp40_ = iterator;
					_tmp41_ = gee_iterator_get_valid (_tmp40_);
					_tmp42_ = _tmp41_;
					valid = _tmp42_;
					_tmp43_ = valid;
					_vala_assert (_tmp43_, "valid = iterator.valid");
					_tmp44_ = has_next;
					if (!_tmp44_) {
						break;
					}
					_tmp45_ = iterator;
					_tmp46_ = gee_iterator_get (_tmp45_);
					element = (gchar*) _tmp46_;
					_tmp47_ = iterator;
					_tmp48_ = gee_iterator_get_valid (_tmp47_);
					_tmp49_ = _tmp48_;
					_vala_assert (_tmp49_, "iterator.valid");
					{
						guint element_idx = 0U;
						element_idx = (guint) 0;
						{
							gboolean _tmp50_ = FALSE;
							_tmp50_ = TRUE;
							while (TRUE) {
								guint _tmp52_ = 0U;
								gchar** _tmp53_ = NULL;
								gint _tmp53__length1 = 0;
								gchar** _tmp54_ = NULL;
								gint _tmp54__length1 = 0;
								guint _tmp55_ = 0U;
								const gchar* _tmp56_ = NULL;
								const gchar* _tmp57_ = NULL;
								if (!_tmp50_) {
									guint _tmp51_ = 0U;
									_tmp51_ = element_idx;
									element_idx = _tmp51_ + 1;
								}
								_tmp50_ = FALSE;
								_tmp52_ = element_idx;
								_tmp53_ = data;
								_tmp53__length1 = data_length1;
								_vala_assert (_tmp52_ < ((guint) _tmp53__length1), "element_idx < data.length");
								_tmp54_ = data;
								_tmp54__length1 = data_length1;
								_tmp55_ = element_idx;
								_tmp56_ = _tmp54_[_tmp55_];
								_tmp57_ = element;
								if (g_strcmp0 (_tmp56_, _tmp57_) == 0) {
									guint* _tmp58_ = NULL;
									gint _tmp58__length1 = 0;
									guint _tmp59_ = 0U;
									guint _tmp60_ = 0U;
									_tmp58_ = found_times;
									_tmp58__length1 = found_times_length1;
									_tmp59_ = element_idx;
									_tmp60_ = _tmp58_[_tmp59_];
									_tmp58_[_tmp59_] = _tmp60_ + 1;
									break;
								}
							}
						}
					}
					_g_free0 (element);
				}
				_tmp61_ = iterator;
				_tmp62_ = gee_iterator_has_next (_tmp61_);
				has_next = _tmp62_;
				_tmp63_ = has_next;
				_vala_assert (!_tmp63_, "! has_next");
				_tmp64_ = iterator;
				_tmp65_ = gee_iterator_get_valid (_tmp64_);
				_tmp66_ = _tmp65_;
				_vala_assert (_tmp66_, "iterator.valid");
				_tmp67_ = has_next;
				_tmp68_ = iterator;
				_tmp69_ = gee_iterator_next (_tmp68_);
				_vala_assert (_tmp67_ == _tmp69_, "has_next == iterator.next ()");
				_tmp70_ = iterator;
				_tmp71_ = gee_iterator_get_valid (_tmp70_);
				_tmp72_ = _tmp71_;
				_vala_assert (_tmp72_, "iterator.valid");
				_tmp73_ = found_times;
				_tmp73__length1 = found_times_length1;
				{
					guint* ft_collection = NULL;
					gint ft_collection_length1 = 0;
					gint _ft_collection_size_ = 0;
					gint ft_it = 0;
					ft_collection = _tmp73_;
					ft_collection_length1 = _tmp73__length1;
					for (ft_it = 0; ft_it < _tmp73__length1; ft_it = ft_it + 1) {
						guint ft = 0U;
						ft = ft_collection[ft_it];
						{
							guint _tmp74_ = 0U;
							_tmp74_ = ft;
							_vala_assert (_tmp74_ == ((guint) 1), "ft == 1");
						}
					}
				}
			}
		}
	}
	found_times = (g_free (found_times), NULL);
	_g_object_unref0 (iterator);
}


void collection_tests_test_mutable_iterator (CollectionTests* self) {
	GeeCollection* _tmp0_ = NULL;
	gboolean has_next = FALSE;
	GeeIterator* iterator = NULL;
	GeeCollection* _tmp1_ = NULL;
	GeeIterator* _tmp2_ = NULL;
	gchar** data = NULL;
	gint _tmp3_ = 0;
	gchar** _tmp4_ = NULL;
	gint data_length1 = 0;
	gint _data_size_ = 0;
	guint* idx = NULL;
	gint _tmp5_ = 0;
	guint* _tmp6_ = NULL;
	gint idx_length1 = 0;
	gint _idx_size_ = 0;
	gchar** _tmp7_ = NULL;
	gint _tmp7__length1 = 0;
	GeeCollection* _tmp11_ = NULL;
	GeeIterator* _tmp12_ = NULL;
	guint* found_times = NULL;
	gchar** _tmp13_ = NULL;
	gint _tmp13__length1 = 0;
	guint* _tmp14_ = NULL;
	gint found_times_length1 = 0;
	gint _found_times_size_ = 0;
	g_return_if_fail (self != NULL);
	_tmp0_ = self->test_collection;
	_vala_assert (_tmp0_ != NULL, "test_collection != null");
	_tmp1_ = self->test_collection;
	_tmp2_ = gee_iterable_iterator ((GeeIterable*) _tmp1_);
	iterator = _tmp2_;
	_tmp4_ = test_data_get_data (&_tmp3_);
	data = _tmp4_;
	data_length1 = _tmp3_;
	_data_size_ = data_length1;
	_tmp6_ = test_data_get_drawn_numbers (&_tmp5_);
	idx = _tmp6_;
	idx_length1 = _tmp5_;
	_idx_size_ = idx_length1;
	_tmp7_ = data;
	_tmp7__length1 = data_length1;
	{
		gchar** el_collection = NULL;
		gint el_collection_length1 = 0;
		gint _el_collection_size_ = 0;
		gint el_it = 0;
		el_collection = _tmp7_;
		el_collection_length1 = _tmp7__length1;
		for (el_it = 0; el_it < _tmp7__length1; el_it = el_it + 1) {
			const gchar* el = NULL;
			el = el_collection[el_it];
			{
				GeeCollection* _tmp8_ = NULL;
				const gchar* _tmp9_ = NULL;
				gboolean _tmp10_ = FALSE;
				_tmp8_ = self->test_collection;
				_tmp9_ = el;
				_tmp10_ = gee_collection_add (_tmp8_, _tmp9_);
				_vala_assert (_tmp10_, "test_collection.add (el)");
			}
		}
	}
	_tmp11_ = self->test_collection;
	_tmp12_ = gee_iterable_iterator ((GeeIterable*) _tmp11_);
	_g_object_unref0 (iterator);
	iterator = _tmp12_;
	_tmp13_ = data;
	_tmp13__length1 = data_length1;
	_tmp14_ = g_new0 (guint, _tmp13__length1);
	found_times = _tmp14_;
	found_times_length1 = _tmp13__length1;
	_found_times_size_ = found_times_length1;
	{
		guint i = 0U;
		i = (guint) 0;
		{
			gboolean _tmp15_ = FALSE;
			_tmp15_ = TRUE;
			while (TRUE) {
				guint _tmp17_ = 0U;
				guint* _tmp18_ = NULL;
				gint _tmp18__length1 = 0;
				GeeCollection* _tmp26_ = NULL;
				GeeIterator* _tmp27_ = NULL;
				GeeIterator* _tmp28_ = NULL;
				gboolean _tmp29_ = FALSE;
				gboolean _tmp30_ = FALSE;
				gboolean last_removed = FALSE;
				GeeIterator* _tmp68_ = NULL;
				gboolean _tmp69_ = FALSE;
				gboolean _tmp70_ = FALSE;
				GeeIterator* _tmp71_ = NULL;
				gboolean _tmp72_ = FALSE;
				gboolean _tmp73_ = FALSE;
				gboolean _tmp74_ = FALSE;
				gboolean _tmp75_ = FALSE;
				GeeIterator* _tmp76_ = NULL;
				gboolean _tmp77_ = FALSE;
				GeeIterator* _tmp78_ = NULL;
				gboolean _tmp79_ = FALSE;
				gboolean _tmp80_ = FALSE;
				gboolean _tmp81_ = FALSE;
				if (!_tmp15_) {
					guint _tmp16_ = 0U;
					_tmp16_ = i;
					i = _tmp16_ + 1;
				}
				_tmp15_ = FALSE;
				_tmp17_ = i;
				_tmp18_ = idx;
				_tmp18__length1 = idx_length1;
				if (!(_tmp17_ <= ((guint) _tmp18__length1))) {
					break;
				}
				{
					guint j = 0U;
					j = (guint) 0;
					{
						gboolean _tmp19_ = FALSE;
						_tmp19_ = TRUE;
						while (TRUE) {
							guint _tmp21_ = 0U;
							guint* _tmp22_ = NULL;
							gint _tmp22__length1 = 0;
							guint* _tmp23_ = NULL;
							gint _tmp23__length1 = 0;
							guint _tmp24_ = 0U;
							guint _tmp25_ = 0U;
							if (!_tmp19_) {
								guint _tmp20_ = 0U;
								_tmp20_ = j;
								j = _tmp20_ + 1;
							}
							_tmp19_ = FALSE;
							_tmp21_ = j;
							_tmp22_ = found_times;
							_tmp22__length1 = found_times_length1;
							if (!(_tmp21_ < ((guint) _tmp22__length1))) {
								break;
							}
							_tmp23_ = found_times;
							_tmp23__length1 = found_times_length1;
							_tmp24_ = j;
							_tmp23_[_tmp24_] = (guint) 0;
							_tmp25_ = _tmp23_[_tmp24_];
						}
					}
				}
				_tmp26_ = self->test_collection;
				_tmp27_ = gee_iterable_iterator ((GeeIterable*) _tmp26_);
				_g_object_unref0 (iterator);
				iterator = _tmp27_;
				_tmp28_ = iterator;
				_tmp29_ = gee_iterator_get_valid (_tmp28_);
				_tmp30_ = _tmp29_;
				_vala_assert (!_tmp30_, "! iterator.valid");
				last_removed = FALSE;
				while (TRUE) {
					GeeIterator* _tmp31_ = NULL;
					gboolean _tmp32_ = FALSE;
					gboolean _tmp33_ = FALSE;
					GeeIterator* _tmp34_ = NULL;
					gboolean _tmp35_ = FALSE;
					gboolean _tmp36_ = FALSE;
					gchar* element = NULL;
					GeeIterator* _tmp37_ = NULL;
					gpointer _tmp38_ = NULL;
					GeeIterator* _tmp39_ = NULL;
					gboolean _tmp40_ = FALSE;
					gboolean _tmp41_ = FALSE;
					_tmp31_ = iterator;
					_tmp32_ = gee_iterator_has_next (_tmp31_);
					has_next = _tmp32_;
					_tmp33_ = has_next;
					_tmp34_ = iterator;
					_tmp35_ = gee_iterator_next (_tmp34_);
					_vala_assert (_tmp33_ == _tmp35_, "has_next == iterator.next ()");
					_tmp36_ = has_next;
					if (!_tmp36_) {
						break;
					}
					_tmp37_ = iterator;
					_tmp38_ = gee_iterator_get (_tmp37_);
					element = (gchar*) _tmp38_;
					_tmp39_ = iterator;
					_tmp40_ = gee_iterator_get_valid (_tmp39_);
					_tmp41_ = _tmp40_;
					_vala_assert (_tmp41_, "iterator.valid");
					{
						guint element_idx = 0U;
						element_idx = (guint) 0;
						{
							gboolean _tmp42_ = FALSE;
							_tmp42_ = TRUE;
							while (TRUE) {
								guint _tmp44_ = 0U;
								gchar** _tmp45_ = NULL;
								gint _tmp45__length1 = 0;
								gchar** _tmp46_ = NULL;
								gint _tmp46__length1 = 0;
								guint _tmp47_ = 0U;
								const gchar* _tmp48_ = NULL;
								const gchar* _tmp49_ = NULL;
								if (!_tmp42_) {
									guint _tmp43_ = 0U;
									_tmp43_ = element_idx;
									element_idx = _tmp43_ + 1;
								}
								_tmp42_ = FALSE;
								_tmp44_ = element_idx;
								_tmp45_ = data;
								_tmp45__length1 = data_length1;
								_vala_assert (_tmp44_ < ((guint) _tmp45__length1), "element_idx < data.length");
								_tmp46_ = data;
								_tmp46__length1 = data_length1;
								_tmp47_ = element_idx;
								_tmp48_ = _tmp46_[_tmp47_];
								_tmp49_ = element;
								if (g_strcmp0 (_tmp48_, _tmp49_) == 0) {
									gboolean _tmp50_ = FALSE;
									guint _tmp51_ = 0U;
									guint* _tmp52_ = NULL;
									gint _tmp52__length1 = 0;
									guint* _tmp65_ = NULL;
									gint _tmp65__length1 = 0;
									guint _tmp66_ = 0U;
									guint _tmp67_ = 0U;
									_tmp51_ = i;
									_tmp52_ = idx;
									_tmp52__length1 = idx_length1;
									if (_tmp51_ != ((guint) _tmp52__length1)) {
										gchar** _tmp53_ = NULL;
										gint _tmp53__length1 = 0;
										guint _tmp54_ = 0U;
										const gchar* _tmp55_ = NULL;
										gchar** _tmp56_ = NULL;
										gint _tmp56__length1 = 0;
										guint* _tmp57_ = NULL;
										gint _tmp57__length1 = 0;
										guint _tmp58_ = 0U;
										guint _tmp59_ = 0U;
										const gchar* _tmp60_ = NULL;
										_tmp53_ = data;
										_tmp53__length1 = data_length1;
										_tmp54_ = element_idx;
										_tmp55_ = _tmp53_[_tmp54_];
										_tmp56_ = data;
										_tmp56__length1 = data_length1;
										_tmp57_ = idx;
										_tmp57__length1 = idx_length1;
										_tmp58_ = i;
										_tmp59_ = _tmp57_[_tmp58_];
										_tmp60_ = _tmp56_[_tmp59_];
										_tmp50_ = g_strcmp0 (_tmp55_, _tmp60_) == 0;
									} else {
										_tmp50_ = FALSE;
									}
									if (_tmp50_) {
										GeeIterator* _tmp61_ = NULL;
										GeeIterator* _tmp62_ = NULL;
										gboolean _tmp63_ = FALSE;
										gboolean _tmp64_ = FALSE;
										_tmp61_ = iterator;
										gee_iterator_remove (_tmp61_);
										_tmp62_ = iterator;
										_tmp63_ = gee_iterator_get_valid (_tmp62_);
										_tmp64_ = _tmp63_;
										_vala_assert (!_tmp64_, "! iterator.valid");
										last_removed = TRUE;
									} else {
										last_removed = FALSE;
									}
									_tmp65_ = found_times;
									_tmp65__length1 = found_times_length1;
									_tmp66_ = element_idx;
									_tmp67_ = _tmp65_[_tmp66_];
									_tmp65_[_tmp66_] = _tmp67_ + 1;
									break;
								}
							}
						}
					}
					_g_free0 (element);
				}
				_tmp68_ = iterator;
				_tmp69_ = gee_iterator_has_next (_tmp68_);
				has_next = _tmp69_;
				_tmp70_ = has_next;
				_vala_assert (!_tmp70_, "! has_next");
				_tmp71_ = iterator;
				_tmp72_ = gee_iterator_get_valid (_tmp71_);
				_tmp73_ = _tmp72_;
				_tmp74_ = last_removed;
				_vala_assert (_tmp73_ == (!_tmp74_), "iterator.valid == !last_removed");
				_tmp75_ = has_next;
				_tmp76_ = iterator;
				_tmp77_ = gee_iterator_next (_tmp76_);
				_vala_assert (_tmp75_ == _tmp77_, "has_next == iterator.next ()");
				_tmp78_ = iterator;
				_tmp79_ = gee_iterator_get_valid (_tmp78_);
				_tmp80_ = _tmp79_;
				_tmp81_ = last_removed;
				_vala_assert (_tmp80_ == (!_tmp81_), "iterator.valid == !last_removed");
				{
					guint j = 0U;
					j = (guint) 0;
					{
						gboolean _tmp82_ = FALSE;
						_tmp82_ = TRUE;
						while (TRUE) {
							guint _tmp84_ = 0U;
							guint* _tmp85_ = NULL;
							gint _tmp85__length1 = 0;
							gboolean removed = FALSE;
							gint _tmp94_ = 0;
							gboolean _tmp95_ = FALSE;
							guint* _tmp96_ = NULL;
							gint _tmp96__length1 = 0;
							guint _tmp97_ = 0U;
							guint _tmp98_ = 0U;
							if (!_tmp82_) {
								guint _tmp83_ = 0U;
								_tmp83_ = j;
								j = _tmp83_ + 1;
							}
							_tmp82_ = FALSE;
							_tmp84_ = j;
							_tmp85_ = found_times;
							_tmp85__length1 = found_times_length1;
							if (!(_tmp84_ < ((guint) _tmp85__length1))) {
								break;
							}
							removed = FALSE;
							{
								gint k = 0;
								k = 0;
								{
									gboolean _tmp86_ = FALSE;
									_tmp86_ = TRUE;
									while (TRUE) {
										gint _tmp88_ = 0;
										guint _tmp89_ = 0U;
										guint* _tmp90_ = NULL;
										gint _tmp90__length1 = 0;
										gint _tmp91_ = 0;
										guint _tmp92_ = 0U;
										guint _tmp93_ = 0U;
										if (!_tmp86_) {
											gint _tmp87_ = 0;
											_tmp87_ = k;
											k = _tmp87_ + 1;
										}
										_tmp86_ = FALSE;
										_tmp88_ = k;
										_tmp89_ = i;
										if (!(((guint) _tmp88_) < _tmp89_)) {
											break;
										}
										_tmp90_ = idx;
										_tmp90__length1 = idx_length1;
										_tmp91_ = k;
										_tmp92_ = _tmp90_[_tmp91_];
										_tmp93_ = j;
										if (_tmp92_ == _tmp93_) {
											removed = TRUE;
											break;
										}
									}
								}
							}
							_tmp95_ = removed;
							if (_tmp95_) {
								_tmp94_ = 0;
							} else {
								_tmp94_ = 1;
							}
							_tmp96_ = found_times;
							_tmp96__length1 = found_times_length1;
							_tmp97_ = j;
							_tmp98_ = _tmp96_[_tmp97_];
							_vala_assert (_tmp98_ == ((guint) _tmp94_), "found_times[j] == (removed ? 0 : 1)");
						}
					}
				}
			}
		}
	}
	found_times = (g_free (found_times), NULL);
	_g_object_unref0 (iterator);
}


void collection_tests_test_contains_size_and_is_empty (CollectionTests* self) {
	GeeCollection* _tmp0_ = NULL;
	gchar** data = NULL;
	gint _tmp1_ = 0;
	gchar** _tmp2_ = NULL;
	gint data_length1 = 0;
	gint _data_size_ = 0;
	guint* idx = NULL;
	gint _tmp3_ = 0;
	guint* _tmp4_ = NULL;
	gint idx_length1 = 0;
	gint _idx_size_ = 0;
	gchar** _tmp5_ = NULL;
	gint _tmp5__length1 = 0;
	GeeCollection* _tmp9_ = NULL;
	gint _tmp10_ = 0;
	gint _tmp11_ = 0;
	GeeCollection* _tmp12_ = NULL;
	gboolean _tmp13_ = FALSE;
	gboolean _tmp14_ = FALSE;
	GeeCollection* _tmp15_ = NULL;
	gchar** _tmp16_ = NULL;
	gint _tmp16__length1 = 0;
	const gchar* _tmp17_ = NULL;
	gboolean _tmp18_ = FALSE;
	GeeCollection* _tmp19_ = NULL;
	gchar** _tmp20_ = NULL;
	gint _tmp20__length1 = 0;
	const gchar* _tmp21_ = NULL;
	gboolean _tmp22_ = FALSE;
	GeeCollection* _tmp32_ = NULL;
	gint _tmp33_ = 0;
	gint _tmp34_ = 0;
	GeeCollection* _tmp35_ = NULL;
	gboolean _tmp36_ = FALSE;
	gboolean _tmp37_ = FALSE;
	GeeCollection* _tmp38_ = NULL;
	gboolean _tmp39_ = FALSE;
	gchar** _tmp40_ = NULL;
	gint _tmp40__length1 = 0;
	GeeCollection* _tmp44_ = NULL;
	gint _tmp45_ = 0;
	gint _tmp46_ = 0;
	GeeCollection* _tmp47_ = NULL;
	gboolean _tmp48_ = FALSE;
	gboolean _tmp49_ = FALSE;
	GeeCollection* _tmp149_ = NULL;
	gchar** _tmp150_ = NULL;
	gint _tmp150__length1 = 0;
	GeeCollection* _tmp154_ = NULL;
	gint _tmp155_ = 0;
	gint _tmp156_ = 0;
	GeeCollection* _tmp157_ = NULL;
	gboolean _tmp158_ = FALSE;
	gboolean _tmp159_ = FALSE;
	g_return_if_fail (self != NULL);
	_tmp0_ = self->test_collection;
	_vala_assert (_tmp0_ != NULL, "test_collection != null");
	_tmp2_ = test_data_get_data (&_tmp1_);
	data = _tmp2_;
	data_length1 = _tmp1_;
	_data_size_ = data_length1;
	_tmp4_ = test_data_get_drawn_numbers (&_tmp3_);
	idx = _tmp4_;
	idx_length1 = _tmp3_;
	_idx_size_ = idx_length1;
	_tmp5_ = data;
	_tmp5__length1 = data_length1;
	{
		gchar** s_collection = NULL;
		gint s_collection_length1 = 0;
		gint _s_collection_size_ = 0;
		gint s_it = 0;
		s_collection = _tmp5_;
		s_collection_length1 = _tmp5__length1;
		for (s_it = 0; s_it < _tmp5__length1; s_it = s_it + 1) {
			const gchar* s = NULL;
			s = s_collection[s_it];
			{
				GeeCollection* _tmp6_ = NULL;
				const gchar* _tmp7_ = NULL;
				gboolean _tmp8_ = FALSE;
				_tmp6_ = self->test_collection;
				_tmp7_ = s;
				_tmp8_ = gee_collection_contains (_tmp6_, _tmp7_);
				_vala_assert (!_tmp8_, "! test_collection.contains (s)");
			}
		}
	}
	_tmp9_ = self->test_collection;
	_tmp10_ = gee_collection_get_size (_tmp9_);
	_tmp11_ = _tmp10_;
	_vala_assert (_tmp11_ == 0, "test_collection.size == 0");
	_tmp12_ = self->test_collection;
	_tmp13_ = gee_collection_get_is_empty (_tmp12_);
	_tmp14_ = _tmp13_;
	_vala_assert (_tmp14_, "test_collection.is_empty");
	_tmp15_ = self->test_collection;
	_tmp16_ = data;
	_tmp16__length1 = data_length1;
	_tmp17_ = _tmp16_[0];
	_tmp18_ = gee_collection_add (_tmp15_, _tmp17_);
	_vala_assert (_tmp18_, "test_collection.add (data[0])");
	_tmp19_ = self->test_collection;
	_tmp20_ = data;
	_tmp20__length1 = data_length1;
	_tmp21_ = _tmp20_[0];
	_tmp22_ = gee_collection_contains (_tmp19_, _tmp21_);
	_vala_assert (_tmp22_, "test_collection.contains (data[0])");
	{
		guint i = 0U;
		i = (guint) 1;
		{
			gboolean _tmp23_ = FALSE;
			_tmp23_ = TRUE;
			while (TRUE) {
				guint _tmp25_ = 0U;
				gchar** _tmp26_ = NULL;
				gint _tmp26__length1 = 0;
				GeeCollection* _tmp27_ = NULL;
				gchar** _tmp28_ = NULL;
				gint _tmp28__length1 = 0;
				guint _tmp29_ = 0U;
				const gchar* _tmp30_ = NULL;
				gboolean _tmp31_ = FALSE;
				if (!_tmp23_) {
					guint _tmp24_ = 0U;
					_tmp24_ = i;
					i = _tmp24_ + 1;
				}
				_tmp23_ = FALSE;
				_tmp25_ = i;
				_tmp26_ = data;
				_tmp26__length1 = data_length1;
				if (!(_tmp25_ < ((guint) _tmp26__length1))) {
					break;
				}
				_tmp27_ = self->test_collection;
				_tmp28_ = data;
				_tmp28__length1 = data_length1;
				_tmp29_ = i;
				_tmp30_ = _tmp28_[_tmp29_];
				_tmp31_ = gee_collection_contains (_tmp27_, _tmp30_);
				_vala_assert (!_tmp31_, "! test_collection.contains (data[i])");
			}
		}
	}
	_tmp32_ = self->test_collection;
	_tmp33_ = gee_collection_get_size (_tmp32_);
	_tmp34_ = _tmp33_;
	_vala_assert (_tmp34_ == 1, "test_collection.size == 1");
	_tmp35_ = self->test_collection;
	_tmp36_ = gee_collection_get_is_empty (_tmp35_);
	_tmp37_ = _tmp36_;
	_vala_assert (!_tmp37_, "! test_collection.is_empty");
	_tmp38_ = self->test_collection;
	_tmp39_ = gee_collection_remove (_tmp38_, "one");
	_vala_assert (_tmp39_, "test_collection.remove (\"one\")");
	_tmp40_ = data;
	_tmp40__length1 = data_length1;
	{
		gchar** s_collection = NULL;
		gint s_collection_length1 = 0;
		gint _s_collection_size_ = 0;
		gint s_it = 0;
		s_collection = _tmp40_;
		s_collection_length1 = _tmp40__length1;
		for (s_it = 0; s_it < _tmp40__length1; s_it = s_it + 1) {
			const gchar* s = NULL;
			s = s_collection[s_it];
			{
				GeeCollection* _tmp41_ = NULL;
				const gchar* _tmp42_ = NULL;
				gboolean _tmp43_ = FALSE;
				_tmp41_ = self->test_collection;
				_tmp42_ = s;
				_tmp43_ = gee_collection_contains (_tmp41_, _tmp42_);
				_vala_assert (!_tmp43_, "! test_collection.contains (s)");
			}
		}
	}
	_tmp44_ = self->test_collection;
	_tmp45_ = gee_collection_get_size (_tmp44_);
	_tmp46_ = _tmp45_;
	_vala_assert (_tmp46_ == 0, "test_collection.size == 0");
	_tmp47_ = self->test_collection;
	_tmp48_ = gee_collection_get_is_empty (_tmp47_);
	_tmp49_ = _tmp48_;
	_vala_assert (_tmp49_, "test_collection.is_empty");
	{
		guint i = 0U;
		i = (guint) 0;
		{
			gboolean _tmp50_ = FALSE;
			_tmp50_ = TRUE;
			while (TRUE) {
				guint _tmp52_ = 0U;
				gchar** _tmp53_ = NULL;
				gint _tmp53__length1 = 0;
				GeeCollection* _tmp54_ = NULL;
				gchar** _tmp55_ = NULL;
				gint _tmp55__length1 = 0;
				guint _tmp56_ = 0U;
				const gchar* _tmp57_ = NULL;
				gboolean _tmp58_ = FALSE;
				GeeCollection* _tmp78_ = NULL;
				gint _tmp79_ = 0;
				gint _tmp80_ = 0;
				guint _tmp81_ = 0U;
				GeeCollection* _tmp82_ = NULL;
				gboolean _tmp83_ = FALSE;
				gboolean _tmp84_ = FALSE;
				if (!_tmp50_) {
					guint _tmp51_ = 0U;
					_tmp51_ = i;
					i = _tmp51_ + 1;
				}
				_tmp50_ = FALSE;
				_tmp52_ = i;
				_tmp53_ = data;
				_tmp53__length1 = data_length1;
				if (!(_tmp52_ < ((guint) _tmp53__length1))) {
					break;
				}
				_tmp54_ = self->test_collection;
				_tmp55_ = data;
				_tmp55__length1 = data_length1;
				_tmp56_ = i;
				_tmp57_ = _tmp55_[_tmp56_];
				_tmp58_ = gee_collection_add (_tmp54_, _tmp57_);
				_vala_assert (_tmp58_, "test_collection.add (data[i])");
				{
					guint j = 0U;
					j = (guint) 0;
					{
						gboolean _tmp59_ = FALSE;
						_tmp59_ = TRUE;
						while (TRUE) {
							guint _tmp61_ = 0U;
							guint _tmp62_ = 0U;
							GeeCollection* _tmp63_ = NULL;
							gchar** _tmp64_ = NULL;
							gint _tmp64__length1 = 0;
							guint _tmp65_ = 0U;
							const gchar* _tmp66_ = NULL;
							gboolean _tmp67_ = FALSE;
							if (!_tmp59_) {
								guint _tmp60_ = 0U;
								_tmp60_ = j;
								j = _tmp60_ + 1;
							}
							_tmp59_ = FALSE;
							_tmp61_ = j;
							_tmp62_ = i;
							if (!(_tmp61_ <= _tmp62_)) {
								break;
							}
							_tmp63_ = self->test_collection;
							_tmp64_ = data;
							_tmp64__length1 = data_length1;
							_tmp65_ = j;
							_tmp66_ = _tmp64_[_tmp65_];
							_tmp67_ = gee_collection_contains (_tmp63_, _tmp66_);
							_vala_assert (_tmp67_, "test_collection.contains (data[j])");
						}
					}
				}
				{
					guint j = 0U;
					guint _tmp68_ = 0U;
					_tmp68_ = i;
					j = _tmp68_ + 1;
					{
						gboolean _tmp69_ = FALSE;
						_tmp69_ = TRUE;
						while (TRUE) {
							guint _tmp71_ = 0U;
							gchar** _tmp72_ = NULL;
							gint _tmp72__length1 = 0;
							GeeCollection* _tmp73_ = NULL;
							gchar** _tmp74_ = NULL;
							gint _tmp74__length1 = 0;
							guint _tmp75_ = 0U;
							const gchar* _tmp76_ = NULL;
							gboolean _tmp77_ = FALSE;
							if (!_tmp69_) {
								guint _tmp70_ = 0U;
								_tmp70_ = j;
								j = _tmp70_ + 1;
							}
							_tmp69_ = FALSE;
							_tmp71_ = j;
							_tmp72_ = data;
							_tmp72__length1 = data_length1;
							if (!(_tmp71_ < ((guint) _tmp72__length1))) {
								break;
							}
							_tmp73_ = self->test_collection;
							_tmp74_ = data;
							_tmp74__length1 = data_length1;
							_tmp75_ = j;
							_tmp76_ = _tmp74_[_tmp75_];
							_tmp77_ = gee_collection_contains (_tmp73_, _tmp76_);
							_vala_assert (!_tmp77_, "! test_collection.contains (data[j])");
						}
					}
				}
				_tmp78_ = self->test_collection;
				_tmp79_ = gee_collection_get_size (_tmp78_);
				_tmp80_ = _tmp79_;
				_tmp81_ = i;
				_vala_assert (((guint) _tmp80_) == (_tmp81_ + 1), "test_collection.size == i + 1");
				_tmp82_ = self->test_collection;
				_tmp83_ = gee_collection_get_is_empty (_tmp82_);
				_tmp84_ = _tmp83_;
				_vala_assert (!_tmp84_, "! test_collection.is_empty");
			}
		}
	}
	{
		guint i = 0U;
		i = (guint) 0;
		{
			gboolean _tmp85_ = FALSE;
			_tmp85_ = TRUE;
			while (TRUE) {
				guint _tmp87_ = 0U;
				guint* _tmp88_ = NULL;
				gint _tmp88__length1 = 0;
				GeeCollection* _tmp89_ = NULL;
				gchar** _tmp90_ = NULL;
				gint _tmp90__length1 = 0;
				guint* _tmp91_ = NULL;
				gint _tmp91__length1 = 0;
				guint _tmp92_ = 0U;
				guint _tmp93_ = 0U;
				const gchar* _tmp94_ = NULL;
				gboolean _tmp95_ = FALSE;
				GeeCollection* _tmp114_ = NULL;
				gint _tmp115_ = 0;
				gint _tmp116_ = 0;
				gchar** _tmp117_ = NULL;
				gint _tmp117__length1 = 0;
				guint _tmp118_ = 0U;
				GeeCollection* _tmp119_ = NULL;
				gchar** _tmp120_ = NULL;
				gint _tmp120__length1 = 0;
				guint* _tmp121_ = NULL;
				gint _tmp121__length1 = 0;
				guint _tmp122_ = 0U;
				guint _tmp123_ = 0U;
				const gchar* _tmp124_ = NULL;
				gboolean _tmp125_ = FALSE;
				GeeCollection* _tmp144_ = NULL;
				gint _tmp145_ = 0;
				gint _tmp146_ = 0;
				gchar** _tmp147_ = NULL;
				gint _tmp147__length1 = 0;
				guint _tmp148_ = 0U;
				if (!_tmp85_) {
					guint _tmp86_ = 0U;
					_tmp86_ = i;
					i = _tmp86_ + 1;
				}
				_tmp85_ = FALSE;
				_tmp87_ = i;
				_tmp88_ = idx;
				_tmp88__length1 = idx_length1;
				if (!(_tmp87_ < ((guint) _tmp88__length1))) {
					break;
				}
				_tmp89_ = self->test_collection;
				_tmp90_ = data;
				_tmp90__length1 = data_length1;
				_tmp91_ = idx;
				_tmp91__length1 = idx_length1;
				_tmp92_ = i;
				_tmp93_ = _tmp91_[_tmp92_];
				_tmp94_ = _tmp90_[_tmp93_];
				_tmp95_ = gee_collection_remove (_tmp89_, _tmp94_);
				_vala_assert (_tmp95_, "test_collection.remove (data[idx[i]])");
				{
					guint j = 0U;
					j = (guint) 0;
					{
						gboolean _tmp96_ = FALSE;
						_tmp96_ = TRUE;
						while (TRUE) {
							guint _tmp98_ = 0U;
							gchar** _tmp99_ = NULL;
							gint _tmp99__length1 = 0;
							gboolean removed = FALSE;
							GeeCollection* _tmp108_ = NULL;
							gchar** _tmp109_ = NULL;
							gint _tmp109__length1 = 0;
							guint _tmp110_ = 0U;
							const gchar* _tmp111_ = NULL;
							gboolean _tmp112_ = FALSE;
							gboolean _tmp113_ = FALSE;
							if (!_tmp96_) {
								guint _tmp97_ = 0U;
								_tmp97_ = j;
								j = _tmp97_ + 1;
							}
							_tmp96_ = FALSE;
							_tmp98_ = j;
							_tmp99_ = data;
							_tmp99__length1 = data_length1;
							if (!(_tmp98_ < ((guint) _tmp99__length1))) {
								break;
							}
							removed = FALSE;
							{
								guint k = 0U;
								k = (guint) 0;
								{
									gboolean _tmp100_ = FALSE;
									_tmp100_ = TRUE;
									while (TRUE) {
										guint _tmp102_ = 0U;
										guint _tmp103_ = 0U;
										guint* _tmp104_ = NULL;
										gint _tmp104__length1 = 0;
										guint _tmp105_ = 0U;
										guint _tmp106_ = 0U;
										guint _tmp107_ = 0U;
										if (!_tmp100_) {
											guint _tmp101_ = 0U;
											_tmp101_ = k;
											k = _tmp101_ + 1;
										}
										_tmp100_ = FALSE;
										_tmp102_ = k;
										_tmp103_ = i;
										if (!(_tmp102_ <= _tmp103_)) {
											break;
										}
										_tmp104_ = idx;
										_tmp104__length1 = idx_length1;
										_tmp105_ = k;
										_tmp106_ = _tmp104_[_tmp105_];
										_tmp107_ = j;
										if (_tmp106_ == _tmp107_) {
											removed = TRUE;
											break;
										}
									}
								}
							}
							_tmp108_ = self->test_collection;
							_tmp109_ = data;
							_tmp109__length1 = data_length1;
							_tmp110_ = j;
							_tmp111_ = _tmp109_[_tmp110_];
							_tmp112_ = gee_collection_contains (_tmp108_, _tmp111_);
							_tmp113_ = removed;
							_vala_assert (_tmp112_ == (!_tmp113_), "test_collection.contains (data[j]) == !removed");
						}
					}
				}
				_tmp114_ = self->test_collection;
				_tmp115_ = gee_collection_get_size (_tmp114_);
				_tmp116_ = _tmp115_;
				_tmp117_ = data;
				_tmp117__length1 = data_length1;
				_tmp118_ = i;
				_vala_assert (((guint) _tmp116_) == (_tmp117__length1 - (_tmp118_ + 1)), "test_collection.size == data.length - (i + 1)");
				_tmp119_ = self->test_collection;
				_tmp120_ = data;
				_tmp120__length1 = data_length1;
				_tmp121_ = idx;
				_tmp121__length1 = idx_length1;
				_tmp122_ = i;
				_tmp123_ = _tmp121_[_tmp122_];
				_tmp124_ = _tmp120_[_tmp123_];
				_tmp125_ = gee_collection_remove (_tmp119_, _tmp124_);
				_vala_assert (!_tmp125_, "! test_collection.remove (data[idx[i]])");
				{
					guint j = 0U;
					j = (guint) 0;
					{
						gboolean _tmp126_ = FALSE;
						_tmp126_ = TRUE;
						while (TRUE) {
							guint _tmp128_ = 0U;
							gchar** _tmp129_ = NULL;
							gint _tmp129__length1 = 0;
							gboolean removed = FALSE;
							GeeCollection* _tmp138_ = NULL;
							gchar** _tmp139_ = NULL;
							gint _tmp139__length1 = 0;
							guint _tmp140_ = 0U;
							const gchar* _tmp141_ = NULL;
							gboolean _tmp142_ = FALSE;
							gboolean _tmp143_ = FALSE;
							if (!_tmp126_) {
								guint _tmp127_ = 0U;
								_tmp127_ = j;
								j = _tmp127_ + 1;
							}
							_tmp126_ = FALSE;
							_tmp128_ = j;
							_tmp129_ = data;
							_tmp129__length1 = data_length1;
							if (!(_tmp128_ < ((guint) _tmp129__length1))) {
								break;
							}
							removed = FALSE;
							{
								guint k = 0U;
								k = (guint) 0;
								{
									gboolean _tmp130_ = FALSE;
									_tmp130_ = TRUE;
									while (TRUE) {
										guint _tmp132_ = 0U;
										guint _tmp133_ = 0U;
										guint* _tmp134_ = NULL;
										gint _tmp134__length1 = 0;
										guint _tmp135_ = 0U;
										guint _tmp136_ = 0U;
										guint _tmp137_ = 0U;
										if (!_tmp130_) {
											guint _tmp131_ = 0U;
											_tmp131_ = k;
											k = _tmp131_ + 1;
										}
										_tmp130_ = FALSE;
										_tmp132_ = k;
										_tmp133_ = i;
										if (!(_tmp132_ <= _tmp133_)) {
											break;
										}
										_tmp134_ = idx;
										_tmp134__length1 = idx_length1;
										_tmp135_ = k;
										_tmp136_ = _tmp134_[_tmp135_];
										_tmp137_ = j;
										if (_tmp136_ == _tmp137_) {
											removed = TRUE;
											break;
										}
									}
								}
							}
							_tmp138_ = self->test_collection;
							_tmp139_ = data;
							_tmp139__length1 = data_length1;
							_tmp140_ = j;
							_tmp141_ = _tmp139_[_tmp140_];
							_tmp142_ = gee_collection_contains (_tmp138_, _tmp141_);
							_tmp143_ = removed;
							_vala_assert (_tmp142_ == (!_tmp143_), "test_collection.contains (data[j]) == !removed");
						}
					}
				}
				_tmp144_ = self->test_collection;
				_tmp145_ = gee_collection_get_size (_tmp144_);
				_tmp146_ = _tmp145_;
				_tmp147_ = data;
				_tmp147__length1 = data_length1;
				_tmp148_ = i;
				_vala_assert (((guint) _tmp146_) == (_tmp147__length1 - (_tmp148_ + 1)), "test_collection.size == data.length - (i + 1)");
			}
		}
	}
	_tmp149_ = self->test_collection;
	gee_collection_clear (_tmp149_);
	_tmp150_ = data;
	_tmp150__length1 = data_length1;
	{
		gchar** el_collection = NULL;
		gint el_collection_length1 = 0;
		gint _el_collection_size_ = 0;
		gint el_it = 0;
		el_collection = _tmp150_;
		el_collection_length1 = _tmp150__length1;
		for (el_it = 0; el_it < _tmp150__length1; el_it = el_it + 1) {
			const gchar* el = NULL;
			el = el_collection[el_it];
			{
				GeeCollection* _tmp151_ = NULL;
				const gchar* _tmp152_ = NULL;
				gboolean _tmp153_ = FALSE;
				_tmp151_ = self->test_collection;
				_tmp152_ = el;
				_tmp153_ = gee_collection_contains (_tmp151_, _tmp152_);
				_vala_assert (!_tmp153_, "! test_collection.contains (el)");
			}
		}
	}
	_tmp154_ = self->test_collection;
	_tmp155_ = gee_collection_get_size (_tmp154_);
	_tmp156_ = _tmp155_;
	_vala_assert (_tmp156_ == 0, "test_collection.size == 0");
	_tmp157_ = self->test_collection;
	_tmp158_ = gee_collection_get_is_empty (_tmp157_);
	_tmp159_ = _tmp158_;
	_vala_assert (_tmp159_, "test_collection.is_empty");
}


void collection_tests_test_add_remove (CollectionTests* self) {
	GeeCollection* _tmp0_ = NULL;
	gchar** to_add = NULL;
	gint _tmp1_ = 0;
	gchar** _tmp2_ = NULL;
	gint to_add_length1 = 0;
	gint _to_add_size_ = 0;
	gint expected_size = 0;
	gchar** _tmp3_ = NULL;
	gint _tmp3__length1 = 0;
	GeeCollection* _tmp18_ = NULL;
	gint _tmp19_ = 0;
	gint _tmp20_ = 0;
	gchar** _tmp21_ = NULL;
	gint _tmp21__length1 = 0;
	gchar** _tmp22_ = NULL;
	gint _tmp22__length1 = 0;
	gchar** _tmp27_ = NULL;
	gint _tmp27__length1 = 0;
	GeeCollection* _tmp42_ = NULL;
	gint _tmp43_ = 0;
	gint _tmp44_ = 0;
	g_return_if_fail (self != NULL);
	_tmp0_ = self->test_collection;
	_vala_assert (_tmp0_ != NULL, "test_collection != null");
	_tmp2_ = test_data_get_data (&_tmp1_);
	to_add = _tmp2_;
	to_add_length1 = _tmp1_;
	_to_add_size_ = to_add_length1;
	expected_size = 0;
	_tmp3_ = to_add;
	_tmp3__length1 = to_add_length1;
	{
		gchar** a_collection = NULL;
		gint a_collection_length1 = 0;
		gint _a_collection_size_ = 0;
		gint a_it = 0;
		a_collection = _tmp3_;
		a_collection_length1 = _tmp3__length1;
		for (a_it = 0; a_it < _tmp3__length1; a_it = a_it + 1) {
			gchar* _tmp4_ = NULL;
			gchar* a = NULL;
			_tmp4_ = g_strdup (a_collection[a_it]);
			a = _tmp4_;
			{
				GeeCollection* _tmp5_ = NULL;
				const gchar* _tmp6_ = NULL;
				gboolean _tmp7_ = FALSE;
				GeeCollection* _tmp8_ = NULL;
				gint _tmp9_ = 0;
				gint _tmp10_ = 0;
				gint _tmp11_ = 0;
				GeeCollection* _tmp12_ = NULL;
				const gchar* _tmp13_ = NULL;
				gboolean _tmp14_ = FALSE;
				GeeCollection* _tmp15_ = NULL;
				const gchar* _tmp16_ = NULL;
				gboolean _tmp17_ = FALSE;
				_tmp5_ = self->test_collection;
				_tmp6_ = a;
				_tmp7_ = gee_collection_contains (_tmp5_, _tmp6_);
				_vala_assert (!_tmp7_, "!test_collection.contains (a)");
				_tmp8_ = self->test_collection;
				_tmp9_ = gee_collection_get_size (_tmp8_);
				_tmp10_ = _tmp9_;
				_tmp11_ = expected_size;
				expected_size = _tmp11_ + 1;
				_vala_assert (_tmp10_ == _tmp11_, "test_collection.size == expected_size++");
				_tmp12_ = self->test_collection;
				_tmp13_ = a;
				_tmp14_ = gee_collection_add (_tmp12_, _tmp13_);
				_vala_assert (_tmp14_, "test_collection.add (a)");
				_tmp15_ = self->test_collection;
				_tmp16_ = a;
				_tmp17_ = gee_collection_contains (_tmp15_, _tmp16_);
				_vala_assert (_tmp17_, "test_collection.contains (a)");
				_g_free0 (a);
			}
		}
	}
	_tmp18_ = self->test_collection;
	_tmp19_ = gee_collection_get_size (_tmp18_);
	_tmp20_ = _tmp19_;
	_tmp21_ = to_add;
	_tmp21__length1 = to_add_length1;
	_vala_assert (_tmp20_ == _tmp21__length1, "test_collection.size == to_add.length");
	_tmp22_ = to_add;
	_tmp22__length1 = to_add_length1;
	{
		gchar** a_collection = NULL;
		gint a_collection_length1 = 0;
		gint _a_collection_size_ = 0;
		gint a_it = 0;
		a_collection = _tmp22_;
		a_collection_length1 = _tmp22__length1;
		for (a_it = 0; a_it < _tmp22__length1; a_it = a_it + 1) {
			gchar* _tmp23_ = NULL;
			gchar* a = NULL;
			_tmp23_ = g_strdup (a_collection[a_it]);
			a = _tmp23_;
			{
				GeeCollection* _tmp24_ = NULL;
				const gchar* _tmp25_ = NULL;
				gboolean _tmp26_ = FALSE;
				_tmp24_ = self->test_collection;
				_tmp25_ = a;
				_tmp26_ = gee_collection_contains (_tmp24_, _tmp25_);
				_vala_assert (_tmp26_, "test_collection.contains (a)");
				_g_free0 (a);
			}
		}
	}
	_tmp27_ = to_add;
	_tmp27__length1 = to_add_length1;
	{
		gchar** a_collection = NULL;
		gint a_collection_length1 = 0;
		gint _a_collection_size_ = 0;
		gint a_it = 0;
		a_collection = _tmp27_;
		a_collection_length1 = _tmp27__length1;
		for (a_it = 0; a_it < _tmp27__length1; a_it = a_it + 1) {
			gchar* _tmp28_ = NULL;
			gchar* a = NULL;
			_tmp28_ = g_strdup (a_collection[a_it]);
			a = _tmp28_;
			{
				GeeCollection* _tmp29_ = NULL;
				const gchar* _tmp30_ = NULL;
				gboolean _tmp31_ = FALSE;
				GeeCollection* _tmp32_ = NULL;
				gint _tmp33_ = 0;
				gint _tmp34_ = 0;
				gint _tmp35_ = 0;
				GeeCollection* _tmp36_ = NULL;
				const gchar* _tmp37_ = NULL;
				gboolean _tmp38_ = FALSE;
				GeeCollection* _tmp39_ = NULL;
				const gchar* _tmp40_ = NULL;
				gboolean _tmp41_ = FALSE;
				_tmp29_ = self->test_collection;
				_tmp30_ = a;
				_tmp31_ = gee_collection_contains (_tmp29_, _tmp30_);
				_vala_assert (_tmp31_, "test_collection.contains (a)");
				_tmp32_ = self->test_collection;
				_tmp33_ = gee_collection_get_size (_tmp32_);
				_tmp34_ = _tmp33_;
				_tmp35_ = expected_size;
				expected_size = _tmp35_ - 1;
				_vala_assert (_tmp34_ == _tmp35_, "test_collection.size == expected_size--");
				_tmp36_ = self->test_collection;
				_tmp37_ = a;
				_tmp38_ = gee_collection_remove (_tmp36_, _tmp37_);
				_vala_assert (_tmp38_, "test_collection.remove (a)");
				_tmp39_ = self->test_collection;
				_tmp40_ = a;
				_tmp41_ = gee_collection_contains (_tmp39_, _tmp40_);
				_vala_assert (!_tmp41_, "!test_collection.contains (a)");
				_g_free0 (a);
			}
		}
	}
	_tmp42_ = self->test_collection;
	_tmp43_ = gee_collection_get_size (_tmp42_);
	_tmp44_ = _tmp43_;
	_vala_assert (_tmp44_ == 0, "test_collection.size == 0");
}


void collection_tests_test_clear (CollectionTests* self) {
	GeeCollection* _tmp0_ = NULL;
	gchar** to_add = NULL;
	gint _tmp1_ = 0;
	gchar** _tmp2_ = NULL;
	gint to_add_length1 = 0;
	gint _to_add_size_ = 0;
	gint expected_size = 0;
	gchar** _tmp3_ = NULL;
	gint _tmp3__length1 = 0;
	GeeCollection* _tmp18_ = NULL;
	gint _tmp19_ = 0;
	gint _tmp20_ = 0;
	gchar** _tmp21_ = NULL;
	gint _tmp21__length1 = 0;
	GeeCollection* _tmp22_ = NULL;
	GeeCollection* _tmp23_ = NULL;
	gint _tmp24_ = 0;
	gint _tmp25_ = 0;
	GeeIterator* iter = NULL;
	GeeCollection* _tmp26_ = NULL;
	GeeIterator* _tmp27_ = NULL;
	gboolean _tmp28_ = FALSE;
	g_return_if_fail (self != NULL);
	_tmp0_ = self->test_collection;
	_vala_assert (_tmp0_ != NULL, "test_collection != null");
	_tmp2_ = test_data_get_data (&_tmp1_);
	to_add = _tmp2_;
	to_add_length1 = _tmp1_;
	_to_add_size_ = to_add_length1;
	expected_size = 0;
	_tmp3_ = to_add;
	_tmp3__length1 = to_add_length1;
	{
		gchar** a_collection = NULL;
		gint a_collection_length1 = 0;
		gint _a_collection_size_ = 0;
		gint a_it = 0;
		a_collection = _tmp3_;
		a_collection_length1 = _tmp3__length1;
		for (a_it = 0; a_it < _tmp3__length1; a_it = a_it + 1) {
			gchar* _tmp4_ = NULL;
			gchar* a = NULL;
			_tmp4_ = g_strdup (a_collection[a_it]);
			a = _tmp4_;
			{
				GeeCollection* _tmp5_ = NULL;
				const gchar* _tmp6_ = NULL;
				gboolean _tmp7_ = FALSE;
				GeeCollection* _tmp8_ = NULL;
				gint _tmp9_ = 0;
				gint _tmp10_ = 0;
				gint _tmp11_ = 0;
				GeeCollection* _tmp12_ = NULL;
				const gchar* _tmp13_ = NULL;
				gboolean _tmp14_ = FALSE;
				GeeCollection* _tmp15_ = NULL;
				const gchar* _tmp16_ = NULL;
				gboolean _tmp17_ = FALSE;
				_tmp5_ = self->test_collection;
				_tmp6_ = a;
				_tmp7_ = gee_collection_contains (_tmp5_, _tmp6_);
				_vala_assert (!_tmp7_, "!test_collection.contains (a)");
				_tmp8_ = self->test_collection;
				_tmp9_ = gee_collection_get_size (_tmp8_);
				_tmp10_ = _tmp9_;
				_tmp11_ = expected_size;
				expected_size = _tmp11_ + 1;
				_vala_assert (_tmp10_ == _tmp11_, "test_collection.size == expected_size++");
				_tmp12_ = self->test_collection;
				_tmp13_ = a;
				_tmp14_ = gee_collection_add (_tmp12_, _tmp13_);
				_vala_assert (_tmp14_, "test_collection.add (a)");
				_tmp15_ = self->test_collection;
				_tmp16_ = a;
				_tmp17_ = gee_collection_contains (_tmp15_, _tmp16_);
				_vala_assert (_tmp17_, "test_collection.contains (a)");
				_g_free0 (a);
			}
		}
	}
	_tmp18_ = self->test_collection;
	_tmp19_ = gee_collection_get_size (_tmp18_);
	_tmp20_ = _tmp19_;
	_tmp21_ = to_add;
	_tmp21__length1 = to_add_length1;
	_vala_assert (_tmp20_ == _tmp21__length1, "test_collection.size == to_add.length");
	_tmp22_ = self->test_collection;
	gee_collection_clear (_tmp22_);
	_tmp23_ = self->test_collection;
	_tmp24_ = gee_collection_get_size (_tmp23_);
	_tmp25_ = _tmp24_;
	_vala_assert (_tmp25_ == 0, "test_collection.size == 0");
	_tmp26_ = self->test_collection;
	_tmp27_ = gee_iterable_iterator ((GeeIterable*) _tmp26_);
	iter = _tmp27_;
	_vala_assert (iter != NULL, "iter != null");
	_tmp28_ = gee_iterator_has_next (iter);
	_vala_assert (!_tmp28_, "!iter.has_next ()");
	_g_object_unref0 (iter);
}


void collection_tests_test_add_all (CollectionTests* self) {
	GeeCollection* _tmp0_ = NULL;
	GeeArrayList* dummy = NULL;
	GeeArrayList* _tmp1_ = NULL;
	GeeCollection* _tmp2_ = NULL;
	gboolean _tmp3_ = FALSE;
	GeeCollection* _tmp4_ = NULL;
	gboolean _tmp5_ = FALSE;
	gboolean _tmp6_ = FALSE;
	gboolean _tmp7_ = FALSE;
	gboolean _tmp8_ = FALSE;
	GeeCollection* _tmp9_ = NULL;
	gboolean _tmp10_ = FALSE;
	GeeCollection* _tmp11_ = NULL;
	gboolean _tmp12_ = FALSE;
	GeeCollection* _tmp13_ = NULL;
	gint _tmp14_ = 0;
	gint _tmp15_ = 0;
	GeeCollection* _tmp16_ = NULL;
	gboolean _tmp17_ = FALSE;
	GeeCollection* _tmp18_ = NULL;
	gboolean _tmp19_ = FALSE;
	gboolean _tmp20_ = FALSE;
	gboolean _tmp21_ = FALSE;
	GeeCollection* _tmp22_ = NULL;
	gboolean _tmp23_ = FALSE;
	GeeCollection* _tmp24_ = NULL;
	gint _tmp25_ = 0;
	gint _tmp26_ = 0;
	GeeCollection* _tmp27_ = NULL;
	gboolean _tmp28_ = FALSE;
	GeeCollection* _tmp29_ = NULL;
	gboolean _tmp30_ = FALSE;
	GeeCollection* _tmp31_ = NULL;
	gboolean _tmp32_ = FALSE;
	gint _tmp33_ = 0;
	gint _tmp34_ = 0;
	gboolean _tmp35_ = FALSE;
	gboolean _tmp36_ = FALSE;
	gboolean _tmp37_ = FALSE;
	GeeCollection* _tmp38_ = NULL;
	gboolean _tmp39_ = FALSE;
	gboolean _tmp40_ = FALSE;
	gboolean _tmp41_ = FALSE;
	GeeCollection* _tmp42_ = NULL;
	gboolean _tmp43_ = FALSE;
	GeeCollection* _tmp44_ = NULL;
	gboolean _tmp45_ = FALSE;
	GeeCollection* _tmp46_ = NULL;
	gint _tmp47_ = 0;
	gint _tmp48_ = 0;
	GeeCollection* _tmp49_ = NULL;
	gboolean _tmp50_ = FALSE;
	GeeCollection* _tmp51_ = NULL;
	gboolean _tmp52_ = FALSE;
	GeeCollection* _tmp53_ = NULL;
	gboolean _tmp54_ = FALSE;
	GeeCollection* _tmp55_ = NULL;
	gboolean _tmp56_ = FALSE;
	gint _tmp57_ = 0;
	gint _tmp58_ = 0;
	gboolean _tmp59_ = FALSE;
	gboolean _tmp60_ = FALSE;
	gboolean _tmp61_ = FALSE;
	GeeCollection* _tmp62_ = NULL;
	gboolean _tmp63_ = FALSE;
	gboolean _tmp64_ = FALSE;
	gboolean _tmp65_ = FALSE;
	GeeCollection* _tmp66_ = NULL;
	gboolean _tmp67_ = FALSE;
	GeeCollection* _tmp68_ = NULL;
	gboolean _tmp69_ = FALSE;
	GeeCollection* _tmp70_ = NULL;
	gint _tmp71_ = 0;
	gint _tmp72_ = 0;
	GeeCollection* _tmp73_ = NULL;
	gboolean _tmp74_ = FALSE;
	GeeCollection* _tmp75_ = NULL;
	gboolean _tmp76_ = FALSE;
	GeeCollection* _tmp77_ = NULL;
	gboolean _tmp78_ = FALSE;
	gint _tmp79_ = 0;
	gint _tmp80_ = 0;
	gboolean _tmp81_ = FALSE;
	gboolean _tmp82_ = FALSE;
	gboolean _tmp83_ = FALSE;
	g_return_if_fail (self != NULL);
	_tmp0_ = self->test_collection;
	_vala_assert (_tmp0_ != NULL, "test_collection != null");
	_tmp1_ = gee_array_list_new (G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, g_free, NULL, NULL, NULL);
	dummy = _tmp1_;
	_tmp2_ = self->test_collection;
	_tmp3_ = gee_collection_add_all (_tmp2_, (GeeCollection*) dummy);
	_vala_assert (!_tmp3_, "! test_collection.add_all (dummy)");
	_tmp4_ = self->test_collection;
	_tmp5_ = gee_collection_get_is_empty (_tmp4_);
	_tmp6_ = _tmp5_;
	_vala_assert (_tmp6_, "test_collection.is_empty");
	_tmp7_ = gee_collection_get_is_empty ((GeeCollection*) dummy);
	_tmp8_ = _tmp7_;
	_vala_assert (_tmp8_, "dummy.is_empty");
	_tmp9_ = self->test_collection;
	_tmp10_ = gee_collection_add (_tmp9_, "hello");
	_vala_assert (_tmp10_, "test_collection.add (\"hello\")");
	_tmp11_ = self->test_collection;
	_tmp12_ = gee_collection_add_all (_tmp11_, (GeeCollection*) dummy);
	_vala_assert (!_tmp12_, "! test_collection.add_all (dummy)");
	_tmp13_ = self->test_collection;
	_tmp14_ = gee_collection_get_size (_tmp13_);
	_tmp15_ = _tmp14_;
	_vala_assert (_tmp15_ == 1, "test_collection.size == 1");
	_tmp16_ = self->test_collection;
	_tmp17_ = gee_collection_contains (_tmp16_, "hello");
	_vala_assert (_tmp17_, "test_collection.contains (\"hello\")");
	_tmp18_ = self->test_collection;
	gee_collection_clear (_tmp18_);
	gee_abstract_collection_clear ((GeeAbstractCollection*) dummy);
	_tmp19_ = gee_abstract_collection_add ((GeeAbstractCollection*) dummy, "hello1");
	_vala_assert (_tmp19_, "dummy.add (\"hello1\")");
	_tmp20_ = gee_abstract_collection_add ((GeeAbstractCollection*) dummy, "hello2");
	_vala_assert (_tmp20_, "dummy.add (\"hello2\")");
	_tmp21_ = gee_abstract_collection_add ((GeeAbstractCollection*) dummy, "hello3");
	_vala_assert (_tmp21_, "dummy.add (\"hello3\")");
	_tmp22_ = self->test_collection;
	_tmp23_ = gee_collection_add_all (_tmp22_, (GeeCollection*) dummy);
	_vala_assert (_tmp23_, "test_collection.add_all (dummy)");
	_tmp24_ = self->test_collection;
	_tmp25_ = gee_collection_get_size (_tmp24_);
	_tmp26_ = _tmp25_;
	_vala_assert (_tmp26_ == 3, "test_collection.size == 3");
	_tmp27_ = self->test_collection;
	_tmp28_ = gee_collection_contains (_tmp27_, "hello1");
	_vala_assert (_tmp28_, "test_collection.contains (\"hello1\")");
	_tmp29_ = self->test_collection;
	_tmp30_ = gee_collection_contains (_tmp29_, "hello2");
	_vala_assert (_tmp30_, "test_collection.contains (\"hello2\")");
	_tmp31_ = self->test_collection;
	_tmp32_ = gee_collection_contains (_tmp31_, "hello3");
	_vala_assert (_tmp32_, "test_collection.contains (\"hello3\")");
	_tmp33_ = gee_abstract_collection_get_size ((GeeCollection*) dummy);
	_tmp34_ = _tmp33_;
	_vala_assert (_tmp34_ == 3, "dummy.size == 3");
	_tmp35_ = gee_abstract_collection_contains ((GeeAbstractCollection*) dummy, "hello1");
	_vala_assert (_tmp35_, "dummy.contains (\"hello1\")");
	_tmp36_ = gee_abstract_collection_contains ((GeeAbstractCollection*) dummy, "hello2");
	_vala_assert (_tmp36_, "dummy.contains (\"hello2\")");
	_tmp37_ = gee_abstract_collection_contains ((GeeAbstractCollection*) dummy, "hello3");
	_vala_assert (_tmp37_, "dummy.contains (\"hello3\")");
	_tmp38_ = self->test_collection;
	gee_collection_clear (_tmp38_);
	gee_abstract_collection_clear ((GeeAbstractCollection*) dummy);
	_tmp39_ = gee_abstract_collection_add ((GeeAbstractCollection*) dummy, "hello1");
	_vala_assert (_tmp39_, "dummy.add (\"hello1\")");
	_tmp40_ = gee_abstract_collection_add ((GeeAbstractCollection*) dummy, "hello2");
	_vala_assert (_tmp40_, "dummy.add (\"hello2\")");
	_tmp41_ = gee_abstract_collection_add ((GeeAbstractCollection*) dummy, "hello3");
	_vala_assert (_tmp41_, "dummy.add (\"hello3\")");
	_tmp42_ = self->test_collection;
	_tmp43_ = gee_collection_add (_tmp42_, "hello");
	_vala_assert (_tmp43_, "test_collection.add (\"hello\")");
	_tmp44_ = self->test_collection;
	_tmp45_ = gee_collection_add_all (_tmp44_, (GeeCollection*) dummy);
	_vala_assert (_tmp45_, "test_collection.add_all (dummy)");
	_tmp46_ = self->test_collection;
	_tmp47_ = gee_collection_get_size (_tmp46_);
	_tmp48_ = _tmp47_;
	_vala_assert (_tmp48_ == 4, "test_collection.size == 4");
	_tmp49_ = self->test_collection;
	_tmp50_ = gee_collection_contains (_tmp49_, "hello");
	_vala_assert (_tmp50_, "test_collection.contains (\"hello\")");
	_tmp51_ = self->test_collection;
	_tmp52_ = gee_collection_contains (_tmp51_, "hello1");
	_vala_assert (_tmp52_, "test_collection.contains (\"hello1\")");
	_tmp53_ = self->test_collection;
	_tmp54_ = gee_collection_contains (_tmp53_, "hello2");
	_vala_assert (_tmp54_, "test_collection.contains (\"hello2\")");
	_tmp55_ = self->test_collection;
	_tmp56_ = gee_collection_contains (_tmp55_, "hello3");
	_vala_assert (_tmp56_, "test_collection.contains (\"hello3\")");
	_tmp57_ = gee_abstract_collection_get_size ((GeeCollection*) dummy);
	_tmp58_ = _tmp57_;
	_vala_assert (_tmp58_ == 3, "dummy.size == 3");
	_tmp59_ = gee_abstract_collection_contains ((GeeAbstractCollection*) dummy, "hello1");
	_vala_assert (_tmp59_, "dummy.contains (\"hello1\")");
	_tmp60_ = gee_abstract_collection_contains ((GeeAbstractCollection*) dummy, "hello2");
	_vala_assert (_tmp60_, "dummy.contains (\"hello2\")");
	_tmp61_ = gee_abstract_collection_contains ((GeeAbstractCollection*) dummy, "hello3");
	_vala_assert (_tmp61_, "dummy.contains (\"hello3\")");
	_tmp62_ = self->test_collection;
	gee_collection_clear (_tmp62_);
	gee_abstract_collection_clear ((GeeAbstractCollection*) dummy);
	_tmp63_ = gee_abstract_collection_add ((GeeAbstractCollection*) dummy, "hello1");
	_vala_assert (_tmp63_, "dummy.add (\"hello1\")");
	_tmp64_ = gee_abstract_collection_add ((GeeAbstractCollection*) dummy, "hello2");
	_vala_assert (_tmp64_, "dummy.add (\"hello2\")");
	_tmp65_ = gee_abstract_collection_add ((GeeAbstractCollection*) dummy, "hello3");
	_vala_assert (_tmp65_, "dummy.add (\"hello3\")");
	_tmp66_ = self->test_collection;
	_tmp67_ = gee_collection_add (_tmp66_, "hello1");
	_vala_assert (_tmp67_, "test_collection.add (\"hello1\")");
	_tmp68_ = self->test_collection;
	_tmp69_ = gee_collection_add_all (_tmp68_, (GeeCollection*) dummy);
	_vala_assert (_tmp69_, "test_collection.add_all (dummy)");
	_tmp70_ = self->test_collection;
	_tmp71_ = gee_collection_get_size (_tmp70_);
	_tmp72_ = _tmp71_;
	_vala_assert (_tmp72_ >= 3, "test_collection.size >= 3");
	_tmp73_ = self->test_collection;
	_tmp74_ = gee_collection_contains (_tmp73_, "hello1");
	_vala_assert (_tmp74_, "test_collection.contains (\"hello1\")");
	_tmp75_ = self->test_collection;
	_tmp76_ = gee_collection_contains (_tmp75_, "hello2");
	_vala_assert (_tmp76_, "test_collection.contains (\"hello2\")");
	_tmp77_ = self->test_collection;
	_tmp78_ = gee_collection_contains (_tmp77_, "hello3");
	_vala_assert (_tmp78_, "test_collection.contains (\"hello3\")");
	_tmp79_ = gee_abstract_collection_get_size ((GeeCollection*) dummy);
	_tmp80_ = _tmp79_;
	_vala_assert (_tmp80_ == 3, "dummy.size == 3");
	_tmp81_ = gee_abstract_collection_contains ((GeeAbstractCollection*) dummy, "hello1");
	_vala_assert (_tmp81_, "dummy.contains (\"hello1\")");
	_tmp82_ = gee_abstract_collection_contains ((GeeAbstractCollection*) dummy, "hello2");
	_vala_assert (_tmp82_, "dummy.contains (\"hello2\")");
	_tmp83_ = gee_abstract_collection_contains ((GeeAbstractCollection*) dummy, "hello3");
	_vala_assert (_tmp83_, "dummy.contains (\"hello3\")");
	_g_object_unref0 (dummy);
}


void collection_tests_test_contains_all (CollectionTests* self) {
	GeeCollection* _tmp0_ = NULL;
	GeeArrayList* dummy = NULL;
	GeeArrayList* _tmp1_ = NULL;
	gboolean _tmp2_ = FALSE;
	gboolean _tmp3_ = FALSE;
	gboolean _tmp4_ = FALSE;
	GeeCollection* _tmp5_ = NULL;
	gboolean _tmp6_ = FALSE;
	gboolean _tmp7_ = FALSE;
	GeeCollection* _tmp8_ = NULL;
	gboolean _tmp9_ = FALSE;
	GeeCollection* _tmp10_ = NULL;
	gboolean _tmp11_ = FALSE;
	GeeCollection* _tmp12_ = NULL;
	gboolean _tmp13_ = FALSE;
	GeeCollection* _tmp14_ = NULL;
	gboolean _tmp15_ = FALSE;
	GeeCollection* _tmp16_ = NULL;
	gboolean _tmp17_ = FALSE;
	GeeCollection* _tmp18_ = NULL;
	gboolean _tmp19_ = FALSE;
	GeeCollection* _tmp20_ = NULL;
	gboolean _tmp21_ = FALSE;
	GeeCollection* _tmp22_ = NULL;
	gboolean _tmp23_ = FALSE;
	GeeCollection* _tmp24_ = NULL;
	gboolean _tmp25_ = FALSE;
	GeeCollection* _tmp26_ = NULL;
	gboolean _tmp27_ = FALSE;
	g_return_if_fail (self != NULL);
	_tmp0_ = self->test_collection;
	_vala_assert (_tmp0_ != NULL, "test_collection != null");
	_tmp1_ = gee_array_list_new (G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, g_free, NULL, NULL, NULL);
	dummy = _tmp1_;
	_tmp2_ = gee_abstract_collection_add ((GeeAbstractCollection*) dummy, "hello1");
	_vala_assert (_tmp2_, "dummy.add (\"hello1\")");
	_tmp3_ = gee_abstract_collection_add ((GeeAbstractCollection*) dummy, "hello2");
	_vala_assert (_tmp3_, "dummy.add (\"hello2\")");
	_tmp4_ = gee_abstract_collection_add ((GeeAbstractCollection*) dummy, "hello3");
	_vala_assert (_tmp4_, "dummy.add (\"hello3\")");
	_tmp5_ = self->test_collection;
	_tmp6_ = gee_collection_get_is_empty (_tmp5_);
	_tmp7_ = _tmp6_;
	_vala_assert (_tmp7_, "test_collection.is_empty");
	_tmp8_ = self->test_collection;
	_tmp9_ = gee_collection_contains_all (_tmp8_, (GeeCollection*) dummy);
	_vala_assert (!_tmp9_, "! test_collection.contains_all (dummy)");
	_tmp10_ = self->test_collection;
	_tmp11_ = gee_collection_add (_tmp10_, "hello4");
	_vala_assert (_tmp11_, "test_collection.add (\"hello4\")");
	_tmp12_ = self->test_collection;
	_tmp13_ = gee_collection_add (_tmp12_, "hello5");
	_vala_assert (_tmp13_, "test_collection.add (\"hello5\")");
	_tmp14_ = self->test_collection;
	_tmp15_ = gee_collection_contains_all (_tmp14_, (GeeCollection*) dummy);
	_vala_assert (!_tmp15_, "! test_collection.contains_all (dummy)");
	_tmp16_ = self->test_collection;
	_tmp17_ = gee_collection_add (_tmp16_, "hello1");
	_vala_assert (_tmp17_, "test_collection.add (\"hello1\")");
	_tmp18_ = self->test_collection;
	_tmp19_ = gee_collection_add (_tmp18_, "hello2");
	_vala_assert (_tmp19_, "test_collection.add (\"hello2\")");
	_tmp20_ = self->test_collection;
	_tmp21_ = gee_collection_contains_all (_tmp20_, (GeeCollection*) dummy);
	_vala_assert (!_tmp21_, "! test_collection.contains_all (dummy)");
	_tmp22_ = self->test_collection;
	_tmp23_ = gee_collection_add (_tmp22_, "hello3");
	_vala_assert (_tmp23_, "test_collection.add (\"hello3\")");
	_tmp24_ = self->test_collection;
	_tmp25_ = gee_collection_contains_all (_tmp24_, (GeeCollection*) dummy);
	_vala_assert (_tmp25_, "test_collection.contains_all (dummy)");
	_tmp26_ = self->test_collection;
	_tmp27_ = gee_collection_contains_all ((GeeCollection*) dummy, _tmp26_);
	_vala_assert (!_tmp27_, "! dummy.contains_all (test_collection)");
	_g_object_unref0 (dummy);
}


void collection_tests_test_remove_all (CollectionTests* self) {
	GeeCollection* _tmp0_ = NULL;
	GeeArrayList* dummy = NULL;
	GeeArrayList* _tmp1_ = NULL;
	GeeCollection* _tmp2_ = NULL;
	gboolean _tmp3_ = FALSE;
	GeeCollection* _tmp4_ = NULL;
	gboolean _tmp5_ = FALSE;
	gboolean _tmp6_ = FALSE;
	gboolean _tmp7_ = FALSE;
	gboolean _tmp8_ = FALSE;
	gboolean _tmp9_ = FALSE;
	gboolean _tmp10_ = FALSE;
	gboolean _tmp11_ = FALSE;
	GeeCollection* _tmp12_ = NULL;
	gboolean _tmp13_ = FALSE;
	GeeCollection* _tmp14_ = NULL;
	gboolean _tmp15_ = FALSE;
	gboolean _tmp16_ = FALSE;
	GeeCollection* _tmp17_ = NULL;
	gboolean _tmp18_ = FALSE;
	gboolean _tmp19_ = FALSE;
	gboolean _tmp20_ = FALSE;
	GeeCollection* _tmp21_ = NULL;
	gboolean _tmp22_ = FALSE;
	GeeCollection* _tmp23_ = NULL;
	gboolean _tmp24_ = FALSE;
	GeeCollection* _tmp25_ = NULL;
	gboolean _tmp26_ = FALSE;
	GeeCollection* _tmp27_ = NULL;
	gint _tmp28_ = 0;
	gint _tmp29_ = 0;
	gint _tmp30_ = 0;
	gint _tmp31_ = 0;
	GeeCollection* _tmp32_ = NULL;
	gboolean _tmp33_ = FALSE;
	gboolean _tmp34_ = FALSE;
	gboolean _tmp35_ = FALSE;
	GeeCollection* _tmp36_ = NULL;
	gboolean _tmp37_ = FALSE;
	GeeCollection* _tmp38_ = NULL;
	gboolean _tmp39_ = FALSE;
	GeeCollection* _tmp40_ = NULL;
	gboolean _tmp41_ = FALSE;
	GeeCollection* _tmp42_ = NULL;
	gboolean _tmp43_ = FALSE;
	GeeCollection* _tmp44_ = NULL;
	gboolean _tmp45_ = FALSE;
	gboolean _tmp46_ = FALSE;
	gint _tmp47_ = 0;
	gint _tmp48_ = 0;
	GeeCollection* _tmp49_ = NULL;
	g_return_if_fail (self != NULL);
	_tmp0_ = self->test_collection;
	_vala_assert (_tmp0_ != NULL, "test_collection != null");
	_tmp1_ = gee_array_list_new (G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, g_free, NULL, NULL, NULL);
	dummy = _tmp1_;
	_tmp2_ = self->test_collection;
	_tmp3_ = gee_collection_remove_all (_tmp2_, (GeeCollection*) dummy);
	_vala_assert (!_tmp3_, "! test_collection.remove_all (dummy)");
	_tmp4_ = self->test_collection;
	_tmp5_ = gee_collection_get_is_empty (_tmp4_);
	_tmp6_ = _tmp5_;
	_vala_assert (_tmp6_, "test_collection.is_empty");
	_tmp7_ = gee_collection_get_is_empty ((GeeCollection*) dummy);
	_tmp8_ = _tmp7_;
	_vala_assert (_tmp8_, "dummy.is_empty");
	_tmp9_ = gee_abstract_collection_add ((GeeAbstractCollection*) dummy, "hello1");
	_vala_assert (_tmp9_, "dummy.add (\"hello1\")");
	_tmp10_ = gee_abstract_collection_add ((GeeAbstractCollection*) dummy, "hello2");
	_vala_assert (_tmp10_, "dummy.add (\"hello2\")");
	_tmp11_ = gee_abstract_collection_add ((GeeAbstractCollection*) dummy, "hello3");
	_vala_assert (_tmp11_, "dummy.add (\"hello3\")");
	_tmp12_ = self->test_collection;
	_tmp13_ = gee_collection_remove_all (_tmp12_, (GeeCollection*) dummy);
	_vala_assert (!_tmp13_, "! test_collection.remove_all (dummy)");
	_tmp14_ = self->test_collection;
	_tmp15_ = gee_collection_get_is_empty (_tmp14_);
	_tmp16_ = _tmp15_;
	_vala_assert (_tmp16_, "test_collection.is_empty");
	_tmp17_ = self->test_collection;
	gee_collection_clear (_tmp17_);
	gee_abstract_collection_clear ((GeeAbstractCollection*) dummy);
	_tmp18_ = gee_abstract_collection_add ((GeeAbstractCollection*) dummy, "hello1");
	_vala_assert (_tmp18_, "dummy.add (\"hello1\")");
	_tmp19_ = gee_abstract_collection_add ((GeeAbstractCollection*) dummy, "hello2");
	_vala_assert (_tmp19_, "dummy.add (\"hello2\")");
	_tmp20_ = gee_abstract_collection_add ((GeeAbstractCollection*) dummy, "hello3");
	_vala_assert (_tmp20_, "dummy.add (\"hello3\")");
	_tmp21_ = self->test_collection;
	_tmp22_ = gee_collection_add (_tmp21_, "hello4");
	_vala_assert (_tmp22_, "test_collection.add (\"hello4\")");
	_tmp23_ = self->test_collection;
	_tmp24_ = gee_collection_add (_tmp23_, "hello5");
	_vala_assert (_tmp24_, "test_collection.add (\"hello5\")");
	_tmp25_ = self->test_collection;
	_tmp26_ = gee_collection_remove_all (_tmp25_, (GeeCollection*) dummy);
	_vala_assert (!_tmp26_, "! test_collection.remove_all (dummy)");
	_tmp27_ = self->test_collection;
	_tmp28_ = gee_collection_get_size (_tmp27_);
	_tmp29_ = _tmp28_;
	_vala_assert (_tmp29_ == 2, "test_collection.size == 2");
	_tmp30_ = gee_abstract_collection_get_size ((GeeCollection*) dummy);
	_tmp31_ = _tmp30_;
	_vala_assert (_tmp31_ == 3, "dummy.size == 3");
	_tmp32_ = self->test_collection;
	gee_collection_clear (_tmp32_);
	gee_abstract_collection_clear ((GeeAbstractCollection*) dummy);
	_tmp33_ = gee_abstract_collection_add ((GeeAbstractCollection*) dummy, "hello1");
	_vala_assert (_tmp33_, "dummy.add (\"hello1\")");
	_tmp34_ = gee_abstract_collection_add ((GeeAbstractCollection*) dummy, "hello2");
	_vala_assert (_tmp34_, "dummy.add (\"hello2\")");
	_tmp35_ = gee_abstract_collection_add ((GeeAbstractCollection*) dummy, "hello3");
	_vala_assert (_tmp35_, "dummy.add (\"hello3\")");
	_tmp36_ = self->test_collection;
	_tmp37_ = gee_collection_add (_tmp36_, "hello1");
	_vala_assert (_tmp37_, "test_collection.add (\"hello1\")");
	_tmp38_ = self->test_collection;
	_tmp39_ = gee_collection_add (_tmp38_, "hello2");
	_vala_assert (_tmp39_, "test_collection.add (\"hello2\")");
	_tmp40_ = self->test_collection;
	_tmp41_ = gee_collection_add (_tmp40_, "hello3");
	_vala_assert (_tmp41_, "test_collection.add (\"hello3\")");
	_tmp42_ = self->test_collection;
	_tmp43_ = gee_collection_remove_all (_tmp42_, (GeeCollection*) dummy);
	_vala_assert (_tmp43_, "test_collection.remove_all (dummy)");
	_tmp44_ = self->test_collection;
	_tmp45_ = gee_collection_get_is_empty (_tmp44_);
	_tmp46_ = _tmp45_;
	_vala_assert (_tmp46_, "test_collection.is_empty");
	_tmp47_ = gee_abstract_collection_get_size ((GeeCollection*) dummy);
	_tmp48_ = _tmp47_;
	_vala_assert (_tmp48_ == 3, "dummy.size == 3");
	_tmp49_ = self->test_collection;
	gee_collection_clear (_tmp49_);
	gee_abstract_collection_clear ((GeeAbstractCollection*) dummy);
	_g_object_unref0 (dummy);
}


void collection_tests_test_retain_all (CollectionTests* self) {
	GeeCollection* _tmp0_ = NULL;
	GeeArrayList* dummy = NULL;
	GeeArrayList* _tmp1_ = NULL;
	GeeCollection* _tmp2_ = NULL;
	gboolean _tmp3_ = FALSE;
	GeeCollection* _tmp4_ = NULL;
	gboolean _tmp5_ = FALSE;
	gboolean _tmp6_ = FALSE;
	gboolean _tmp7_ = FALSE;
	gboolean _tmp8_ = FALSE;
	GeeCollection* _tmp9_ = NULL;
	gboolean _tmp10_ = FALSE;
	GeeCollection* _tmp11_ = NULL;
	gboolean _tmp12_ = FALSE;
	GeeCollection* _tmp13_ = NULL;
	gboolean _tmp14_ = FALSE;
	GeeCollection* _tmp15_ = NULL;
	gboolean _tmp16_ = FALSE;
	gboolean _tmp17_ = FALSE;
	gboolean _tmp18_ = FALSE;
	gboolean _tmp19_ = FALSE;
	GeeCollection* _tmp20_ = NULL;
	gboolean _tmp21_ = FALSE;
	gboolean _tmp22_ = FALSE;
	gboolean _tmp23_ = FALSE;
	GeeCollection* _tmp24_ = NULL;
	gboolean _tmp25_ = FALSE;
	GeeCollection* _tmp26_ = NULL;
	gboolean _tmp27_ = FALSE;
	gboolean _tmp28_ = FALSE;
	gint _tmp29_ = 0;
	gint _tmp30_ = 0;
	gboolean _tmp31_ = FALSE;
	gboolean _tmp32_ = FALSE;
	gboolean _tmp33_ = FALSE;
	GeeCollection* _tmp34_ = NULL;
	gboolean _tmp35_ = FALSE;
	gboolean _tmp36_ = FALSE;
	gboolean _tmp37_ = FALSE;
	GeeCollection* _tmp38_ = NULL;
	gboolean _tmp39_ = FALSE;
	GeeCollection* _tmp40_ = NULL;
	gboolean _tmp41_ = FALSE;
	GeeCollection* _tmp42_ = NULL;
	gboolean _tmp43_ = FALSE;
	GeeCollection* _tmp44_ = NULL;
	gboolean _tmp45_ = FALSE;
	gboolean _tmp46_ = FALSE;
	gint _tmp47_ = 0;
	gint _tmp48_ = 0;
	gboolean _tmp49_ = FALSE;
	gboolean _tmp50_ = FALSE;
	gboolean _tmp51_ = FALSE;
	GeeCollection* _tmp52_ = NULL;
	gboolean _tmp53_ = FALSE;
	gboolean _tmp54_ = FALSE;
	gboolean _tmp55_ = FALSE;
	GeeCollection* _tmp56_ = NULL;
	gboolean _tmp57_ = FALSE;
	GeeCollection* _tmp58_ = NULL;
	gboolean _tmp59_ = FALSE;
	GeeCollection* _tmp60_ = NULL;
	gboolean _tmp61_ = FALSE;
	GeeCollection* _tmp62_ = NULL;
	gboolean _tmp63_ = FALSE;
	GeeCollection* _tmp64_ = NULL;
	gint _tmp65_ = 0;
	gint _tmp66_ = 0;
	GeeCollection* _tmp67_ = NULL;
	gboolean _tmp68_ = FALSE;
	GeeCollection* _tmp69_ = NULL;
	gboolean _tmp70_ = FALSE;
	GeeCollection* _tmp71_ = NULL;
	gboolean _tmp72_ = FALSE;
	gint _tmp73_ = 0;
	gint _tmp74_ = 0;
	gboolean _tmp75_ = FALSE;
	gboolean _tmp76_ = FALSE;
	gboolean _tmp77_ = FALSE;
	GeeCollection* _tmp78_ = NULL;
	gboolean _tmp79_ = FALSE;
	gboolean _tmp80_ = FALSE;
	gboolean _tmp81_ = FALSE;
	GeeCollection* _tmp82_ = NULL;
	gboolean _tmp83_ = FALSE;
	GeeCollection* _tmp84_ = NULL;
	gboolean _tmp85_ = FALSE;
	GeeCollection* _tmp86_ = NULL;
	gboolean _tmp87_ = FALSE;
	GeeCollection* _tmp88_ = NULL;
	gboolean _tmp89_ = FALSE;
	GeeCollection* _tmp90_ = NULL;
	gint _tmp91_ = 0;
	gint _tmp92_ = 0;
	GeeCollection* _tmp93_ = NULL;
	gboolean _tmp94_ = FALSE;
	GeeCollection* _tmp95_ = NULL;
	gboolean _tmp96_ = FALSE;
	gint _tmp97_ = 0;
	gint _tmp98_ = 0;
	gboolean _tmp99_ = FALSE;
	gboolean _tmp100_ = FALSE;
	gboolean _tmp101_ = FALSE;
	GeeCollection* _tmp102_ = NULL;
	g_return_if_fail (self != NULL);
	_tmp0_ = self->test_collection;
	_vala_assert (_tmp0_ != NULL, "test_collection != null");
	_tmp1_ = gee_array_list_new (G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, g_free, NULL, NULL, NULL);
	dummy = _tmp1_;
	_tmp2_ = self->test_collection;
	_tmp3_ = gee_collection_retain_all (_tmp2_, (GeeCollection*) dummy);
	_vala_assert (!_tmp3_, "! test_collection.retain_all (dummy)");
	_tmp4_ = self->test_collection;
	_tmp5_ = gee_collection_get_is_empty (_tmp4_);
	_tmp6_ = _tmp5_;
	_vala_assert (_tmp6_, "test_collection.is_empty");
	_tmp7_ = gee_collection_get_is_empty ((GeeCollection*) dummy);
	_tmp8_ = _tmp7_;
	_vala_assert (_tmp8_, "dummy.is_empty");
	_tmp9_ = self->test_collection;
	_tmp10_ = gee_collection_add (_tmp9_, "hello1");
	_vala_assert (_tmp10_, "test_collection.add (\"hello1\")");
	_tmp11_ = self->test_collection;
	_tmp12_ = gee_collection_add (_tmp11_, "hello2");
	_vala_assert (_tmp12_, "test_collection.add (\"hello2\")");
	_tmp13_ = self->test_collection;
	_tmp14_ = gee_collection_retain_all (_tmp13_, (GeeCollection*) dummy);
	_vala_assert (_tmp14_, "test_collection.retain_all (dummy)");
	_tmp15_ = self->test_collection;
	_tmp16_ = gee_collection_get_is_empty (_tmp15_);
	_tmp17_ = _tmp16_;
	_vala_assert (_tmp17_, "test_collection.is_empty");
	_tmp18_ = gee_collection_get_is_empty ((GeeCollection*) dummy);
	_tmp19_ = _tmp18_;
	_vala_assert (_tmp19_, "dummy.is_empty");
	_tmp20_ = self->test_collection;
	gee_collection_clear (_tmp20_);
	gee_abstract_collection_clear ((GeeAbstractCollection*) dummy);
	_tmp21_ = gee_abstract_collection_add ((GeeAbstractCollection*) dummy, "hello1");
	_vala_assert (_tmp21_, "dummy.add (\"hello1\")");
	_tmp22_ = gee_abstract_collection_add ((GeeAbstractCollection*) dummy, "hello2");
	_vala_assert (_tmp22_, "dummy.add (\"hello2\")");
	_tmp23_ = gee_abstract_collection_add ((GeeAbstractCollection*) dummy, "hello3");
	_vala_assert (_tmp23_, "dummy.add (\"hello3\")");
	_tmp24_ = self->test_collection;
	_tmp25_ = gee_collection_retain_all (_tmp24_, (GeeCollection*) dummy);
	_vala_assert (!_tmp25_, "! test_collection.retain_all (dummy)");
	_tmp26_ = self->test_collection;
	_tmp27_ = gee_collection_get_is_empty (_tmp26_);
	_tmp28_ = _tmp27_;
	_vala_assert (_tmp28_, "test_collection.is_empty");
	_tmp29_ = gee_abstract_collection_get_size ((GeeCollection*) dummy);
	_tmp30_ = _tmp29_;
	_vala_assert (_tmp30_ == 3, "dummy.size == 3");
	_tmp31_ = gee_abstract_collection_contains ((GeeAbstractCollection*) dummy, "hello1");
	_vala_assert (_tmp31_, "dummy.contains (\"hello1\")");
	_tmp32_ = gee_abstract_collection_contains ((GeeAbstractCollection*) dummy, "hello2");
	_vala_assert (_tmp32_, "dummy.contains (\"hello2\")");
	_tmp33_ = gee_abstract_collection_contains ((GeeAbstractCollection*) dummy, "hello3");
	_vala_assert (_tmp33_, "dummy.contains (\"hello3\")");
	_tmp34_ = self->test_collection;
	gee_collection_clear (_tmp34_);
	gee_abstract_collection_clear ((GeeAbstractCollection*) dummy);
	_tmp35_ = gee_abstract_collection_add ((GeeAbstractCollection*) dummy, "hello1");
	_vala_assert (_tmp35_, "dummy.add (\"hello1\")");
	_tmp36_ = gee_abstract_collection_add ((GeeAbstractCollection*) dummy, "hello2");
	_vala_assert (_tmp36_, "dummy.add (\"hello2\")");
	_tmp37_ = gee_abstract_collection_add ((GeeAbstractCollection*) dummy, "hello3");
	_vala_assert (_tmp37_, "dummy.add (\"hello3\")");
	_tmp38_ = self->test_collection;
	_tmp39_ = gee_collection_add (_tmp38_, "hello4");
	_vala_assert (_tmp39_, "test_collection.add (\"hello4\")");
	_tmp40_ = self->test_collection;
	_tmp41_ = gee_collection_add (_tmp40_, "hello5");
	_vala_assert (_tmp41_, "test_collection.add (\"hello5\")");
	_tmp42_ = self->test_collection;
	_tmp43_ = gee_collection_retain_all (_tmp42_, (GeeCollection*) dummy);
	_vala_assert (_tmp43_, "test_collection.retain_all (dummy)");
	_tmp44_ = self->test_collection;
	_tmp45_ = gee_collection_get_is_empty (_tmp44_);
	_tmp46_ = _tmp45_;
	_vala_assert (_tmp46_, "test_collection.is_empty");
	_tmp47_ = gee_abstract_collection_get_size ((GeeCollection*) dummy);
	_tmp48_ = _tmp47_;
	_vala_assert (_tmp48_ == 3, "dummy.size == 3");
	_tmp49_ = gee_abstract_collection_contains ((GeeAbstractCollection*) dummy, "hello1");
	_vala_assert (_tmp49_, "dummy.contains (\"hello1\")");
	_tmp50_ = gee_abstract_collection_contains ((GeeAbstractCollection*) dummy, "hello2");
	_vala_assert (_tmp50_, "dummy.contains (\"hello2\")");
	_tmp51_ = gee_abstract_collection_contains ((GeeAbstractCollection*) dummy, "hello3");
	_vala_assert (_tmp51_, "dummy.contains (\"hello3\")");
	_tmp52_ = self->test_collection;
	gee_collection_clear (_tmp52_);
	gee_abstract_collection_clear ((GeeAbstractCollection*) dummy);
	_tmp53_ = gee_abstract_collection_add ((GeeAbstractCollection*) dummy, "hello1");
	_vala_assert (_tmp53_, "dummy.add (\"hello1\")");
	_tmp54_ = gee_abstract_collection_add ((GeeAbstractCollection*) dummy, "hello2");
	_vala_assert (_tmp54_, "dummy.add (\"hello2\")");
	_tmp55_ = gee_abstract_collection_add ((GeeAbstractCollection*) dummy, "hello3");
	_vala_assert (_tmp55_, "dummy.add (\"hello3\")");
	_tmp56_ = self->test_collection;
	_tmp57_ = gee_collection_add (_tmp56_, "hello1");
	_vala_assert (_tmp57_, "test_collection.add (\"hello1\")");
	_tmp58_ = self->test_collection;
	_tmp59_ = gee_collection_add (_tmp58_, "hello2");
	_vala_assert (_tmp59_, "test_collection.add (\"hello2\")");
	_tmp60_ = self->test_collection;
	_tmp61_ = gee_collection_add (_tmp60_, "hello3");
	_vala_assert (_tmp61_, "test_collection.add (\"hello3\")");
	_tmp62_ = self->test_collection;
	_tmp63_ = gee_collection_retain_all (_tmp62_, (GeeCollection*) dummy);
	_vala_assert (!_tmp63_, "! test_collection.retain_all (dummy)");
	_tmp64_ = self->test_collection;
	_tmp65_ = gee_collection_get_size (_tmp64_);
	_tmp66_ = _tmp65_;
	_vala_assert (_tmp66_ == 3, "test_collection.size == 3");
	_tmp67_ = self->test_collection;
	_tmp68_ = gee_collection_contains (_tmp67_, "hello1");
	_vala_assert (_tmp68_, "test_collection.contains (\"hello1\")");
	_tmp69_ = self->test_collection;
	_tmp70_ = gee_collection_contains (_tmp69_, "hello2");
	_vala_assert (_tmp70_, "test_collection.contains (\"hello2\")");
	_tmp71_ = self->test_collection;
	_tmp72_ = gee_collection_contains (_tmp71_, "hello3");
	_vala_assert (_tmp72_, "test_collection.contains (\"hello3\")");
	_tmp73_ = gee_abstract_collection_get_size ((GeeCollection*) dummy);
	_tmp74_ = _tmp73_;
	_vala_assert (_tmp74_ == 3, "dummy.size == 3");
	_tmp75_ = gee_abstract_collection_contains ((GeeAbstractCollection*) dummy, "hello1");
	_vala_assert (_tmp75_, "dummy.contains (\"hello1\")");
	_tmp76_ = gee_abstract_collection_contains ((GeeAbstractCollection*) dummy, "hello2");
	_vala_assert (_tmp76_, "dummy.contains (\"hello2\")");
	_tmp77_ = gee_abstract_collection_contains ((GeeAbstractCollection*) dummy, "hello3");
	_vala_assert (_tmp77_, "dummy.contains (\"hello3\")");
	_tmp78_ = self->test_collection;
	gee_collection_clear (_tmp78_);
	gee_abstract_collection_clear ((GeeAbstractCollection*) dummy);
	_tmp79_ = gee_abstract_collection_add ((GeeAbstractCollection*) dummy, "hello1");
	_vala_assert (_tmp79_, "dummy.add (\"hello1\")");
	_tmp80_ = gee_abstract_collection_add ((GeeAbstractCollection*) dummy, "hello2");
	_vala_assert (_tmp80_, "dummy.add (\"hello2\")");
	_tmp81_ = gee_abstract_collection_add ((GeeAbstractCollection*) dummy, "hello3");
	_vala_assert (_tmp81_, "dummy.add (\"hello3\")");
	_tmp82_ = self->test_collection;
	_tmp83_ = gee_collection_add (_tmp82_, "hello2");
	_vala_assert (_tmp83_, "test_collection.add (\"hello2\")");
	_tmp84_ = self->test_collection;
	_tmp85_ = gee_collection_add (_tmp84_, "hello3");
	_vala_assert (_tmp85_, "test_collection.add (\"hello3\")");
	_tmp86_ = self->test_collection;
	_tmp87_ = gee_collection_add (_tmp86_, "hello4");
	_vala_assert (_tmp87_, "test_collection.add (\"hello4\")");
	_tmp88_ = self->test_collection;
	_tmp89_ = gee_collection_retain_all (_tmp88_, (GeeCollection*) dummy);
	_vala_assert (_tmp89_, "test_collection.retain_all (dummy)");
	_tmp90_ = self->test_collection;
	_tmp91_ = gee_collection_get_size (_tmp90_);
	_tmp92_ = _tmp91_;
	_vala_assert (_tmp92_ == 2, "test_collection.size == 2");
	_tmp93_ = self->test_collection;
	_tmp94_ = gee_collection_contains (_tmp93_, "hello2");
	_vala_assert (_tmp94_, "test_collection.contains (\"hello2\")");
	_tmp95_ = self->test_collection;
	_tmp96_ = gee_collection_contains (_tmp95_, "hello3");
	_vala_assert (_tmp96_, "test_collection.contains (\"hello3\")");
	_tmp97_ = gee_abstract_collection_get_size ((GeeCollection*) dummy);
	_tmp98_ = _tmp97_;
	_vala_assert (_tmp98_ == 3, "dummy.size == 3");
	_tmp99_ = gee_abstract_collection_contains ((GeeAbstractCollection*) dummy, "hello1");
	_vala_assert (_tmp99_, "dummy.contains (\"hello1\")");
	_tmp100_ = gee_abstract_collection_contains ((GeeAbstractCollection*) dummy, "hello2");
	_vala_assert (_tmp100_, "dummy.contains (\"hello2\")");
	_tmp101_ = gee_abstract_collection_contains ((GeeAbstractCollection*) dummy, "hello3");
	_vala_assert (_tmp101_, "dummy.contains (\"hello3\")");
	_tmp102_ = self->test_collection;
	gee_collection_clear (_tmp102_);
	gee_abstract_collection_clear ((GeeAbstractCollection*) dummy);
	_g_object_unref0 (dummy);
}


void collection_tests_test_to_array (CollectionTests* self) {
	GeeCollection* _tmp0_ = NULL;
	GeeCollection* _tmp1_ = NULL;
	gboolean _tmp2_ = FALSE;
	gboolean _tmp3_ = FALSE;
	GeeCollection* _tmp4_ = NULL;
	gboolean _tmp5_ = FALSE;
	GeeCollection* _tmp6_ = NULL;
	gboolean _tmp7_ = FALSE;
	GeeCollection* _tmp8_ = NULL;
	gboolean _tmp9_ = FALSE;
	gchar** array = NULL;
	GeeCollection* _tmp10_ = NULL;
	gint _tmp11_ = 0;
	gpointer* _tmp12_ = NULL;
	gint array_length1 = 0;
	gint _array_size_ = 0;
	gint index = 0;
	g_return_if_fail (self != NULL);
	_tmp0_ = self->test_collection;
	_vala_assert (_tmp0_ != NULL, "test_collection != null");
	_tmp1_ = self->test_collection;
	_tmp2_ = gee_collection_get_is_empty (_tmp1_);
	_tmp3_ = _tmp2_;
	_vala_assert (_tmp3_, "test_collection.is_empty");
	_tmp4_ = self->test_collection;
	_tmp5_ = gee_collection_add (_tmp4_, "hello1");
	_vala_assert (_tmp5_, "test_collection.add (\"hello1\")");
	_tmp6_ = self->test_collection;
	_tmp7_ = gee_collection_add (_tmp6_, "hello2");
	_vala_assert (_tmp7_, "test_collection.add (\"hello2\")");
	_tmp8_ = self->test_collection;
	_tmp9_ = gee_collection_add (_tmp8_, "hello3");
	_vala_assert (_tmp9_, "test_collection.add (\"hello3\")");
	_tmp10_ = self->test_collection;
	_tmp12_ = gee_collection_to_array (_tmp10_, &_tmp11_);
	array = (gchar**) _tmp12_;
	array_length1 = (_tmp11_ * sizeof (gchar*)) / sizeof (gchar*);
	_array_size_ = array_length1;
	index = 0;
	{
		GeeIterator* _element_it = NULL;
		GeeCollection* _tmp13_ = NULL;
		GeeIterator* _tmp14_ = NULL;
		_tmp13_ = self->test_collection;
		_tmp14_ = gee_iterable_iterator ((GeeIterable*) _tmp13_);
		_element_it = _tmp14_;
		while (TRUE) {
			GeeIterator* _tmp15_ = NULL;
			gboolean _tmp16_ = FALSE;
			gchar* element = NULL;
			GeeIterator* _tmp17_ = NULL;
			gpointer _tmp18_ = NULL;
			const gchar* _tmp19_ = NULL;
			gchar** _tmp20_ = NULL;
			gint _tmp20__length1 = 0;
			gint _tmp21_ = 0;
			const gchar* _tmp22_ = NULL;
			_tmp15_ = _element_it;
			_tmp16_ = gee_iterator_next (_tmp15_);
			if (!_tmp16_) {
				break;
			}
			_tmp17_ = _element_it;
			_tmp18_ = gee_iterator_get (_tmp17_);
			element = (gchar*) _tmp18_;
			_tmp19_ = element;
			_tmp20_ = array;
			_tmp20__length1 = array_length1;
			_tmp21_ = index;
			index = _tmp21_ + 1;
			_tmp22_ = _tmp20_[_tmp21_];
			_vala_assert (g_strcmp0 (_tmp19_, _tmp22_) == 0, "element == array[index++]");
			_g_free0 (element);
		}
		_g_object_unref0 (_element_it);
	}
	array = (_vala_array_free (array, array_length1, (GDestroyNotify) g_free), NULL);
}


void collection_tests_test_gobject_properties (CollectionTests* self) {
	GeeCollection* _tmp0_ = NULL;
	GValue value = {0};
	GValue _tmp1_ = {0};
	GValue _tmp2_ = {0};
	GeeCollection* _tmp3_ = NULL;
	gint _tmp4_ = 0;
	GeeCollection* _tmp5_ = NULL;
	gint _tmp6_ = 0;
	gint _tmp7_ = 0;
	g_return_if_fail (self != NULL);
	_tmp0_ = self->test_collection;
	_vala_assert (_tmp0_ != NULL, "test_collection != null");
	g_value_init (&_tmp1_, G_TYPE_INT);
	G_IS_VALUE (&value) ? (g_value_unset (&value), NULL) : NULL;
	value = _tmp1_;
	_tmp2_ = value;
	_tmp3_ = self->test_collection;
	g_object_get_property ((GObject*) _tmp3_, "size", &value);
	_tmp4_ = g_value_get_int (&value);
	_tmp5_ = self->test_collection;
	_tmp6_ = gee_collection_get_size (_tmp5_);
	_tmp7_ = _tmp6_;
	_vala_assert (_tmp4_ == _tmp7_, "value.get_int () == test_collection.size");
	g_value_unset (&value);
	G_IS_VALUE (&value) ? (g_value_unset (&value), NULL) : NULL;
}


static Block1Data* block1_data_ref (Block1Data* _data1_) {
	g_atomic_int_inc (&_data1_->_ref_count_);
	return _data1_;
}


static void block1_data_unref (void * _userdata_) {
	Block1Data* _data1_;
	_data1_ = (Block1Data*) _userdata_;
	if (g_atomic_int_dec_and_test (&_data1_->_ref_count_)) {
		CollectionTests* self;
		self = _data1_->self;
		_g_object_unref0 (_data1_->test_iterator);
		_g_object_unref0 (self);
		g_slice_free (Block1Data, _data1_);
	}
}


static gboolean __lambda5_ (CollectionTests* self, gchar* x) {
	gboolean result = FALSE;
	g_return_val_if_fail (x != NULL, FALSE);
	g_assert_not_reached ();
	_g_free0 (x);
	return result;
}


static gboolean ___lambda5__gee_forall_func (gpointer g, gpointer self) {
	gboolean result;
	result = __lambda5_ ((CollectionTests*) self, (gchar*) g);
	return result;
}


static gboolean __lambda6_ (CollectionTests* self, gchar* x) {
	gboolean result = FALSE;
	g_return_val_if_fail (x != NULL, FALSE);
	g_assert_not_reached ();
	_g_free0 (x);
	return result;
}


static gboolean ___lambda6__gee_forall_func (gpointer g, gpointer self) {
	gboolean result;
	result = __lambda6_ ((CollectionTests*) self, (gchar*) g);
	return result;
}


static gboolean __lambda7_ (Block1Data* _data1_, gchar* x) {
	CollectionTests* self;
	gboolean result = FALSE;
	GeeIterator* _tmp0_ = NULL;
	gboolean _tmp1_ = FALSE;
	const gchar* _tmp2_ = NULL;
	GeeIterator* _tmp3_ = NULL;
	gpointer _tmp4_ = NULL;
	gchar* _tmp5_ = NULL;
	gint _tmp6_ = 0;
	self = _data1_->self;
	g_return_val_if_fail (x != NULL, FALSE);
	_tmp0_ = _data1_->test_iterator;
	_tmp1_ = gee_iterator_next (_tmp0_);
	_vala_assert (_tmp1_, "test_iterator.next ()");
	_tmp2_ = x;
	_tmp3_ = _data1_->test_iterator;
	_tmp4_ = gee_iterator_get (_tmp3_);
	_tmp5_ = (gchar*) _tmp4_;
	_vala_assert (g_strcmp0 (_tmp2_, _tmp5_) == 0, "x == test_iterator.get ()");
	_g_free0 (_tmp5_);
	_tmp6_ = _data1_->count;
	_data1_->count = _tmp6_ + 1;
	result = TRUE;
	_g_free0 (x);
	return result;
}


static gboolean ___lambda7__gee_forall_func (gpointer g, gpointer self) {
	gboolean result;
	result = __lambda7_ (self, (gchar*) g);
	return result;
}


static gboolean __lambda8_ (Block1Data* _data1_, gchar* x) {
	CollectionTests* self;
	gboolean result = FALSE;
	GeeIterator* _tmp0_ = NULL;
	gboolean _tmp1_ = FALSE;
	const gchar* _tmp2_ = NULL;
	GeeIterator* _tmp3_ = NULL;
	gpointer _tmp4_ = NULL;
	gchar* _tmp5_ = NULL;
	gint _tmp6_ = 0;
	self = _data1_->self;
	g_return_val_if_fail (x != NULL, FALSE);
	_tmp0_ = _data1_->test_iterator;
	_tmp1_ = gee_iterator_next (_tmp0_);
	_vala_assert (_tmp1_, "test_iterator.next ()");
	_tmp2_ = x;
	_tmp3_ = _data1_->test_iterator;
	_tmp4_ = gee_iterator_get (_tmp3_);
	_tmp5_ = (gchar*) _tmp4_;
	_vala_assert (g_strcmp0 (_tmp2_, _tmp5_) == 0, "x == test_iterator.get ()");
	_g_free0 (_tmp5_);
	_tmp6_ = _data1_->count;
	_data1_->count = _tmp6_ + 1;
	result = TRUE;
	_g_free0 (x);
	return result;
}


static gboolean ___lambda8__gee_forall_func (gpointer g, gpointer self) {
	gboolean result;
	result = __lambda8_ (self, (gchar*) g);
	return result;
}


static gboolean __lambda9_ (Block1Data* _data1_, gchar* x) {
	CollectionTests* self;
	gboolean result = FALSE;
	GeeIterator* _tmp0_ = NULL;
	gboolean _tmp1_ = FALSE;
	const gchar* _tmp2_ = NULL;
	GeeIterator* _tmp3_ = NULL;
	gpointer _tmp4_ = NULL;
	gchar* _tmp5_ = NULL;
	gint _tmp6_ = 0;
	self = _data1_->self;
	g_return_val_if_fail (x != NULL, FALSE);
	_tmp0_ = _data1_->test_iterator;
	_tmp1_ = gee_iterator_next (_tmp0_);
	_vala_assert (_tmp1_, "test_iterator.next ()");
	_tmp2_ = x;
	_tmp3_ = _data1_->test_iterator;
	_tmp4_ = gee_iterator_get (_tmp3_);
	_tmp5_ = (gchar*) _tmp4_;
	_vala_assert (g_strcmp0 (_tmp2_, _tmp5_) == 0, "x == test_iterator.get ()");
	_g_free0 (_tmp5_);
	_tmp6_ = _data1_->count;
	_data1_->count = _tmp6_ + 1;
	result = TRUE;
	_g_free0 (x);
	return result;
}


static gboolean ___lambda9__gee_forall_func (gpointer g, gpointer self) {
	gboolean result;
	result = __lambda9_ (self, (gchar*) g);
	return result;
}


static gboolean __lambda10_ (Block1Data* _data1_, gchar* x) {
	CollectionTests* self;
	gboolean result = FALSE;
	GeeIterator* _tmp0_ = NULL;
	gboolean _tmp1_ = FALSE;
	const gchar* _tmp2_ = NULL;
	GeeIterator* _tmp3_ = NULL;
	gpointer _tmp4_ = NULL;
	gchar* _tmp5_ = NULL;
	gint _tmp6_ = 0;
	self = _data1_->self;
	g_return_val_if_fail (x != NULL, FALSE);
	_tmp0_ = _data1_->test_iterator;
	_tmp1_ = gee_iterator_next (_tmp0_);
	_vala_assert (_tmp1_, "test_iterator.next ()");
	_tmp2_ = x;
	_tmp3_ = _data1_->test_iterator;
	_tmp4_ = gee_iterator_get (_tmp3_);
	_tmp5_ = (gchar*) _tmp4_;
	_vala_assert (g_strcmp0 (_tmp2_, _tmp5_) == 0, "x == test_iterator.get ()");
	_g_free0 (_tmp5_);
	_tmp6_ = _data1_->count;
	_data1_->count = _tmp6_ + 1;
	result = TRUE;
	_g_free0 (x);
	return result;
}


static gboolean ___lambda10__gee_forall_func (gpointer g, gpointer self) {
	gboolean result;
	result = __lambda10_ (self, (gchar*) g);
	return result;
}


static Block2Data* block2_data_ref (Block2Data* _data2_) {
	g_atomic_int_inc (&_data2_->_ref_count_);
	return _data2_;
}


static void block2_data_unref (void * _userdata_) {
	Block2Data* _data2_;
	_data2_ = (Block2Data*) _userdata_;
	if (g_atomic_int_dec_and_test (&_data2_->_ref_count_)) {
		CollectionTests* self;
		self = _data2_->_data1_->self;
		block1_data_unref (_data2_->_data1_);
		_data2_->_data1_ = NULL;
		g_slice_free (Block2Data, _data2_);
	}
}


static gboolean _____lambda11_ (Block2Data* _data2_, gchar* x) {
	Block1Data* _data1_;
	CollectionTests* self;
	gboolean result = FALSE;
	GeeIterator* _tmp0_ = NULL;
	gboolean _tmp1_ = FALSE;
	const gchar* _tmp2_ = NULL;
	GeeIterator* _tmp3_ = NULL;
	gpointer _tmp4_ = NULL;
	gchar* _tmp5_ = NULL;
	gint _tmp6_ = 0;
	gint _tmp7_ = 0;
	_data1_ = _data2_->_data1_;
	self = _data1_->self;
	g_return_val_if_fail (x != NULL, FALSE);
	_tmp0_ = _data1_->test_iterator;
	_tmp1_ = gee_iterator_next (_tmp0_);
	_vala_assert (_tmp1_, "test_iterator.next ()");
	_tmp2_ = x;
	_tmp3_ = _data1_->test_iterator;
	_tmp4_ = gee_iterator_get (_tmp3_);
	_tmp5_ = (gchar*) _tmp4_;
	_vala_assert (g_strcmp0 (_tmp2_, _tmp5_) == 0, "x == test_iterator.get ()");
	_g_free0 (_tmp5_);
	_tmp6_ = _data1_->count;
	_data1_->count = _tmp6_ + 1;
	_tmp7_ = _data2_->i;
	result = _tmp6_ != _tmp7_;
	_g_free0 (x);
	return result;
}


static gboolean ______lambda11__gee_forall_func (gpointer g, gpointer self) {
	gboolean result;
	result = _____lambda11_ (self, (gchar*) g);
	return result;
}


static gboolean _____lambda12_ (Block2Data* _data2_, gchar* x) {
	Block1Data* _data1_;
	CollectionTests* self;
	gboolean result = FALSE;
	GeeIterator* _tmp0_ = NULL;
	gboolean _tmp1_ = FALSE;
	const gchar* _tmp2_ = NULL;
	GeeIterator* _tmp3_ = NULL;
	gpointer _tmp4_ = NULL;
	gchar* _tmp5_ = NULL;
	gint _tmp6_ = 0;
	gint _tmp7_ = 0;
	_data1_ = _data2_->_data1_;
	self = _data1_->self;
	g_return_val_if_fail (x != NULL, FALSE);
	_tmp0_ = _data1_->test_iterator;
	_tmp1_ = gee_iterator_next (_tmp0_);
	_vala_assert (_tmp1_, "test_iterator.next ()");
	_tmp2_ = x;
	_tmp3_ = _data1_->test_iterator;
	_tmp4_ = gee_iterator_get (_tmp3_);
	_tmp5_ = (gchar*) _tmp4_;
	_vala_assert (g_strcmp0 (_tmp2_, _tmp5_) == 0, "x == test_iterator.get ()");
	_g_free0 (_tmp5_);
	_tmp6_ = _data1_->count;
	_data1_->count = _tmp6_ + 1;
	_tmp7_ = _data2_->i;
	result = _tmp6_ != _tmp7_;
	_g_free0 (x);
	return result;
}


static gboolean ______lambda12__gee_forall_func (gpointer g, gpointer self) {
	gboolean result;
	result = _____lambda12_ (self, (gchar*) g);
	return result;
}


static gboolean _____lambda13_ (Block2Data* _data2_, gchar* x) {
	Block1Data* _data1_;
	CollectionTests* self;
	gboolean result = FALSE;
	GeeIterator* _tmp0_ = NULL;
	gboolean _tmp1_ = FALSE;
	const gchar* _tmp2_ = NULL;
	GeeIterator* _tmp3_ = NULL;
	gpointer _tmp4_ = NULL;
	gchar* _tmp5_ = NULL;
	gint _tmp6_ = 0;
	gint _tmp7_ = 0;
	_data1_ = _data2_->_data1_;
	self = _data1_->self;
	g_return_val_if_fail (x != NULL, FALSE);
	_tmp0_ = _data1_->test_iterator;
	_tmp1_ = gee_iterator_next (_tmp0_);
	_vala_assert (_tmp1_, "test_iterator.next ()");
	_tmp2_ = x;
	_tmp3_ = _data1_->test_iterator;
	_tmp4_ = gee_iterator_get (_tmp3_);
	_tmp5_ = (gchar*) _tmp4_;
	_vala_assert (g_strcmp0 (_tmp2_, _tmp5_) == 0, "x == test_iterator.get ()");
	_g_free0 (_tmp5_);
	_tmp6_ = _data1_->count;
	_data1_->count = _tmp6_ + 1;
	_tmp7_ = _data2_->i;
	result = _tmp6_ != (_tmp7_ + 1);
	_g_free0 (x);
	return result;
}


static gboolean ______lambda13__gee_forall_func (gpointer g, gpointer self) {
	gboolean result;
	result = _____lambda13_ (self, (gchar*) g);
	return result;
}


static gboolean _____lambda14_ (Block2Data* _data2_, gchar* x) {
	Block1Data* _data1_;
	CollectionTests* self;
	gboolean result = FALSE;
	GeeIterator* _tmp0_ = NULL;
	gboolean _tmp1_ = FALSE;
	const gchar* _tmp2_ = NULL;
	GeeIterator* _tmp3_ = NULL;
	gpointer _tmp4_ = NULL;
	gchar* _tmp5_ = NULL;
	gint _tmp6_ = 0;
	gint _tmp7_ = 0;
	_data1_ = _data2_->_data1_;
	self = _data1_->self;
	g_return_val_if_fail (x != NULL, FALSE);
	_tmp0_ = _data1_->test_iterator;
	_tmp1_ = gee_iterator_next (_tmp0_);
	_vala_assert (_tmp1_, "test_iterator.next ()");
	_tmp2_ = x;
	_tmp3_ = _data1_->test_iterator;
	_tmp4_ = gee_iterator_get (_tmp3_);
	_tmp5_ = (gchar*) _tmp4_;
	_vala_assert (g_strcmp0 (_tmp2_, _tmp5_) == 0, "x == test_iterator.get ()");
	_g_free0 (_tmp5_);
	_tmp6_ = _data1_->count;
	_data1_->count = _tmp6_ + 1;
	_tmp7_ = _data2_->i;
	result = _tmp6_ != (_tmp7_ + 1);
	_g_free0 (x);
	return result;
}


static gboolean ______lambda14__gee_forall_func (gpointer g, gpointer self) {
	gboolean result;
	result = _____lambda14_ (self, (gchar*) g);
	return result;
}


void collection_tests_test_foreach (CollectionTests* self) {
	Block1Data* _data1_;
	gboolean res = FALSE;
	gchar** data = NULL;
	gint _tmp0_ = 0;
	gchar** _tmp1_ = NULL;
	gint data_length1 = 0;
	gint _data_size_ = 0;
	GeeCollection* _tmp2_ = NULL;
	gboolean _tmp3_ = FALSE;
	gboolean _tmp4_ = FALSE;
	GeeCollection* _tmp5_ = NULL;
	GeeIterator* _tmp6_ = NULL;
	GeeIterator* _tmp7_ = NULL;
	gboolean _tmp8_ = FALSE;
	gboolean _tmp9_ = FALSE;
	gchar** _tmp10_ = NULL;
	gint _tmp10__length1 = 0;
	GeeCollection* _tmp14_ = NULL;
	GeeIterator* _tmp15_ = NULL;
	GeeCollection* _tmp16_ = NULL;
	gboolean _tmp17_ = FALSE;
	gint _tmp18_ = 0;
	gchar** _tmp19_ = NULL;
	gint _tmp19__length1 = 0;
	gboolean _tmp20_ = FALSE;
	GeeCollection* _tmp21_ = NULL;
	GeeIterator* _tmp22_ = NULL;
	GeeIterator* iter = NULL;
	GeeCollection* _tmp23_ = NULL;
	GeeIterator* _tmp24_ = NULL;
	GeeIterator* _tmp25_ = NULL;
	gboolean _tmp26_ = FALSE;
	gint _tmp27_ = 0;
	gchar** _tmp28_ = NULL;
	gint _tmp28__length1 = 0;
	gboolean _tmp29_ = FALSE;
	GeeIterator* _tmp30_ = NULL;
	gboolean _tmp31_ = FALSE;
	gboolean _tmp32_ = FALSE;
	GeeIterator* _tmp33_ = NULL;
	gpointer _tmp34_ = NULL;
	gchar* _tmp35_ = NULL;
	GeeIterator* _tmp36_ = NULL;
	gpointer _tmp37_ = NULL;
	gchar* _tmp38_ = NULL;
	GeeIterator* _tmp39_ = NULL;
	gboolean _tmp40_ = FALSE;
	GeeCollection* _tmp41_ = NULL;
	GeeIterator* _tmp42_ = NULL;
	GeeCollection* _tmp43_ = NULL;
	GeeIterator* _tmp44_ = NULL;
	GeeIterator* _tmp45_ = NULL;
	gboolean _tmp46_ = FALSE;
	GeeIterator* _tmp47_ = NULL;
	gboolean _tmp48_ = FALSE;
	GeeIterator* _tmp49_ = NULL;
	gboolean _tmp50_ = FALSE;
	GeeIterator* _tmp51_ = NULL;
	gboolean _tmp52_ = FALSE;
	gint _tmp53_ = 0;
	gchar** _tmp54_ = NULL;
	gint _tmp54__length1 = 0;
	gboolean _tmp55_ = FALSE;
	GeeIterator* _tmp56_ = NULL;
	gboolean _tmp57_ = FALSE;
	gboolean _tmp58_ = FALSE;
	GeeIterator* _tmp59_ = NULL;
	gpointer _tmp60_ = NULL;
	gchar* _tmp61_ = NULL;
	GeeIterator* _tmp62_ = NULL;
	gpointer _tmp63_ = NULL;
	gchar* _tmp64_ = NULL;
	GeeIterator* _tmp65_ = NULL;
	gboolean _tmp66_ = FALSE;
	GeeCollection* _tmp67_ = NULL;
	GeeIterator* _tmp68_ = NULL;
	GeeCollection* _tmp69_ = NULL;
	GeeIterator* _tmp70_ = NULL;
	GeeIterator* _tmp71_ = NULL;
	gboolean _tmp72_ = FALSE;
	GeeIterator* _tmp73_ = NULL;
	gboolean _tmp74_ = FALSE;
	GeeIterator* _tmp75_ = NULL;
	gboolean _tmp76_ = FALSE;
	GeeIterator* _tmp77_ = NULL;
	gboolean _tmp78_ = FALSE;
	GeeIterator* _tmp79_ = NULL;
	gboolean _tmp80_ = FALSE;
	gint _tmp81_ = 0;
	gchar** _tmp82_ = NULL;
	gint _tmp82__length1 = 0;
	gboolean _tmp83_ = FALSE;
	GeeIterator* _tmp84_ = NULL;
	gboolean _tmp85_ = FALSE;
	gboolean _tmp86_ = FALSE;
	GeeIterator* _tmp87_ = NULL;
	gpointer _tmp88_ = NULL;
	gchar* _tmp89_ = NULL;
	GeeIterator* _tmp90_ = NULL;
	gpointer _tmp91_ = NULL;
	gchar* _tmp92_ = NULL;
	GeeIterator* _tmp93_ = NULL;
	gboolean _tmp94_ = FALSE;
	g_return_if_fail (self != NULL);
	_data1_ = g_slice_new0 (Block1Data);
	_data1_->_ref_count_ = 1;
	_data1_->self = g_object_ref (self);
	_tmp1_ = test_data_get_data (&_tmp0_);
	data = _tmp1_;
	data_length1 = _tmp0_;
	_data_size_ = data_length1;
	_tmp2_ = self->test_collection;
	_tmp3_ = gee_traversable_foreach ((GeeTraversable*) _tmp2_, ___lambda5__gee_forall_func, self);
	res = _tmp3_;
	_tmp4_ = res;
	_vala_assert (_tmp4_ == TRUE, "res == true");
	_tmp5_ = self->test_collection;
	_tmp6_ = gee_iterable_iterator ((GeeIterable*) _tmp5_);
	_tmp7_ = _tmp6_;
	_tmp8_ = gee_traversable_foreach ((GeeTraversable*) _tmp7_, ___lambda6__gee_forall_func, self);
	res = _tmp8_;
	_g_object_unref0 (_tmp7_);
	_tmp9_ = res;
	_vala_assert (_tmp9_ == TRUE, "res == true");
	_tmp10_ = data;
	_tmp10__length1 = data_length1;
	{
		gchar** el_collection = NULL;
		gint el_collection_length1 = 0;
		gint _el_collection_size_ = 0;
		gint el_it = 0;
		el_collection = _tmp10_;
		el_collection_length1 = _tmp10__length1;
		for (el_it = 0; el_it < _tmp10__length1; el_it = el_it + 1) {
			const gchar* el = NULL;
			el = el_collection[el_it];
			{
				GeeCollection* _tmp11_ = NULL;
				const gchar* _tmp12_ = NULL;
				gboolean _tmp13_ = FALSE;
				_tmp11_ = self->test_collection;
				_tmp12_ = el;
				_tmp13_ = gee_collection_add (_tmp11_, _tmp12_);
				_vala_assert (_tmp13_, "test_collection.add (el)");
			}
		}
	}
	_data1_->count = 0;
	_tmp14_ = self->test_collection;
	_tmp15_ = gee_iterable_iterator ((GeeIterable*) _tmp14_);
	_data1_->test_iterator = _tmp15_;
	_tmp16_ = self->test_collection;
	_tmp17_ = gee_traversable_foreach ((GeeTraversable*) _tmp16_, ___lambda7__gee_forall_func, _data1_);
	res = _tmp17_;
	_tmp18_ = _data1_->count;
	_tmp19_ = data;
	_tmp19__length1 = data_length1;
	_vala_assert (_tmp18_ == _tmp19__length1, "count == data.length");
	_tmp20_ = res;
	_vala_assert (_tmp20_ == TRUE, "res == true");
	_data1_->count = 0;
	_tmp21_ = self->test_collection;
	_tmp22_ = gee_iterable_iterator ((GeeIterable*) _tmp21_);
	_g_object_unref0 (_data1_->test_iterator);
	_data1_->test_iterator = _tmp22_;
	_tmp23_ = self->test_collection;
	_tmp24_ = gee_iterable_iterator ((GeeIterable*) _tmp23_);
	iter = _tmp24_;
	_tmp25_ = iter;
	_tmp26_ = gee_traversable_foreach ((GeeTraversable*) _tmp25_, ___lambda8__gee_forall_func, _data1_);
	res = _tmp26_;
	_tmp27_ = _data1_->count;
	_tmp28_ = data;
	_tmp28__length1 = data_length1;
	_vala_assert (_tmp27_ == _tmp28__length1, "count == data.length");
	_tmp29_ = res;
	_vala_assert (_tmp29_ == TRUE, "res == true");
	_tmp30_ = iter;
	_tmp31_ = gee_iterator_get_valid (_tmp30_);
	_tmp32_ = _tmp31_;
	_vala_assert (_tmp32_, "iter.valid");
	_tmp33_ = iter;
	_tmp34_ = gee_iterator_get (_tmp33_);
	_tmp35_ = (gchar*) _tmp34_;
	_tmp36_ = _data1_->test_iterator;
	_tmp37_ = gee_iterator_get (_tmp36_);
	_tmp38_ = (gchar*) _tmp37_;
	_vala_assert (g_strcmp0 (_tmp35_, _tmp38_) == 0, "iter.get () == test_iterator.get ()");
	_g_free0 (_tmp38_);
	_g_free0 (_tmp35_);
	_tmp39_ = iter;
	_tmp40_ = gee_iterator_has_next (_tmp39_);
	_vala_assert (!_tmp40_, "!iter.has_next ()");
	_data1_->count = 1;
	_tmp41_ = self->test_collection;
	_tmp42_ = gee_iterable_iterator ((GeeIterable*) _tmp41_);
	_g_object_unref0 (_data1_->test_iterator);
	_data1_->test_iterator = _tmp42_;
	_tmp43_ = self->test_collection;
	_tmp44_ = gee_iterable_iterator ((GeeIterable*) _tmp43_);
	_g_object_unref0 (iter);
	iter = _tmp44_;
	_tmp45_ = iter;
	_tmp46_ = gee_iterator_next (_tmp45_);
	_vala_assert (_tmp46_, "iter.next ()");
	_tmp47_ = iter;
	_tmp48_ = gee_iterator_next (_tmp47_);
	_vala_assert (_tmp48_, "iter.next ()");
	_tmp49_ = _data1_->test_iterator;
	_tmp50_ = gee_iterator_next (_tmp49_);
	_vala_assert (_tmp50_, "test_iterator.next ()");
	_tmp51_ = iter;
	_tmp52_ = gee_traversable_foreach ((GeeTraversable*) _tmp51_, ___lambda9__gee_forall_func, _data1_);
	res = _tmp52_;
	_tmp53_ = _data1_->count;
	_tmp54_ = data;
	_tmp54__length1 = data_length1;
	_vala_assert (_tmp53_ == _tmp54__length1, "count == data.length");
	_tmp55_ = res;
	_vala_assert (_tmp55_ == TRUE, "res == true");
	_tmp56_ = iter;
	_tmp57_ = gee_iterator_get_valid (_tmp56_);
	_tmp58_ = _tmp57_;
	_vala_assert (_tmp58_, "iter.valid");
	_tmp59_ = iter;
	_tmp60_ = gee_iterator_get (_tmp59_);
	_tmp61_ = (gchar*) _tmp60_;
	_tmp62_ = _data1_->test_iterator;
	_tmp63_ = gee_iterator_get (_tmp62_);
	_tmp64_ = (gchar*) _tmp63_;
	_vala_assert (g_strcmp0 (_tmp61_, _tmp64_) == 0, "iter.get () == test_iterator.get ()");
	_g_free0 (_tmp64_);
	_g_free0 (_tmp61_);
	_tmp65_ = iter;
	_tmp66_ = gee_iterator_has_next (_tmp65_);
	_vala_assert (!_tmp66_, "!iter.has_next ()");
	_data1_->count = 1;
	_tmp67_ = self->test_collection;
	_tmp68_ = gee_iterable_iterator ((GeeIterable*) _tmp67_);
	_g_object_unref0 (_data1_->test_iterator);
	_data1_->test_iterator = _tmp68_;
	_tmp69_ = self->test_collection;
	_tmp70_ = gee_iterable_iterator ((GeeIterable*) _tmp69_);
	_g_object_unref0 (iter);
	iter = _tmp70_;
	_tmp71_ = iter;
	_tmp72_ = gee_iterator_next (_tmp71_);
	_vala_assert (_tmp72_, "iter.next ()");
	_tmp73_ = iter;
	_tmp74_ = gee_iterator_next (_tmp73_);
	_vala_assert (_tmp74_, "iter.next ()");
	_tmp75_ = iter;
	_tmp76_ = gee_iterator_has_next (_tmp75_);
	_vala_assert (_tmp76_, "iter.has_next ()");
	_tmp77_ = _data1_->test_iterator;
	_tmp78_ = gee_iterator_next (_tmp77_);
	_vala_assert (_tmp78_, "test_iterator.next ()");
	_tmp79_ = iter;
	_tmp80_ = gee_traversable_foreach ((GeeTraversable*) _tmp79_, ___lambda10__gee_forall_func, _data1_);
	res = _tmp80_;
	_tmp81_ = _data1_->count;
	_tmp82_ = data;
	_tmp82__length1 = data_length1;
	_vala_assert (_tmp81_ == _tmp82__length1, "count == data.length");
	_tmp83_ = res;
	_vala_assert (_tmp83_ == TRUE, "res == true");
	_tmp84_ = iter;
	_tmp85_ = gee_iterator_get_valid (_tmp84_);
	_tmp86_ = _tmp85_;
	_vala_assert (_tmp86_, "iter.valid");
	_tmp87_ = iter;
	_tmp88_ = gee_iterator_get (_tmp87_);
	_tmp89_ = (gchar*) _tmp88_;
	_tmp90_ = _data1_->test_iterator;
	_tmp91_ = gee_iterator_get (_tmp90_);
	_tmp92_ = (gchar*) _tmp91_;
	_vala_assert (g_strcmp0 (_tmp89_, _tmp92_) == 0, "iter.get () == test_iterator.get ()");
	_g_free0 (_tmp92_);
	_g_free0 (_tmp89_);
	_tmp93_ = iter;
	_tmp94_ = gee_iterator_has_next (_tmp93_);
	_vala_assert (!_tmp94_, "!iter.has_next ()");
	{
		Block2Data* _data2_;
		_data2_ = g_slice_new0 (Block2Data);
		_data2_->_ref_count_ = 1;
		_data2_->_data1_ = block1_data_ref (_data1_);
		_data2_->i = 0;
		{
			gboolean _tmp95_ = FALSE;
			_tmp95_ = TRUE;
			while (TRUE) {
				gint _tmp97_ = 0;
				GeeCollection* _tmp98_ = NULL;
				GeeIterator* _tmp99_ = NULL;
				GeeCollection* _tmp100_ = NULL;
				gboolean _tmp101_ = FALSE;
				gint _tmp102_ = 0;
				gint _tmp103_ = 0;
				gboolean _tmp104_ = FALSE;
				GeeCollection* _tmp105_ = NULL;
				GeeIterator* _tmp106_ = NULL;
				GeeCollection* _tmp107_ = NULL;
				GeeIterator* _tmp108_ = NULL;
				GeeIterator* _tmp109_ = NULL;
				gboolean _tmp110_ = FALSE;
				gint _tmp111_ = 0;
				gint _tmp112_ = 0;
				gboolean _tmp113_ = FALSE;
				GeeIterator* _tmp114_ = NULL;
				gboolean _tmp115_ = FALSE;
				gboolean _tmp116_ = FALSE;
				GeeIterator* _tmp117_ = NULL;
				gpointer _tmp118_ = NULL;
				gchar* _tmp119_ = NULL;
				GeeIterator* _tmp120_ = NULL;
				gpointer _tmp121_ = NULL;
				gchar* _tmp122_ = NULL;
				GeeIterator* _tmp123_ = NULL;
				gboolean _tmp124_ = FALSE;
				GeeIterator* _tmp135_ = NULL;
				gboolean _tmp136_ = FALSE;
				GeeCollection* _tmp137_ = NULL;
				GeeIterator* _tmp138_ = NULL;
				GeeCollection* _tmp139_ = NULL;
				GeeIterator* _tmp140_ = NULL;
				GeeIterator* _tmp141_ = NULL;
				gboolean _tmp142_ = FALSE;
				GeeIterator* _tmp143_ = NULL;
				gboolean _tmp144_ = FALSE;
				GeeIterator* _tmp145_ = NULL;
				gboolean _tmp146_ = FALSE;
				GeeIterator* _tmp147_ = NULL;
				gboolean _tmp148_ = FALSE;
				gint _tmp149_ = 0;
				gint _tmp150_ = 0;
				gboolean _tmp151_ = FALSE;
				GeeIterator* _tmp152_ = NULL;
				gboolean _tmp153_ = FALSE;
				gboolean _tmp154_ = FALSE;
				GeeIterator* _tmp155_ = NULL;
				gpointer _tmp156_ = NULL;
				gchar* _tmp157_ = NULL;
				GeeIterator* _tmp158_ = NULL;
				gpointer _tmp159_ = NULL;
				gchar* _tmp160_ = NULL;
				GeeIterator* _tmp161_ = NULL;
				gboolean _tmp162_ = FALSE;
				GeeIterator* _tmp173_ = NULL;
				gboolean _tmp174_ = FALSE;
				GeeCollection* _tmp175_ = NULL;
				GeeIterator* _tmp176_ = NULL;
				GeeCollection* _tmp177_ = NULL;
				GeeIterator* _tmp178_ = NULL;
				GeeIterator* _tmp179_ = NULL;
				gboolean _tmp180_ = FALSE;
				GeeIterator* _tmp181_ = NULL;
				gboolean _tmp182_ = FALSE;
				GeeIterator* _tmp183_ = NULL;
				gboolean _tmp184_ = FALSE;
				GeeIterator* _tmp185_ = NULL;
				gboolean _tmp186_ = FALSE;
				GeeIterator* _tmp187_ = NULL;
				gboolean _tmp188_ = FALSE;
				gint _tmp189_ = 0;
				gint _tmp190_ = 0;
				gboolean _tmp191_ = FALSE;
				GeeIterator* _tmp192_ = NULL;
				gboolean _tmp193_ = FALSE;
				gboolean _tmp194_ = FALSE;
				GeeIterator* _tmp195_ = NULL;
				gpointer _tmp196_ = NULL;
				gchar* _tmp197_ = NULL;
				GeeIterator* _tmp198_ = NULL;
				gpointer _tmp199_ = NULL;
				gchar* _tmp200_ = NULL;
				GeeIterator* _tmp201_ = NULL;
				gboolean _tmp202_ = FALSE;
				GeeIterator* _tmp213_ = NULL;
				gboolean _tmp214_ = FALSE;
				if (!_tmp95_) {
					gint _tmp96_ = 0;
					_tmp96_ = _data2_->i;
					_data2_->i = _tmp96_ + 1;
				}
				_tmp95_ = FALSE;
				_tmp97_ = _data2_->i;
				if (!(_tmp97_ < 3)) {
					break;
				}
				_data1_->count = 0;
				_tmp98_ = self->test_collection;
				_tmp99_ = gee_iterable_iterator ((GeeIterable*) _tmp98_);
				_g_object_unref0 (_data1_->test_iterator);
				_data1_->test_iterator = _tmp99_;
				_tmp100_ = self->test_collection;
				_tmp101_ = gee_traversable_foreach ((GeeTraversable*) _tmp100_, ______lambda11__gee_forall_func, _data2_);
				res = _tmp101_;
				_tmp102_ = _data1_->count;
				_tmp103_ = _data2_->i;
				_vala_assert (_tmp102_ == (_tmp103_ + 1), "count == i + 1");
				_tmp104_ = res;
				_vala_assert (_tmp104_ == FALSE, "res == false");
				_data1_->count = 0;
				_tmp105_ = self->test_collection;
				_tmp106_ = gee_iterable_iterator ((GeeIterable*) _tmp105_);
				_g_object_unref0 (_data1_->test_iterator);
				_data1_->test_iterator = _tmp106_;
				_tmp107_ = self->test_collection;
				_tmp108_ = gee_iterable_iterator ((GeeIterable*) _tmp107_);
				_g_object_unref0 (iter);
				iter = _tmp108_;
				_tmp109_ = iter;
				_tmp110_ = gee_traversable_foreach ((GeeTraversable*) _tmp109_, ______lambda12__gee_forall_func, _data2_);
				res = _tmp110_;
				_tmp111_ = _data1_->count;
				_tmp112_ = _data2_->i;
				_vala_assert (_tmp111_ == (_tmp112_ + 1), "count == i + 1");
				_tmp113_ = res;
				_vala_assert (_tmp113_ == FALSE, "res == false");
				_tmp114_ = iter;
				_tmp115_ = gee_iterator_get_valid (_tmp114_);
				_tmp116_ = _tmp115_;
				_vala_assert (_tmp116_, "iter.valid");
				_tmp117_ = iter;
				_tmp118_ = gee_iterator_get (_tmp117_);
				_tmp119_ = (gchar*) _tmp118_;
				_tmp120_ = _data1_->test_iterator;
				_tmp121_ = gee_iterator_get (_tmp120_);
				_tmp122_ = (gchar*) _tmp121_;
				_vala_assert (g_strcmp0 (_tmp119_, _tmp122_) == 0, "iter.get () == test_iterator.get ()");
				_g_free0 (_tmp122_);
				_g_free0 (_tmp119_);
				_tmp123_ = iter;
				_tmp124_ = gee_iterator_has_next (_tmp123_);
				_vala_assert (_tmp124_, "iter.has_next ()");
				while (TRUE) {
					GeeIterator* _tmp125_ = NULL;
					gboolean _tmp126_ = FALSE;
					GeeIterator* _tmp127_ = NULL;
					gboolean _tmp128_ = FALSE;
					GeeIterator* _tmp129_ = NULL;
					gpointer _tmp130_ = NULL;
					gchar* _tmp131_ = NULL;
					GeeIterator* _tmp132_ = NULL;
					gpointer _tmp133_ = NULL;
					gchar* _tmp134_ = NULL;
					_tmp125_ = _data1_->test_iterator;
					_tmp126_ = gee_iterator_next (_tmp125_);
					if (!_tmp126_) {
						break;
					}
					_tmp127_ = iter;
					_tmp128_ = gee_iterator_next (_tmp127_);
					_vala_assert (_tmp128_, "iter.next ()");
					_tmp129_ = iter;
					_tmp130_ = gee_iterator_get (_tmp129_);
					_tmp131_ = (gchar*) _tmp130_;
					_tmp132_ = _data1_->test_iterator;
					_tmp133_ = gee_iterator_get (_tmp132_);
					_tmp134_ = (gchar*) _tmp133_;
					_vala_assert (g_strcmp0 (_tmp131_, _tmp134_) == 0, "iter.get () == test_iterator.get ()");
					_g_free0 (_tmp134_);
					_g_free0 (_tmp131_);
				}
				_tmp135_ = iter;
				_tmp136_ = gee_iterator_has_next (_tmp135_);
				_vala_assert (!_tmp136_, "!iter.has_next ()");
				_data1_->count = 1;
				_tmp137_ = self->test_collection;
				_tmp138_ = gee_iterable_iterator ((GeeIterable*) _tmp137_);
				_g_object_unref0 (_data1_->test_iterator);
				_data1_->test_iterator = _tmp138_;
				_tmp139_ = self->test_collection;
				_tmp140_ = gee_iterable_iterator ((GeeIterable*) _tmp139_);
				_g_object_unref0 (iter);
				iter = _tmp140_;
				_tmp141_ = iter;
				_tmp142_ = gee_iterator_next (_tmp141_);
				_vala_assert (_tmp142_, "iter.next ()");
				_tmp143_ = iter;
				_tmp144_ = gee_iterator_next (_tmp143_);
				_vala_assert (_tmp144_, "iter.next ()");
				_tmp145_ = _data1_->test_iterator;
				_tmp146_ = gee_iterator_next (_tmp145_);
				_vala_assert (_tmp146_, "test_iterator.next ()");
				_tmp147_ = iter;
				_tmp148_ = gee_traversable_foreach ((GeeTraversable*) _tmp147_, ______lambda13__gee_forall_func, _data2_);
				res = _tmp148_;
				_tmp149_ = _data1_->count;
				_tmp150_ = _data2_->i;
				_vala_assert (_tmp149_ == (_tmp150_ + 2), "count == i + 2");
				_tmp151_ = res;
				_vala_assert (_tmp151_ == FALSE, "res == false");
				_tmp152_ = iter;
				_tmp153_ = gee_iterator_get_valid (_tmp152_);
				_tmp154_ = _tmp153_;
				_vala_assert (_tmp154_, "iter.valid");
				_tmp155_ = iter;
				_tmp156_ = gee_iterator_get (_tmp155_);
				_tmp157_ = (gchar*) _tmp156_;
				_tmp158_ = _data1_->test_iterator;
				_tmp159_ = gee_iterator_get (_tmp158_);
				_tmp160_ = (gchar*) _tmp159_;
				_vala_assert (g_strcmp0 (_tmp157_, _tmp160_) == 0, "iter.get () == test_iterator.get ()");
				_g_free0 (_tmp160_);
				_g_free0 (_tmp157_);
				_tmp161_ = iter;
				_tmp162_ = gee_iterator_has_next (_tmp161_);
				_vala_assert (_tmp162_, "iter.has_next ()");
				while (TRUE) {
					GeeIterator* _tmp163_ = NULL;
					gboolean _tmp164_ = FALSE;
					GeeIterator* _tmp165_ = NULL;
					gboolean _tmp166_ = FALSE;
					GeeIterator* _tmp167_ = NULL;
					gpointer _tmp168_ = NULL;
					gchar* _tmp169_ = NULL;
					GeeIterator* _tmp170_ = NULL;
					gpointer _tmp171_ = NULL;
					gchar* _tmp172_ = NULL;
					_tmp163_ = _data1_->test_iterator;
					_tmp164_ = gee_iterator_next (_tmp163_);
					if (!_tmp164_) {
						break;
					}
					_tmp165_ = iter;
					_tmp166_ = gee_iterator_next (_tmp165_);
					_vala_assert (_tmp166_, "iter.next ()");
					_tmp167_ = iter;
					_tmp168_ = gee_iterator_get (_tmp167_);
					_tmp169_ = (gchar*) _tmp168_;
					_tmp170_ = _data1_->test_iterator;
					_tmp171_ = gee_iterator_get (_tmp170_);
					_tmp172_ = (gchar*) _tmp171_;
					_vala_assert (g_strcmp0 (_tmp169_, _tmp172_) == 0, "iter.get () == test_iterator.get ()");
					_g_free0 (_tmp172_);
					_g_free0 (_tmp169_);
				}
				_tmp173_ = iter;
				_tmp174_ = gee_iterator_has_next (_tmp173_);
				_vala_assert (!_tmp174_, "!iter.has_next ()");
				_data1_->count = 1;
				_tmp175_ = self->test_collection;
				_tmp176_ = gee_iterable_iterator ((GeeIterable*) _tmp175_);
				_g_object_unref0 (_data1_->test_iterator);
				_data1_->test_iterator = _tmp176_;
				_tmp177_ = self->test_collection;
				_tmp178_ = gee_iterable_iterator ((GeeIterable*) _tmp177_);
				_g_object_unref0 (iter);
				iter = _tmp178_;
				_tmp179_ = iter;
				_tmp180_ = gee_iterator_next (_tmp179_);
				_vala_assert (_tmp180_, "iter.next ()");
				_tmp181_ = iter;
				_tmp182_ = gee_iterator_next (_tmp181_);
				_vala_assert (_tmp182_, "iter.next ()");
				_tmp183_ = iter;
				_tmp184_ = gee_iterator_has_next (_tmp183_);
				_vala_assert (_tmp184_, "iter.has_next ()");
				_tmp185_ = _data1_->test_iterator;
				_tmp186_ = gee_iterator_next (_tmp185_);
				_vala_assert (_tmp186_, "test_iterator.next ()");
				_tmp187_ = iter;
				_tmp188_ = gee_traversable_foreach ((GeeTraversable*) _tmp187_, ______lambda14__gee_forall_func, _data2_);
				res = _tmp188_;
				_tmp189_ = _data1_->count;
				_tmp190_ = _data2_->i;
				_vala_assert (_tmp189_ == (_tmp190_ + 2), "count == i + 2");
				_tmp191_ = res;
				_vala_assert (_tmp191_ == FALSE, "res == false");
				_tmp192_ = iter;
				_tmp193_ = gee_iterator_get_valid (_tmp192_);
				_tmp194_ = _tmp193_;
				_vala_assert (_tmp194_, "iter.valid");
				_tmp195_ = iter;
				_tmp196_ = gee_iterator_get (_tmp195_);
				_tmp197_ = (gchar*) _tmp196_;
				_tmp198_ = _data1_->test_iterator;
				_tmp199_ = gee_iterator_get (_tmp198_);
				_tmp200_ = (gchar*) _tmp199_;
				_vala_assert (g_strcmp0 (_tmp197_, _tmp200_) == 0, "iter.get () == test_iterator.get ()");
				_g_free0 (_tmp200_);
				_g_free0 (_tmp197_);
				_tmp201_ = iter;
				_tmp202_ = gee_iterator_has_next (_tmp201_);
				_vala_assert (_tmp202_, "iter.has_next ()");
				while (TRUE) {
					GeeIterator* _tmp203_ = NULL;
					gboolean _tmp204_ = FALSE;
					GeeIterator* _tmp205_ = NULL;
					gboolean _tmp206_ = FALSE;
					GeeIterator* _tmp207_ = NULL;
					gpointer _tmp208_ = NULL;
					gchar* _tmp209_ = NULL;
					GeeIterator* _tmp210_ = NULL;
					gpointer _tmp211_ = NULL;
					gchar* _tmp212_ = NULL;
					_tmp203_ = _data1_->test_iterator;
					_tmp204_ = gee_iterator_next (_tmp203_);
					if (!_tmp204_) {
						break;
					}
					_tmp205_ = iter;
					_tmp206_ = gee_iterator_next (_tmp205_);
					_vala_assert (_tmp206_, "iter.next ()");
					_tmp207_ = iter;
					_tmp208_ = gee_iterator_get (_tmp207_);
					_tmp209_ = (gchar*) _tmp208_;
					_tmp210_ = _data1_->test_iterator;
					_tmp211_ = gee_iterator_get (_tmp210_);
					_tmp212_ = (gchar*) _tmp211_;
					_vala_assert (g_strcmp0 (_tmp209_, _tmp212_) == 0, "iter.get () == test_iterator.get ()");
					_g_free0 (_tmp212_);
					_g_free0 (_tmp209_);
				}
				_tmp213_ = iter;
				_tmp214_ = gee_iterator_has_next (_tmp213_);
				_vala_assert (!_tmp214_, "!iter.has_next ()");
			}
		}
		block2_data_unref (_data2_);
		_data2_ = NULL;
	}
	_g_object_unref0 (iter);
	block1_data_unref (_data1_);
	_data1_ = NULL;
}


static Block3Data* block3_data_ref (Block3Data* _data3_) {
	g_atomic_int_inc (&_data3_->_ref_count_);
	return _data3_;
}


static void block3_data_unref (void * _userdata_) {
	Block3Data* _data3_;
	_data3_ = (Block3Data*) _userdata_;
	if (g_atomic_int_dec_and_test (&_data3_->_ref_count_)) {
		CollectionTests* self;
		self = _data3_->self;
		_g_object_unref0 (_data3_->test_iterator);
		_g_object_unref0 (self);
		g_slice_free (Block3Data, _data3_);
	}
}


static gint __lambda15_ (CollectionTests* self, gchar* x, gint y) {
	gint result = 0;
	g_return_val_if_fail (x != NULL, 0);
	g_assert_not_reached ();
	_g_free0 (x);
	return result;
}


static gpointer ___lambda15__gee_fold_func (gpointer g, gpointer a, gpointer self) {
	gpointer result;
	result = (gpointer) ((gintptr) __lambda15_ ((CollectionTests*) self, (gchar*) g, (gint) ((gintptr) a)));
	return result;
}


static gint __lambda16_ (CollectionTests* self, gchar* x, gint y) {
	gint result = 0;
	g_return_val_if_fail (x != NULL, 0);
	g_assert_not_reached ();
	_g_free0 (x);
	return result;
}


static gpointer ___lambda16__gee_fold_func (gpointer g, gpointer a, gpointer self) {
	gpointer result;
	result = (gpointer) ((gintptr) __lambda16_ ((CollectionTests*) self, (gchar*) g, (gint) ((gintptr) a)));
	return result;
}


static gint __lambda17_ (Block3Data* _data3_, gchar* x, gint y) {
	CollectionTests* self;
	gint result = 0;
	GeeIterator* _tmp0_ = NULL;
	gboolean _tmp1_ = FALSE;
	const gchar* _tmp2_ = NULL;
	GeeIterator* _tmp3_ = NULL;
	gpointer _tmp4_ = NULL;
	gchar* _tmp5_ = NULL;
	gint _tmp6_ = 0;
	self = _data3_->self;
	g_return_val_if_fail (x != NULL, 0);
	_tmp0_ = _data3_->test_iterator;
	_tmp1_ = gee_iterator_next (_tmp0_);
	_vala_assert (_tmp1_, "test_iterator.next ()");
	_tmp2_ = x;
	_tmp3_ = _data3_->test_iterator;
	_tmp4_ = gee_iterator_get (_tmp3_);
	_tmp5_ = (gchar*) _tmp4_;
	_vala_assert (g_strcmp0 (_tmp2_, _tmp5_) == 0, "x == test_iterator.get ()");
	_g_free0 (_tmp5_);
	_tmp6_ = y;
	result = _tmp6_ + 1;
	_g_free0 (x);
	return result;
}


static gpointer ___lambda17__gee_fold_func (gpointer g, gpointer a, gpointer self) {
	gpointer result;
	result = (gpointer) ((gintptr) __lambda17_ (self, (gchar*) g, (gint) ((gintptr) a)));
	return result;
}


static gint __lambda18_ (Block3Data* _data3_, gchar* x, gint y) {
	CollectionTests* self;
	gint result = 0;
	GeeIterator* _tmp0_ = NULL;
	gboolean _tmp1_ = FALSE;
	const gchar* _tmp2_ = NULL;
	GeeIterator* _tmp3_ = NULL;
	gpointer _tmp4_ = NULL;
	gchar* _tmp5_ = NULL;
	gint _tmp6_ = 0;
	self = _data3_->self;
	g_return_val_if_fail (x != NULL, 0);
	_tmp0_ = _data3_->test_iterator;
	_tmp1_ = gee_iterator_next (_tmp0_);
	_vala_assert (_tmp1_, "test_iterator.next ()");
	_tmp2_ = x;
	_tmp3_ = _data3_->test_iterator;
	_tmp4_ = gee_iterator_get (_tmp3_);
	_tmp5_ = (gchar*) _tmp4_;
	_vala_assert (g_strcmp0 (_tmp2_, _tmp5_) == 0, "x == test_iterator.get ()");
	_g_free0 (_tmp5_);
	_tmp6_ = y;
	result = _tmp6_ + 1;
	_g_free0 (x);
	return result;
}


static gpointer ___lambda18__gee_fold_func (gpointer g, gpointer a, gpointer self) {
	gpointer result;
	result = (gpointer) ((gintptr) __lambda18_ (self, (gchar*) g, (gint) ((gintptr) a)));
	return result;
}


static gint __lambda19_ (Block3Data* _data3_, gchar* x, gint y) {
	CollectionTests* self;
	gint result = 0;
	GeeIterator* _tmp0_ = NULL;
	gboolean _tmp1_ = FALSE;
	const gchar* _tmp2_ = NULL;
	GeeIterator* _tmp3_ = NULL;
	gpointer _tmp4_ = NULL;
	gchar* _tmp5_ = NULL;
	gint _tmp6_ = 0;
	self = _data3_->self;
	g_return_val_if_fail (x != NULL, 0);
	_tmp0_ = _data3_->test_iterator;
	_tmp1_ = gee_iterator_next (_tmp0_);
	_vala_assert (_tmp1_, "test_iterator.next ()");
	_tmp2_ = x;
	_tmp3_ = _data3_->test_iterator;
	_tmp4_ = gee_iterator_get (_tmp3_);
	_tmp5_ = (gchar*) _tmp4_;
	_vala_assert (g_strcmp0 (_tmp2_, _tmp5_) == 0, "x == test_iterator.get ()");
	_g_free0 (_tmp5_);
	_tmp6_ = y;
	result = _tmp6_ + 1;
	_g_free0 (x);
	return result;
}


static gpointer ___lambda19__gee_fold_func (gpointer g, gpointer a, gpointer self) {
	gpointer result;
	result = (gpointer) ((gintptr) __lambda19_ (self, (gchar*) g, (gint) ((gintptr) a)));
	return result;
}


static gint __lambda20_ (Block3Data* _data3_, gchar* x, gint y) {
	CollectionTests* self;
	gint result = 0;
	GeeIterator* _tmp0_ = NULL;
	gboolean _tmp1_ = FALSE;
	const gchar* _tmp2_ = NULL;
	GeeIterator* _tmp3_ = NULL;
	gpointer _tmp4_ = NULL;
	gchar* _tmp5_ = NULL;
	gint _tmp6_ = 0;
	self = _data3_->self;
	g_return_val_if_fail (x != NULL, 0);
	_tmp0_ = _data3_->test_iterator;
	_tmp1_ = gee_iterator_next (_tmp0_);
	_vala_assert (_tmp1_, "test_iterator.next ()");
	_tmp2_ = x;
	_tmp3_ = _data3_->test_iterator;
	_tmp4_ = gee_iterator_get (_tmp3_);
	_tmp5_ = (gchar*) _tmp4_;
	_vala_assert (g_strcmp0 (_tmp2_, _tmp5_) == 0, "x == test_iterator.get ()");
	_g_free0 (_tmp5_);
	_tmp6_ = y;
	result = _tmp6_ + 1;
	_g_free0 (x);
	return result;
}


static gpointer ___lambda20__gee_fold_func (gpointer g, gpointer a, gpointer self) {
	gpointer result;
	result = (gpointer) ((gintptr) __lambda20_ (self, (gchar*) g, (gint) ((gintptr) a)));
	return result;
}


void collection_tests_test_fold (CollectionTests* self) {
	Block3Data* _data3_;
	gint count = 0;
	gchar** data = NULL;
	gint _tmp0_ = 0;
	gchar** _tmp1_ = NULL;
	gint data_length1 = 0;
	gint _data_size_ = 0;
	GeeCollection* _tmp2_ = NULL;
	gpointer _tmp3_ = NULL;
	GeeCollection* _tmp4_ = NULL;
	GeeIterator* _tmp5_ = NULL;
	GeeIterator* _tmp6_ = NULL;
	gpointer _tmp7_ = NULL;
	gchar** _tmp8_ = NULL;
	gint _tmp8__length1 = 0;
	GeeCollection* _tmp12_ = NULL;
	GeeIterator* _tmp13_ = NULL;
	GeeCollection* _tmp14_ = NULL;
	gpointer _tmp15_ = NULL;
	gint _tmp16_ = 0;
	gchar** _tmp17_ = NULL;
	gint _tmp17__length1 = 0;
	GeeCollection* _tmp18_ = NULL;
	GeeIterator* _tmp19_ = NULL;
	GeeCollection* _tmp20_ = NULL;
	GeeIterator* _tmp21_ = NULL;
	GeeIterator* _tmp22_ = NULL;
	gpointer _tmp23_ = NULL;
	gint _tmp24_ = 0;
	gchar** _tmp25_ = NULL;
	gint _tmp25__length1 = 0;
	GeeCollection* _tmp26_ = NULL;
	GeeIterator* _tmp27_ = NULL;
	GeeIterator* iter = NULL;
	GeeCollection* _tmp28_ = NULL;
	GeeIterator* _tmp29_ = NULL;
	GeeIterator* _tmp30_ = NULL;
	gboolean _tmp31_ = FALSE;
	GeeIterator* _tmp32_ = NULL;
	gboolean _tmp33_ = FALSE;
	GeeIterator* _tmp34_ = NULL;
	gboolean _tmp35_ = FALSE;
	GeeIterator* _tmp36_ = NULL;
	gpointer _tmp37_ = NULL;
	gint _tmp38_ = 0;
	gchar** _tmp39_ = NULL;
	gint _tmp39__length1 = 0;
	GeeCollection* _tmp40_ = NULL;
	GeeIterator* _tmp41_ = NULL;
	GeeCollection* _tmp42_ = NULL;
	GeeIterator* _tmp43_ = NULL;
	GeeIterator* _tmp44_ = NULL;
	gboolean _tmp45_ = FALSE;
	GeeIterator* _tmp46_ = NULL;
	gboolean _tmp47_ = FALSE;
	GeeIterator* _tmp48_ = NULL;
	gboolean _tmp49_ = FALSE;
	GeeIterator* _tmp50_ = NULL;
	gboolean _tmp51_ = FALSE;
	GeeIterator* _tmp52_ = NULL;
	gpointer _tmp53_ = NULL;
	gint _tmp54_ = 0;
	gchar** _tmp55_ = NULL;
	gint _tmp55__length1 = 0;
	g_return_if_fail (self != NULL);
	_data3_ = g_slice_new0 (Block3Data);
	_data3_->_ref_count_ = 1;
	_data3_->self = g_object_ref (self);
	_tmp1_ = test_data_get_data (&_tmp0_);
	data = _tmp1_;
	data_length1 = _tmp0_;
	_data_size_ = data_length1;
	_tmp2_ = self->test_collection;
	_tmp3_ = gee_traversable_fold ((GeeTraversable*) _tmp2_, G_TYPE_INT, NULL, NULL, ___lambda15__gee_fold_func, self, (gpointer) ((gintptr) 0));
	count = (gint) ((gintptr) _tmp3_);
	_tmp4_ = self->test_collection;
	_tmp5_ = gee_iterable_iterator ((GeeIterable*) _tmp4_);
	_tmp6_ = _tmp5_;
	_tmp7_ = gee_traversable_fold ((GeeTraversable*) _tmp6_, G_TYPE_INT, NULL, NULL, ___lambda16__gee_fold_func, self, (gpointer) ((gintptr) 0));
	count = (gint) ((gintptr) _tmp7_);
	_g_object_unref0 (_tmp6_);
	_tmp8_ = data;
	_tmp8__length1 = data_length1;
	{
		gchar** el_collection = NULL;
		gint el_collection_length1 = 0;
		gint _el_collection_size_ = 0;
		gint el_it = 0;
		el_collection = _tmp8_;
		el_collection_length1 = _tmp8__length1;
		for (el_it = 0; el_it < _tmp8__length1; el_it = el_it + 1) {
			const gchar* el = NULL;
			el = el_collection[el_it];
			{
				GeeCollection* _tmp9_ = NULL;
				const gchar* _tmp10_ = NULL;
				gboolean _tmp11_ = FALSE;
				_tmp9_ = self->test_collection;
				_tmp10_ = el;
				_tmp11_ = gee_collection_add (_tmp9_, _tmp10_);
				_vala_assert (_tmp11_, "test_collection.add (el)");
			}
		}
	}
	_tmp12_ = self->test_collection;
	_tmp13_ = gee_iterable_iterator ((GeeIterable*) _tmp12_);
	_data3_->test_iterator = _tmp13_;
	_tmp14_ = self->test_collection;
	_tmp15_ = gee_traversable_fold ((GeeTraversable*) _tmp14_, G_TYPE_INT, NULL, NULL, ___lambda17__gee_fold_func, _data3_, (gpointer) ((gintptr) 0));
	count = (gint) ((gintptr) _tmp15_);
	_tmp16_ = count;
	_tmp17_ = data;
	_tmp17__length1 = data_length1;
	_vala_assert (_tmp16_ == _tmp17__length1, "count == data.length");
	_tmp18_ = self->test_collection;
	_tmp19_ = gee_iterable_iterator ((GeeIterable*) _tmp18_);
	_g_object_unref0 (_data3_->test_iterator);
	_data3_->test_iterator = _tmp19_;
	_tmp20_ = self->test_collection;
	_tmp21_ = gee_iterable_iterator ((GeeIterable*) _tmp20_);
	_tmp22_ = _tmp21_;
	_tmp23_ = gee_traversable_fold ((GeeTraversable*) _tmp22_, G_TYPE_INT, NULL, NULL, ___lambda18__gee_fold_func, _data3_, (gpointer) ((gintptr) 0));
	count = (gint) ((gintptr) _tmp23_);
	_g_object_unref0 (_tmp22_);
	_tmp24_ = count;
	_tmp25_ = data;
	_tmp25__length1 = data_length1;
	_vala_assert (_tmp24_ == _tmp25__length1, "count == data.length");
	_tmp26_ = self->test_collection;
	_tmp27_ = gee_iterable_iterator ((GeeIterable*) _tmp26_);
	_g_object_unref0 (_data3_->test_iterator);
	_data3_->test_iterator = _tmp27_;
	_tmp28_ = self->test_collection;
	_tmp29_ = gee_iterable_iterator ((GeeIterable*) _tmp28_);
	iter = _tmp29_;
	_tmp30_ = iter;
	_tmp31_ = gee_iterator_next (_tmp30_);
	_vala_assert (_tmp31_, "iter.next ()");
	_tmp32_ = iter;
	_tmp33_ = gee_iterator_next (_tmp32_);
	_vala_assert (_tmp33_, "iter.next ()");
	_tmp34_ = _data3_->test_iterator;
	_tmp35_ = gee_iterator_next (_tmp34_);
	_vala_assert (_tmp35_, "test_iterator.next ()");
	_tmp36_ = iter;
	_tmp37_ = gee_traversable_fold ((GeeTraversable*) _tmp36_, G_TYPE_INT, NULL, NULL, ___lambda19__gee_fold_func, _data3_, (gpointer) ((gintptr) 1));
	count = (gint) ((gintptr) _tmp37_);
	_tmp38_ = count;
	_tmp39_ = data;
	_tmp39__length1 = data_length1;
	_vala_assert (_tmp38_ == _tmp39__length1, "count == data.length");
	_tmp40_ = self->test_collection;
	_tmp41_ = gee_iterable_iterator ((GeeIterable*) _tmp40_);
	_g_object_unref0 (_data3_->test_iterator);
	_data3_->test_iterator = _tmp41_;
	_tmp42_ = self->test_collection;
	_tmp43_ = gee_iterable_iterator ((GeeIterable*) _tmp42_);
	_g_object_unref0 (iter);
	iter = _tmp43_;
	_tmp44_ = iter;
	_tmp45_ = gee_iterator_next (_tmp44_);
	_vala_assert (_tmp45_, "iter.next ()");
	_tmp46_ = iter;
	_tmp47_ = gee_iterator_next (_tmp46_);
	_vala_assert (_tmp47_, "iter.next ()");
	_tmp48_ = iter;
	_tmp49_ = gee_iterator_has_next (_tmp48_);
	_vala_assert (_tmp49_, "iter.has_next ()");
	_tmp50_ = _data3_->test_iterator;
	_tmp51_ = gee_iterator_next (_tmp50_);
	_vala_assert (_tmp51_, "test_iterator.next ()");
	_tmp52_ = iter;
	_tmp53_ = gee_traversable_fold ((GeeTraversable*) _tmp52_, G_TYPE_INT, NULL, NULL, ___lambda20__gee_fold_func, _data3_, (gpointer) ((gintptr) 1));
	count = (gint) ((gintptr) _tmp53_);
	_tmp54_ = count;
	_tmp55_ = data;
	_tmp55__length1 = data_length1;
	_vala_assert (_tmp54_ == _tmp55__length1, "count == data.length");
	_g_object_unref0 (iter);
	block3_data_unref (_data3_);
	_data3_ = NULL;
}


static Block4Data* block4_data_ref (Block4Data* _data4_) {
	g_atomic_int_inc (&_data4_->_ref_count_);
	return _data4_;
}


static void block4_data_unref (void * _userdata_) {
	Block4Data* _data4_;
	_data4_ = (Block4Data*) _userdata_;
	if (g_atomic_int_dec_and_test (&_data4_->_ref_count_)) {
		CollectionTests* self;
		self = _data4_->self;
		_g_object_unref0 (_data4_->test_iterator);
		_g_object_unref0 (_data4_->iter);
		_g_object_unref0 (self);
		g_slice_free (Block4Data, _data4_);
	}
}


static gint __lambda21_ (CollectionTests* self, gchar* str) {
	gint result = 0;
	g_return_val_if_fail (str != NULL, 0);
	g_assert_not_reached ();
	_g_free0 (str);
	return result;
}


static gpointer ___lambda21__gee_map_func (gpointer g, gpointer self) {
	gpointer result;
	result = (gpointer) ((gintptr) __lambda21_ ((CollectionTests*) self, (gchar*) g));
	return result;
}


static gint __lambda22_ (CollectionTests* self, gchar* str) {
	gint result = 0;
	g_return_val_if_fail (str != NULL, 0);
	g_assert_not_reached ();
	_g_free0 (str);
	return result;
}


static gpointer ___lambda22__gee_map_func (gpointer g, gpointer self) {
	gpointer result;
	result = (gpointer) ((gintptr) __lambda22_ ((CollectionTests*) self, (gchar*) g));
	return result;
}


static gint __lambda23_ (Block4Data* _data4_, gchar* str) {
	CollectionTests* self;
	gint result = 0;
	GeeIterator* _tmp0_ = NULL;
	gboolean _tmp1_ = FALSE;
	const gchar* _tmp2_ = NULL;
	GeeIterator* _tmp3_ = NULL;
	gpointer _tmp4_ = NULL;
	gchar* _tmp5_ = NULL;
	gint _tmp6_ = 0;
	self = _data4_->self;
	g_return_val_if_fail (str != NULL, 0);
	_tmp0_ = _data4_->test_iterator;
	_tmp1_ = gee_iterator_next (_tmp0_);
	_vala_assert (_tmp1_, "test_iterator.next ()");
	_tmp2_ = str;
	_tmp3_ = _data4_->test_iterator;
	_tmp4_ = gee_iterator_get (_tmp3_);
	_tmp5_ = (gchar*) _tmp4_;
	_vala_assert (g_strcmp0 (_tmp2_, _tmp5_) == 0, "str == test_iterator.get ()");
	_g_free0 (_tmp5_);
	_tmp6_ = _data4_->i;
	_data4_->i = _tmp6_ + 1;
	result = _tmp6_;
	_g_free0 (str);
	return result;
}


static gpointer ___lambda23__gee_map_func (gpointer g, gpointer self) {
	gpointer result;
	result = (gpointer) ((gintptr) __lambda23_ (self, (gchar*) g));
	return result;
}


static gboolean __lambda24_ (Block4Data* _data4_, gchar* str) {
	CollectionTests* self;
	gboolean result = FALSE;
	gint _tmp0_ = 0;
	gint _tmp1_ = 0;
	GeeIterator* _tmp2_ = NULL;
	gboolean _tmp3_ = FALSE;
	gint _tmp4_ = 0;
	gint _tmp5_ = 0;
	GeeIterator* _tmp6_ = NULL;
	gboolean _tmp7_ = FALSE;
	GeeIterator* _tmp8_ = NULL;
	gboolean _tmp9_ = FALSE;
	gboolean _tmp10_ = FALSE;
	gint _tmp11_ = 0;
	GeeIterator* _tmp12_ = NULL;
	gpointer _tmp13_ = NULL;
	gint _tmp14_ = 0;
	gint _tmp15_ = 0;
	gint _tmp16_ = 0;
	self = _data4_->self;
	g_return_val_if_fail (str != NULL, FALSE);
	_tmp0_ = _data4_->j;
	_tmp1_ = _data4_->i;
	_vala_assert (_tmp0_ == _tmp1_, "j == i");
	_tmp2_ = _data4_->iter;
	_tmp3_ = gee_iterator_has_next (_tmp2_);
	_vala_assert (_tmp3_, "iter.has_next ()");
	_tmp4_ = _data4_->j;
	_tmp5_ = _data4_->i;
	_vala_assert (_tmp4_ == _tmp5_, "j == i");
	_tmp6_ = _data4_->iter;
	_tmp7_ = gee_iterator_next (_tmp6_);
	_vala_assert (_tmp7_, "iter.next ()");
	_tmp8_ = _data4_->iter;
	_tmp9_ = gee_iterator_get_valid (_tmp8_);
	_tmp10_ = _tmp9_;
	_vala_assert (_tmp10_, "iter.valid");
	_tmp11_ = _data4_->j;
	_tmp12_ = _data4_->iter;
	_tmp13_ = gee_iterator_get (_tmp12_);
	_vala_assert (_tmp11_ == ((gint) ((gintptr) _tmp13_)), "j == iter.get ()");
	_tmp14_ = _data4_->j;
	_data4_->j = _tmp14_ + 1;
	_tmp15_ = _data4_->j;
	_tmp16_ = _data4_->i;
	_vala_assert (_tmp15_ == _tmp16_, "++j == i");
	result = TRUE;
	_g_free0 (str);
	return result;
}


static gboolean ___lambda24__gee_forall_func (gpointer g, gpointer self) {
	gboolean result;
	result = __lambda24_ (self, (gchar*) g);
	return result;
}


static gint __lambda25_ (Block4Data* _data4_, gchar* str) {
	CollectionTests* self;
	gint result = 0;
	GeeIterator* _tmp0_ = NULL;
	gboolean _tmp1_ = FALSE;
	const gchar* _tmp2_ = NULL;
	GeeIterator* _tmp3_ = NULL;
	gpointer _tmp4_ = NULL;
	gchar* _tmp5_ = NULL;
	gint _tmp6_ = 0;
	self = _data4_->self;
	g_return_val_if_fail (str != NULL, 0);
	_tmp0_ = _data4_->test_iterator;
	_tmp1_ = gee_iterator_next (_tmp0_);
	_vala_assert (_tmp1_, "test_iterator.next ()");
	_tmp2_ = str;
	_tmp3_ = _data4_->test_iterator;
	_tmp4_ = gee_iterator_get (_tmp3_);
	_tmp5_ = (gchar*) _tmp4_;
	_vala_assert (g_strcmp0 (_tmp2_, _tmp5_) == 0, "str == test_iterator.get ()");
	_g_free0 (_tmp5_);
	_tmp6_ = _data4_->i;
	_data4_->i = _tmp6_ + 1;
	result = _tmp6_;
	_g_free0 (str);
	return result;
}


static gpointer ___lambda25__gee_map_func (gpointer g, gpointer self) {
	gpointer result;
	result = (gpointer) ((gintptr) __lambda25_ (self, (gchar*) g));
	return result;
}


static gboolean __lambda26_ (Block4Data* _data4_, gchar* str) {
	CollectionTests* self;
	gboolean result = FALSE;
	gint _tmp0_ = 0;
	gint _tmp1_ = 0;
	GeeIterator* _tmp2_ = NULL;
	gboolean _tmp3_ = FALSE;
	gint _tmp4_ = 0;
	gint _tmp5_ = 0;
	GeeIterator* _tmp6_ = NULL;
	gboolean _tmp7_ = FALSE;
	gboolean _tmp8_ = FALSE;
	GeeIterator* _tmp10_ = NULL;
	gboolean _tmp11_ = FALSE;
	GeeIterator* _tmp12_ = NULL;
	gboolean _tmp13_ = FALSE;
	gboolean _tmp14_ = FALSE;
	gint _tmp15_ = 0;
	gint _tmp16_ = 0;
	self = _data4_->self;
	g_return_val_if_fail (str != NULL, FALSE);
	_tmp0_ = _data4_->j;
	_tmp1_ = _data4_->i;
	_vala_assert (_tmp0_ == _tmp1_, "j == i");
	_tmp2_ = _data4_->iter;
	_tmp3_ = gee_iterator_has_next (_tmp2_);
	_vala_assert (_tmp3_, "iter.has_next ()");
	_tmp4_ = _data4_->j;
	_tmp5_ = _data4_->i;
	_vala_assert (_tmp4_ == _tmp5_, "j == i");
	_tmp6_ = _data4_->iter;
	_tmp7_ = gee_iterator_get_valid (_tmp6_);
	_tmp8_ = _tmp7_;
	if (_tmp8_) {
		gint _tmp9_ = 0;
		_tmp9_ = _data4_->j;
		_data4_->j = _tmp9_ + 1;
	}
	_tmp10_ = _data4_->iter;
	_tmp11_ = gee_iterator_next (_tmp10_);
	_vala_assert (_tmp11_, "iter.next ()");
	_tmp12_ = _data4_->iter;
	_tmp13_ = gee_iterator_get_valid (_tmp12_);
	_tmp14_ = _tmp13_;
	_vala_assert (_tmp14_, "iter.valid");
	_tmp15_ = _data4_->j;
	_tmp16_ = _data4_->i;
	_vala_assert (_tmp15_ == _tmp16_, "j == i");
	result = TRUE;
	_g_free0 (str);
	return result;
}


static gboolean ___lambda26__gee_forall_func (gpointer g, gpointer self) {
	gboolean result;
	result = __lambda26_ (self, (gchar*) g);
	return result;
}


static gint __lambda27_ (Block4Data* _data4_, gchar* str) {
	CollectionTests* self;
	gint result = 0;
	GeeIterator* _tmp0_ = NULL;
	gboolean _tmp1_ = FALSE;
	const gchar* _tmp2_ = NULL;
	GeeIterator* _tmp3_ = NULL;
	gpointer _tmp4_ = NULL;
	gchar* _tmp5_ = NULL;
	gint _tmp6_ = 0;
	self = _data4_->self;
	g_return_val_if_fail (str != NULL, 0);
	_tmp0_ = _data4_->test_iterator;
	_tmp1_ = gee_iterator_next (_tmp0_);
	_vala_assert (_tmp1_, "test_iterator.next ()");
	_tmp2_ = str;
	_tmp3_ = _data4_->test_iterator;
	_tmp4_ = gee_iterator_get (_tmp3_);
	_tmp5_ = (gchar*) _tmp4_;
	_vala_assert (g_strcmp0 (_tmp2_, _tmp5_) == 0, "str == test_iterator.get ()");
	_g_free0 (_tmp5_);
	_tmp6_ = _data4_->i;
	_data4_->i = _tmp6_ + 1;
	result = _tmp6_;
	_g_free0 (str);
	return result;
}


static gpointer ___lambda27__gee_map_func (gpointer g, gpointer self) {
	gpointer result;
	result = (gpointer) ((gintptr) __lambda27_ (self, (gchar*) g));
	return result;
}


static gboolean __lambda28_ (Block4Data* _data4_, gchar* str) {
	CollectionTests* self;
	gboolean result = FALSE;
	gint _tmp0_ = 0;
	gint _tmp1_ = 0;
	GeeIterator* _tmp2_ = NULL;
	gboolean _tmp3_ = FALSE;
	gint _tmp4_ = 0;
	gint _tmp5_ = 0;
	GeeIterator* _tmp6_ = NULL;
	gboolean _tmp7_ = FALSE;
	GeeIterator* _tmp8_ = NULL;
	gboolean _tmp9_ = FALSE;
	gboolean _tmp10_ = FALSE;
	gint _tmp11_ = 0;
	GeeIterator* _tmp12_ = NULL;
	gpointer _tmp13_ = NULL;
	gint _tmp14_ = 0;
	gint _tmp15_ = 0;
	gint _tmp16_ = 0;
	self = _data4_->self;
	g_return_val_if_fail (str != NULL, FALSE);
	_tmp0_ = _data4_->j;
	_tmp1_ = _data4_->i;
	_vala_assert (_tmp0_ == _tmp1_, "j == i");
	_tmp2_ = _data4_->iter;
	_tmp3_ = gee_iterator_has_next (_tmp2_);
	_vala_assert (_tmp3_, "iter.has_next ()");
	_tmp4_ = _data4_->j;
	_tmp5_ = _data4_->i;
	_vala_assert (_tmp4_ == _tmp5_, "j == i");
	_tmp6_ = _data4_->iter;
	_tmp7_ = gee_iterator_next (_tmp6_);
	_vala_assert (_tmp7_, "iter.next ()");
	_tmp8_ = _data4_->iter;
	_tmp9_ = gee_iterator_get_valid (_tmp8_);
	_tmp10_ = _tmp9_;
	_vala_assert (_tmp10_, "iter.valid");
	_tmp11_ = _data4_->j;
	_tmp12_ = _data4_->iter;
	_tmp13_ = gee_iterator_get (_tmp12_);
	_vala_assert (_tmp11_ == ((gint) ((gintptr) _tmp13_)), "j == iter.get ()");
	_tmp14_ = _data4_->j;
	_data4_->j = _tmp14_ + 1;
	_tmp15_ = _data4_->j;
	_tmp16_ = _data4_->i;
	_vala_assert (_tmp15_ == _tmp16_, "++j == i");
	result = TRUE;
	_g_free0 (str);
	return result;
}


static gboolean ___lambda28__gee_forall_func (gpointer g, gpointer self) {
	gboolean result;
	result = __lambda28_ (self, (gchar*) g);
	return result;
}


static gint __lambda29_ (Block4Data* _data4_, gchar* str) {
	CollectionTests* self;
	gint result = 0;
	GeeIterator* _tmp0_ = NULL;
	gboolean _tmp1_ = FALSE;
	const gchar* _tmp2_ = NULL;
	GeeIterator* _tmp3_ = NULL;
	gpointer _tmp4_ = NULL;
	gchar* _tmp5_ = NULL;
	gint _tmp6_ = 0;
	self = _data4_->self;
	g_return_val_if_fail (str != NULL, 0);
	_tmp0_ = _data4_->test_iterator;
	_tmp1_ = gee_iterator_next (_tmp0_);
	_vala_assert (_tmp1_, "test_iterator.next ()");
	_tmp2_ = str;
	_tmp3_ = _data4_->test_iterator;
	_tmp4_ = gee_iterator_get (_tmp3_);
	_tmp5_ = (gchar*) _tmp4_;
	_vala_assert (g_strcmp0 (_tmp2_, _tmp5_) == 0, "str == test_iterator.get ()");
	_g_free0 (_tmp5_);
	_tmp6_ = _data4_->i;
	_data4_->i = _tmp6_ + 1;
	result = _tmp6_;
	_g_free0 (str);
	return result;
}


static gpointer ___lambda29__gee_map_func (gpointer g, gpointer self) {
	gpointer result;
	result = (gpointer) ((gintptr) __lambda29_ (self, (gchar*) g));
	return result;
}


static gboolean __lambda30_ (Block4Data* _data4_, gchar* str) {
	CollectionTests* self;
	gboolean result = FALSE;
	gint _tmp0_ = 0;
	gint _tmp1_ = 0;
	GeeIterator* _tmp2_ = NULL;
	gboolean _tmp3_ = FALSE;
	gint _tmp4_ = 0;
	gint _tmp5_ = 0;
	GeeIterator* _tmp6_ = NULL;
	gboolean _tmp7_ = FALSE;
	gboolean _tmp8_ = FALSE;
	GeeIterator* _tmp10_ = NULL;
	gboolean _tmp11_ = FALSE;
	GeeIterator* _tmp12_ = NULL;
	gboolean _tmp13_ = FALSE;
	gboolean _tmp14_ = FALSE;
	gint _tmp15_ = 0;
	gint _tmp16_ = 0;
	self = _data4_->self;
	g_return_val_if_fail (str != NULL, FALSE);
	_tmp0_ = _data4_->j;
	_tmp1_ = _data4_->i;
	_vala_assert (_tmp0_ == _tmp1_, "j == i");
	_tmp2_ = _data4_->iter;
	_tmp3_ = gee_iterator_has_next (_tmp2_);
	_vala_assert (_tmp3_, "iter.has_next ()");
	_tmp4_ = _data4_->j;
	_tmp5_ = _data4_->i;
	_vala_assert (_tmp4_ == _tmp5_, "j == i");
	_tmp6_ = _data4_->iter;
	_tmp7_ = gee_iterator_get_valid (_tmp6_);
	_tmp8_ = _tmp7_;
	if (_tmp8_) {
		gint _tmp9_ = 0;
		_tmp9_ = _data4_->j;
		_data4_->j = _tmp9_ + 1;
	}
	_tmp10_ = _data4_->iter;
	_tmp11_ = gee_iterator_next (_tmp10_);
	_vala_assert (_tmp11_, "iter.next ()");
	_tmp12_ = _data4_->iter;
	_tmp13_ = gee_iterator_get_valid (_tmp12_);
	_tmp14_ = _tmp13_;
	_vala_assert (_tmp14_, "iter.valid");
	_tmp15_ = _data4_->j;
	_tmp16_ = _data4_->i;
	_vala_assert (_tmp15_ == _tmp16_, "j == i");
	result = TRUE;
	_g_free0 (str);
	return result;
}


static gboolean ___lambda30__gee_forall_func (gpointer g, gpointer self) {
	gboolean result;
	result = __lambda30_ (self, (gchar*) g);
	return result;
}


static gint __lambda31_ (Block4Data* _data4_, gchar* str) {
	CollectionTests* self;
	gint result = 0;
	GeeIterator* _tmp0_ = NULL;
	gboolean _tmp1_ = FALSE;
	const gchar* _tmp2_ = NULL;
	GeeIterator* _tmp3_ = NULL;
	gpointer _tmp4_ = NULL;
	gchar* _tmp5_ = NULL;
	gint _tmp6_ = 0;
	self = _data4_->self;
	g_return_val_if_fail (str != NULL, 0);
	_tmp0_ = _data4_->test_iterator;
	_tmp1_ = gee_iterator_next (_tmp0_);
	_vala_assert (_tmp1_, "test_iterator.next ()");
	_tmp2_ = str;
	_tmp3_ = _data4_->test_iterator;
	_tmp4_ = gee_iterator_get (_tmp3_);
	_tmp5_ = (gchar*) _tmp4_;
	_vala_assert (g_strcmp0 (_tmp2_, _tmp5_) == 0, "str == test_iterator.get ()");
	_g_free0 (_tmp5_);
	_tmp6_ = _data4_->i;
	_data4_->i = _tmp6_ + 1;
	result = _tmp6_;
	_g_free0 (str);
	return result;
}


static gpointer ___lambda31__gee_map_func (gpointer g, gpointer self) {
	gpointer result;
	result = (gpointer) ((gintptr) __lambda31_ (self, (gchar*) g));
	return result;
}


static gint __lambda32_ (Block4Data* _data4_, gchar* str) {
	CollectionTests* self;
	gint result = 0;
	GeeIterator* _tmp0_ = NULL;
	gboolean _tmp1_ = FALSE;
	const gchar* _tmp2_ = NULL;
	GeeIterator* _tmp3_ = NULL;
	gpointer _tmp4_ = NULL;
	gchar* _tmp5_ = NULL;
	gint _tmp6_ = 0;
	self = _data4_->self;
	g_return_val_if_fail (str != NULL, 0);
	_tmp0_ = _data4_->test_iterator;
	_tmp1_ = gee_iterator_next (_tmp0_);
	_vala_assert (_tmp1_, "test_iterator.next ()");
	_tmp2_ = str;
	_tmp3_ = _data4_->test_iterator;
	_tmp4_ = gee_iterator_get (_tmp3_);
	_tmp5_ = (gchar*) _tmp4_;
	_vala_assert (g_strcmp0 (_tmp2_, _tmp5_) == 0, "str == test_iterator.get ()");
	_g_free0 (_tmp5_);
	_tmp6_ = _data4_->i;
	_data4_->i = _tmp6_ + 1;
	result = _tmp6_;
	_g_free0 (str);
	return result;
}


static gpointer ___lambda32__gee_map_func (gpointer g, gpointer self) {
	gpointer result;
	result = (gpointer) ((gintptr) __lambda32_ (self, (gchar*) g));
	return result;
}


void collection_tests_test_map (CollectionTests* self) {
	Block4Data* _data4_;
	gchar** data = NULL;
	gint _tmp0_ = 0;
	gchar** _tmp1_ = NULL;
	gint data_length1 = 0;
	gint _data_size_ = 0;
	GeeCollection* _tmp2_ = NULL;
	GeeIterator* _tmp3_ = NULL;
	GeeIterator* _tmp4_ = NULL;
	gboolean _tmp5_ = FALSE;
	gboolean _tmp6_ = FALSE;
	GeeIterator* _tmp7_ = NULL;
	gboolean _tmp8_ = FALSE;
	GeeIterator* _tmp9_ = NULL;
	gboolean _tmp10_ = FALSE;
	GeeCollection* _tmp11_ = NULL;
	GeeIterator* _tmp12_ = NULL;
	GeeIterator* _tmp13_ = NULL;
	GeeIterator* _tmp14_ = NULL;
	GeeIterator* _tmp15_ = NULL;
	gboolean _tmp16_ = FALSE;
	gboolean _tmp17_ = FALSE;
	GeeIterator* _tmp18_ = NULL;
	gboolean _tmp19_ = FALSE;
	GeeIterator* _tmp20_ = NULL;
	gboolean _tmp21_ = FALSE;
	gchar** _tmp22_ = NULL;
	gint _tmp22__length1 = 0;
	GeeCollection* _tmp26_ = NULL;
	GeeIterator* _tmp27_ = NULL;
	GeeCollection* _tmp28_ = NULL;
	GeeIterator* _tmp29_ = NULL;
	GeeIterator* _tmp30_ = NULL;
	gboolean _tmp31_ = FALSE;
	gboolean _tmp32_ = FALSE;
	GeeCollection* _tmp33_ = NULL;
	GeeIterator* _tmp34_ = NULL;
	gboolean _tmp35_ = FALSE;
	GeeIterator* _tmp36_ = NULL;
	gboolean _tmp37_ = FALSE;
	GeeCollection* _tmp38_ = NULL;
	GeeIterator* _tmp39_ = NULL;
	GeeCollection* _tmp40_ = NULL;
	GeeIterator* _tmp41_ = NULL;
	GeeIterator* _tmp42_ = NULL;
	gboolean _tmp43_ = FALSE;
	gboolean _tmp44_ = FALSE;
	GeeCollection* _tmp45_ = NULL;
	GeeIterator* _tmp46_ = NULL;
	gboolean _tmp47_ = FALSE;
	GeeIterator* _tmp48_ = NULL;
	gboolean _tmp49_ = FALSE;
	GeeCollection* _tmp50_ = NULL;
	GeeIterator* _tmp51_ = NULL;
	GeeIterator* outer_iter = NULL;
	GeeCollection* _tmp52_ = NULL;
	GeeIterator* _tmp53_ = NULL;
	GeeIterator* _tmp54_ = NULL;
	GeeIterator* _tmp55_ = NULL;
	GeeIterator* _tmp56_ = NULL;
	gboolean _tmp57_ = FALSE;
	gboolean _tmp58_ = FALSE;
	GeeCollection* _tmp59_ = NULL;
	GeeIterator* _tmp60_ = NULL;
	gboolean _tmp61_ = FALSE;
	GeeIterator* _tmp62_ = NULL;
	gboolean _tmp63_ = FALSE;
	GeeCollection* _tmp64_ = NULL;
	GeeIterator* _tmp65_ = NULL;
	GeeCollection* _tmp66_ = NULL;
	GeeIterator* _tmp67_ = NULL;
	GeeIterator* _tmp68_ = NULL;
	GeeIterator* _tmp69_ = NULL;
	GeeIterator* _tmp70_ = NULL;
	gboolean _tmp71_ = FALSE;
	gboolean _tmp72_ = FALSE;
	GeeCollection* _tmp73_ = NULL;
	GeeIterator* _tmp74_ = NULL;
	gboolean _tmp75_ = FALSE;
	GeeIterator* _tmp76_ = NULL;
	gboolean _tmp77_ = FALSE;
	GeeCollection* _tmp78_ = NULL;
	GeeIterator* _tmp79_ = NULL;
	GeeCollection* _tmp80_ = NULL;
	GeeIterator* _tmp81_ = NULL;
	GeeIterator* outer_iter2 = NULL;
	GeeCollection* _tmp82_ = NULL;
	GeeIterator* _tmp83_ = NULL;
	GeeIterator* _tmp84_ = NULL;
	gboolean _tmp85_ = FALSE;
	GeeIterator* _tmp86_ = NULL;
	gboolean _tmp87_ = FALSE;
	GeeIterator* _tmp88_ = NULL;
	gboolean _tmp89_ = FALSE;
	GeeIterator* _tmp90_ = NULL;
	gboolean _tmp91_ = FALSE;
	GeeIterator* _tmp92_ = NULL;
	gboolean _tmp93_ = FALSE;
	GeeIterator* _tmp94_ = NULL;
	GeeIterator* _tmp95_ = NULL;
	GeeIterator* _tmp96_ = NULL;
	gboolean _tmp97_ = FALSE;
	gboolean _tmp98_ = FALSE;
	GeeIterator* _tmp123_ = NULL;
	gboolean _tmp124_ = FALSE;
	GeeIterator* _tmp125_ = NULL;
	gboolean _tmp126_ = FALSE;
	GeeCollection* _tmp127_ = NULL;
	GeeIterator* _tmp128_ = NULL;
	GeeCollection* _tmp129_ = NULL;
	GeeIterator* _tmp130_ = NULL;
	GeeCollection* _tmp131_ = NULL;
	GeeIterator* _tmp132_ = NULL;
	GeeIterator* _tmp133_ = NULL;
	gboolean _tmp134_ = FALSE;
	GeeIterator* _tmp135_ = NULL;
	gboolean _tmp136_ = FALSE;
	GeeIterator* _tmp137_ = NULL;
	gboolean _tmp138_ = FALSE;
	GeeIterator* _tmp139_ = NULL;
	gboolean _tmp140_ = FALSE;
	GeeIterator* _tmp141_ = NULL;
	gboolean _tmp142_ = FALSE;
	GeeIterator* _tmp143_ = NULL;
	GeeIterator* _tmp144_ = NULL;
	GeeIterator* _tmp145_ = NULL;
	gboolean _tmp146_ = FALSE;
	gboolean _tmp147_ = FALSE;
	GeeIterator* _tmp167_ = NULL;
	gboolean _tmp168_ = FALSE;
	GeeIterator* _tmp169_ = NULL;
	gboolean _tmp170_ = FALSE;
	g_return_if_fail (self != NULL);
	_data4_ = g_slice_new0 (Block4Data);
	_data4_->_ref_count_ = 1;
	_data4_->self = g_object_ref (self);
	_tmp1_ = test_data_get_data (&_tmp0_);
	data = _tmp1_;
	data_length1 = _tmp0_;
	_data_size_ = data_length1;
	_tmp2_ = self->test_collection;
	_tmp3_ = gee_traversable_map ((GeeTraversable*) _tmp2_, G_TYPE_INT, NULL, NULL, ___lambda21__gee_map_func, self);
	_data4_->iter = _tmp3_;
	_tmp4_ = _data4_->iter;
	_tmp5_ = gee_iterator_get_valid (_tmp4_);
	_tmp6_ = _tmp5_;
	_vala_assert (!_tmp6_, "!iter.valid");
	_tmp7_ = _data4_->iter;
	_tmp8_ = gee_iterator_has_next (_tmp7_);
	_vala_assert (!_tmp8_, "!iter.has_next ()");
	_tmp9_ = _data4_->iter;
	_tmp10_ = gee_iterator_next (_tmp9_);
	_vala_assert (!_tmp10_, "!iter.next ()");
	_tmp11_ = self->test_collection;
	_tmp12_ = gee_iterable_iterator ((GeeIterable*) _tmp11_);
	_tmp13_ = _tmp12_;
	_tmp14_ = gee_traversable_map ((GeeTraversable*) _tmp13_, G_TYPE_INT, NULL, NULL, ___lambda22__gee_map_func, self);
	_g_object_unref0 (_data4_->iter);
	_data4_->iter = _tmp14_;
	_g_object_unref0 (_tmp13_);
	_tmp15_ = _data4_->iter;
	_tmp16_ = gee_iterator_get_valid (_tmp15_);
	_tmp17_ = _tmp16_;
	_vala_assert (!_tmp17_, "!iter.valid");
	_tmp18_ = _data4_->iter;
	_tmp19_ = gee_iterator_has_next (_tmp18_);
	_vala_assert (!_tmp19_, "!iter.has_next ()");
	_tmp20_ = _data4_->iter;
	_tmp21_ = gee_iterator_next (_tmp20_);
	_vala_assert (!_tmp21_, "!iter.next ()");
	_tmp22_ = data;
	_tmp22__length1 = data_length1;
	{
		gchar** el_collection = NULL;
		gint el_collection_length1 = 0;
		gint _el_collection_size_ = 0;
		gint el_it = 0;
		el_collection = _tmp22_;
		el_collection_length1 = _tmp22__length1;
		for (el_it = 0; el_it < _tmp22__length1; el_it = el_it + 1) {
			const gchar* el = NULL;
			el = el_collection[el_it];
			{
				GeeCollection* _tmp23_ = NULL;
				const gchar* _tmp24_ = NULL;
				gboolean _tmp25_ = FALSE;
				_tmp23_ = self->test_collection;
				_tmp24_ = el;
				_tmp25_ = gee_collection_add (_tmp23_, _tmp24_);
				_vala_assert (_tmp25_, "test_collection.add (el)");
			}
		}
	}
	_data4_->i = 0;
	_data4_->j = 0;
	_tmp26_ = self->test_collection;
	_tmp27_ = gee_iterable_iterator ((GeeIterable*) _tmp26_);
	_data4_->test_iterator = _tmp27_;
	_tmp28_ = self->test_collection;
	_tmp29_ = gee_traversable_map ((GeeTraversable*) _tmp28_, G_TYPE_INT, NULL, NULL, ___lambda23__gee_map_func, _data4_);
	_g_object_unref0 (_data4_->iter);
	_data4_->iter = _tmp29_;
	_tmp30_ = _data4_->iter;
	_tmp31_ = gee_iterator_get_valid (_tmp30_);
	_tmp32_ = _tmp31_;
	_vala_assert (!_tmp32_, "!iter.valid");
	_tmp33_ = self->test_collection;
	gee_traversable_foreach ((GeeTraversable*) _tmp33_, ___lambda24__gee_forall_func, _data4_);
	_tmp34_ = _data4_->iter;
	_tmp35_ = gee_iterator_has_next (_tmp34_);
	_vala_assert (!_tmp35_, "!iter.has_next ()");
	_tmp36_ = _data4_->iter;
	_tmp37_ = gee_iterator_next (_tmp36_);
	_vala_assert (!_tmp37_, "!iter.next ()");
	_data4_->i = 0;
	_data4_->j = 0;
	_tmp38_ = self->test_collection;
	_tmp39_ = gee_iterable_iterator ((GeeIterable*) _tmp38_);
	_g_object_unref0 (_data4_->test_iterator);
	_data4_->test_iterator = _tmp39_;
	_tmp40_ = self->test_collection;
	_tmp41_ = gee_traversable_map ((GeeTraversable*) _tmp40_, G_TYPE_INT, NULL, NULL, ___lambda25__gee_map_func, _data4_);
	_g_object_unref0 (_data4_->iter);
	_data4_->iter = _tmp41_;
	_tmp42_ = _data4_->iter;
	_tmp43_ = gee_iterator_get_valid (_tmp42_);
	_tmp44_ = _tmp43_;
	_vala_assert (!_tmp44_, "!iter.valid");
	_tmp45_ = self->test_collection;
	gee_traversable_foreach ((GeeTraversable*) _tmp45_, ___lambda26__gee_forall_func, _data4_);
	_tmp46_ = _data4_->iter;
	_tmp47_ = gee_iterator_has_next (_tmp46_);
	_vala_assert (!_tmp47_, "!iter.has_next ()");
	_tmp48_ = _data4_->iter;
	_tmp49_ = gee_iterator_next (_tmp48_);
	_vala_assert (!_tmp49_, "!iter.next ()");
	_data4_->i = 0;
	_data4_->j = 0;
	_tmp50_ = self->test_collection;
	_tmp51_ = gee_iterable_iterator ((GeeIterable*) _tmp50_);
	_g_object_unref0 (_data4_->test_iterator);
	_data4_->test_iterator = _tmp51_;
	_tmp52_ = self->test_collection;
	_tmp53_ = gee_iterable_iterator ((GeeIterable*) _tmp52_);
	outer_iter = _tmp53_;
	_tmp54_ = outer_iter;
	_tmp55_ = gee_traversable_map ((GeeTraversable*) _tmp54_, G_TYPE_INT, NULL, NULL, ___lambda27__gee_map_func, _data4_);
	_g_object_unref0 (_data4_->iter);
	_data4_->iter = _tmp55_;
	_tmp56_ = _data4_->iter;
	_tmp57_ = gee_iterator_get_valid (_tmp56_);
	_tmp58_ = _tmp57_;
	_vala_assert (!_tmp58_, "!iter.valid");
	_tmp59_ = self->test_collection;
	gee_traversable_foreach ((GeeTraversable*) _tmp59_, ___lambda28__gee_forall_func, _data4_);
	_tmp60_ = _data4_->iter;
	_tmp61_ = gee_iterator_has_next (_tmp60_);
	_vala_assert (!_tmp61_, "!iter.has_next ()");
	_tmp62_ = _data4_->iter;
	_tmp63_ = gee_iterator_next (_tmp62_);
	_vala_assert (!_tmp63_, "!iter.next ()");
	_data4_->i = 0;
	_data4_->j = 0;
	_tmp64_ = self->test_collection;
	_tmp65_ = gee_iterable_iterator ((GeeIterable*) _tmp64_);
	_g_object_unref0 (_data4_->test_iterator);
	_data4_->test_iterator = _tmp65_;
	_tmp66_ = self->test_collection;
	_tmp67_ = gee_iterable_iterator ((GeeIterable*) _tmp66_);
	_g_object_unref0 (outer_iter);
	outer_iter = _tmp67_;
	_tmp68_ = outer_iter;
	_tmp69_ = gee_traversable_map ((GeeTraversable*) _tmp68_, G_TYPE_INT, NULL, NULL, ___lambda29__gee_map_func, _data4_);
	_g_object_unref0 (_data4_->iter);
	_data4_->iter = _tmp69_;
	_tmp70_ = _data4_->iter;
	_tmp71_ = gee_iterator_get_valid (_tmp70_);
	_tmp72_ = _tmp71_;
	_vala_assert (!_tmp72_, "!iter.valid");
	_tmp73_ = self->test_collection;
	gee_traversable_foreach ((GeeTraversable*) _tmp73_, ___lambda30__gee_forall_func, _data4_);
	_tmp74_ = _data4_->iter;
	_tmp75_ = gee_iterator_has_next (_tmp74_);
	_vala_assert (!_tmp75_, "!iter.has_next ()");
	_tmp76_ = _data4_->iter;
	_tmp77_ = gee_iterator_next (_tmp76_);
	_vala_assert (!_tmp77_, "!iter.next ()");
	_data4_->i = 1;
	_data4_->j = 1;
	_tmp78_ = self->test_collection;
	_tmp79_ = gee_iterable_iterator ((GeeIterable*) _tmp78_);
	_g_object_unref0 (_data4_->test_iterator);
	_data4_->test_iterator = _tmp79_;
	_tmp80_ = self->test_collection;
	_tmp81_ = gee_iterable_iterator ((GeeIterable*) _tmp80_);
	_g_object_unref0 (outer_iter);
	outer_iter = _tmp81_;
	_tmp82_ = self->test_collection;
	_tmp83_ = gee_iterable_iterator ((GeeIterable*) _tmp82_);
	outer_iter2 = _tmp83_;
	_tmp84_ = outer_iter;
	_tmp85_ = gee_iterator_next (_tmp84_);
	_vala_assert (_tmp85_, "outer_iter.next ()");
	_tmp86_ = outer_iter2;
	_tmp87_ = gee_iterator_next (_tmp86_);
	_vala_assert (_tmp87_, "outer_iter2.next ()");
	_tmp88_ = outer_iter;
	_tmp89_ = gee_iterator_next (_tmp88_);
	_vala_assert (_tmp89_, "outer_iter.next ()");
	_tmp90_ = outer_iter2;
	_tmp91_ = gee_iterator_next (_tmp90_);
	_vala_assert (_tmp91_, "outer_iter2.next ()");
	_tmp92_ = _data4_->test_iterator;
	_tmp93_ = gee_iterator_next (_tmp92_);
	_vala_assert (_tmp93_, "test_iterator.next ()");
	_tmp94_ = outer_iter;
	_tmp95_ = gee_traversable_map ((GeeTraversable*) _tmp94_, G_TYPE_INT, NULL, NULL, ___lambda31__gee_map_func, _data4_);
	_g_object_unref0 (_data4_->iter);
	_data4_->iter = _tmp95_;
	_tmp96_ = _data4_->iter;
	_tmp97_ = gee_iterator_get_valid (_tmp96_);
	_tmp98_ = _tmp97_;
	_vala_assert (_tmp98_, "iter.valid");
	{
		gboolean _tmp99_ = FALSE;
		_tmp99_ = TRUE;
		while (TRUE) {
			gint _tmp102_ = 0;
			gint _tmp103_ = 0;
			GeeIterator* _tmp104_ = NULL;
			gboolean _tmp105_ = FALSE;
			GeeIterator* _tmp106_ = NULL;
			gboolean _tmp107_ = FALSE;
			gint _tmp108_ = 0;
			gint _tmp109_ = 0;
			gint _tmp110_ = 0;
			GeeIterator* _tmp111_ = NULL;
			gpointer _tmp112_ = NULL;
			gint _tmp113_ = 0;
			gint _tmp114_ = 0;
			gint _tmp115_ = 0;
			GeeIterator* _tmp116_ = NULL;
			gboolean _tmp117_ = FALSE;
			GeeIterator* _tmp118_ = NULL;
			gboolean _tmp119_ = FALSE;
			GeeIterator* _tmp120_ = NULL;
			gboolean _tmp121_ = FALSE;
			gboolean _tmp122_ = FALSE;
			if (!_tmp99_) {
				GeeIterator* _tmp100_ = NULL;
				gboolean _tmp101_ = FALSE;
				_tmp100_ = outer_iter2;
				_tmp101_ = gee_iterator_next (_tmp100_);
				if (!_tmp101_) {
					break;
				}
			}
			_tmp99_ = FALSE;
			_tmp102_ = _data4_->i;
			_tmp103_ = _data4_->j;
			_vala_assert (_tmp102_ == _tmp103_, "i == j");
			_tmp104_ = outer_iter2;
			_tmp105_ = gee_iterator_has_next (_tmp104_);
			_tmp106_ = _data4_->iter;
			_tmp107_ = gee_iterator_has_next (_tmp106_);
			_vala_assert (_tmp105_ == _tmp107_, "outer_iter2.has_next () == iter.has_next ()");
			_tmp108_ = _data4_->i;
			_tmp109_ = _data4_->j;
			_vala_assert (_tmp108_ == _tmp109_, "i == j");
			_tmp110_ = _data4_->j;
			_tmp111_ = _data4_->iter;
			_tmp112_ = gee_iterator_get (_tmp111_);
			_vala_assert (_tmp110_ == ((gint) ((gintptr) _tmp112_)), "j == iter.get ()");
			_tmp113_ = _data4_->j;
			_data4_->j = _tmp113_ + 1;
			_tmp114_ = _data4_->j;
			_tmp115_ = _data4_->i;
			_vala_assert (_tmp114_ == _tmp115_, "++j == i");
			_tmp116_ = outer_iter2;
			_tmp117_ = gee_iterator_has_next (_tmp116_);
			_tmp118_ = _data4_->iter;
			_tmp119_ = gee_iterator_next (_tmp118_);
			_vala_assert (_tmp117_ == _tmp119_, "outer_iter2.has_next () == iter.next ()");
			_tmp120_ = _data4_->iter;
			_tmp121_ = gee_iterator_get_valid (_tmp120_);
			_tmp122_ = _tmp121_;
			_vala_assert (_tmp122_, "iter.valid");
		}
	}
	_tmp123_ = _data4_->iter;
	_tmp124_ = gee_iterator_has_next (_tmp123_);
	_vala_assert (!_tmp124_, "!iter.has_next ()");
	_tmp125_ = _data4_->iter;
	_tmp126_ = gee_iterator_next (_tmp125_);
	_vala_assert (!_tmp126_, "!iter.next ()");
	_data4_->i = 1;
	_data4_->j = 1;
	_tmp127_ = self->test_collection;
	_tmp128_ = gee_iterable_iterator ((GeeIterable*) _tmp127_);
	_g_object_unref0 (_data4_->test_iterator);
	_data4_->test_iterator = _tmp128_;
	_tmp129_ = self->test_collection;
	_tmp130_ = gee_iterable_iterator ((GeeIterable*) _tmp129_);
	_g_object_unref0 (outer_iter);
	outer_iter = _tmp130_;
	_tmp131_ = self->test_collection;
	_tmp132_ = gee_iterable_iterator ((GeeIterable*) _tmp131_);
	_g_object_unref0 (outer_iter2);
	outer_iter2 = _tmp132_;
	_tmp133_ = outer_iter;
	_tmp134_ = gee_iterator_next (_tmp133_);
	_vala_assert (_tmp134_, "outer_iter.next ()");
	_tmp135_ = outer_iter2;
	_tmp136_ = gee_iterator_next (_tmp135_);
	_vala_assert (_tmp136_, "outer_iter2.next ()");
	_tmp137_ = outer_iter;
	_tmp138_ = gee_iterator_next (_tmp137_);
	_vala_assert (_tmp138_, "outer_iter.next ()");
	_tmp139_ = outer_iter2;
	_tmp140_ = gee_iterator_next (_tmp139_);
	_vala_assert (_tmp140_, "outer_iter2.next ()");
	_tmp141_ = _data4_->test_iterator;
	_tmp142_ = gee_iterator_next (_tmp141_);
	_vala_assert (_tmp142_, "test_iterator.next ()");
	_tmp143_ = outer_iter;
	_tmp144_ = gee_traversable_map ((GeeTraversable*) _tmp143_, G_TYPE_INT, NULL, NULL, ___lambda32__gee_map_func, _data4_);
	_g_object_unref0 (_data4_->iter);
	_data4_->iter = _tmp144_;
	_tmp145_ = _data4_->iter;
	_tmp146_ = gee_iterator_get_valid (_tmp145_);
	_tmp147_ = _tmp146_;
	_vala_assert (_tmp147_, "iter.valid");
	{
		gboolean _tmp148_ = FALSE;
		_tmp148_ = TRUE;
		while (TRUE) {
			gint _tmp151_ = 0;
			gint _tmp152_ = 0;
			GeeIterator* _tmp153_ = NULL;
			gboolean _tmp154_ = FALSE;
			GeeIterator* _tmp155_ = NULL;
			gboolean _tmp156_ = FALSE;
			gint _tmp157_ = 0;
			gint _tmp158_ = 0;
			GeeIterator* _tmp159_ = NULL;
			gboolean _tmp160_ = FALSE;
			GeeIterator* _tmp161_ = NULL;
			gboolean _tmp162_ = FALSE;
			gint _tmp163_ = 0;
			GeeIterator* _tmp164_ = NULL;
			gboolean _tmp165_ = FALSE;
			gboolean _tmp166_ = FALSE;
			if (!_tmp148_) {
				GeeIterator* _tmp149_ = NULL;
				gboolean _tmp150_ = FALSE;
				_tmp149_ = outer_iter2;
				_tmp150_ = gee_iterator_next (_tmp149_);
				if (!_tmp150_) {
					break;
				}
			}
			_tmp148_ = FALSE;
			_tmp151_ = _data4_->i;
			_tmp152_ = _data4_->j;
			_vala_assert (_tmp151_ == _tmp152_, "i == j");
			_tmp153_ = outer_iter2;
			_tmp154_ = gee_iterator_has_next (_tmp153_);
			_tmp155_ = _data4_->iter;
			_tmp156_ = gee_iterator_has_next (_tmp155_);
			_vala_assert (_tmp154_ == _tmp156_, "outer_iter2.has_next () == iter.has_next ()");
			_tmp157_ = _data4_->i;
			_tmp158_ = _data4_->j;
			_vala_assert (_tmp157_ == _tmp158_, "i == j");
			_tmp159_ = outer_iter2;
			_tmp160_ = gee_iterator_has_next (_tmp159_);
			_tmp161_ = _data4_->iter;
			_tmp162_ = gee_iterator_next (_tmp161_);
			_vala_assert (_tmp160_ == _tmp162_, "outer_iter2.has_next () == iter.next ()");
			_tmp163_ = _data4_->j;
			_data4_->j = _tmp163_ + 1;
			_tmp164_ = _data4_->iter;
			_tmp165_ = gee_iterator_get_valid (_tmp164_);
			_tmp166_ = _tmp165_;
			_vala_assert (_tmp166_, "iter.valid");
		}
	}
	_tmp167_ = _data4_->iter;
	_tmp168_ = gee_iterator_has_next (_tmp167_);
	_vala_assert (!_tmp168_, "!iter.has_next ()");
	_tmp169_ = _data4_->iter;
	_tmp170_ = gee_iterator_next (_tmp169_);
	_vala_assert (!_tmp170_, "!iter.next ()");
	_g_object_unref0 (outer_iter2);
	_g_object_unref0 (outer_iter);
	block4_data_unref (_data4_);
	_data4_ = NULL;
}


static Block5Data* block5_data_ref (Block5Data* _data5_) {
	g_atomic_int_inc (&_data5_->_ref_count_);
	return _data5_;
}


static void block5_data_unref (void * _userdata_) {
	Block5Data* _data5_;
	_data5_ = (Block5Data*) _userdata_;
	if (g_atomic_int_dec_and_test (&_data5_->_ref_count_)) {
		CollectionTests* self;
		self = _data5_->self;
		_g_object_unref0 (self);
		g_slice_free (Block5Data, _data5_);
	}
}


static gint __lambda33_ (Block5Data* _data5_, gchar* str, gint cur) {
	CollectionTests* self;
	gint result = 0;
	const gchar* _tmp0_ = NULL;
	gint _tmp6_ = 0;
	self = _data5_->self;
	g_return_val_if_fail (str != NULL, 0);
	_tmp0_ = str;
	if (g_strcmp0 (_tmp0_, "one") == 0) {
		gboolean _tmp1_ = FALSE;
		_tmp1_ = _data5_->one;
		_vala_assert (!_tmp1_, "!one");
		_data5_->one = TRUE;
	} else {
		const gchar* _tmp2_ = NULL;
		_tmp2_ = str;
		if (g_strcmp0 (_tmp2_, "two") == 0) {
			gboolean _tmp3_ = FALSE;
			_tmp3_ = _data5_->two;
			_vala_assert (!_tmp3_, "!two");
			_data5_->two = TRUE;
		} else {
			const gchar* _tmp4_ = NULL;
			_tmp4_ = str;
			if (g_strcmp0 (_tmp4_, "three") == 0) {
				gboolean _tmp5_ = FALSE;
				_tmp5_ = _data5_->three;
				_vala_assert (!_tmp5_, "!three");
				_data5_->three = TRUE;
			} else {
				g_assert_not_reached ();
			}
		}
	}
	_tmp6_ = cur;
	result = _tmp6_ + 1;
	_g_free0 (str);
	return result;
}


static gpointer ___lambda33__gee_fold_func (gpointer g, gpointer a, gpointer self) {
	gpointer result;
	result = (gpointer) ((gintptr) __lambda33_ (self, (gchar*) g, (gint) ((gintptr) a)));
	return result;
}


static gint __lambda34_ (Block5Data* _data5_, gchar* str, gint cur) {
	CollectionTests* self;
	gint result = 0;
	const gchar* _tmp0_ = NULL;
	gint _tmp6_ = 0;
	self = _data5_->self;
	g_return_val_if_fail (str != NULL, 0);
	_tmp0_ = str;
	if (g_strcmp0 (_tmp0_, "one") == 0) {
		gboolean _tmp1_ = FALSE;
		_tmp1_ = _data5_->one;
		_vala_assert (!_tmp1_, "!one");
		_data5_->one = TRUE;
	} else {
		const gchar* _tmp2_ = NULL;
		_tmp2_ = str;
		if (g_strcmp0 (_tmp2_, "two") == 0) {
			gboolean _tmp3_ = FALSE;
			_tmp3_ = _data5_->two;
			_vala_assert (!_tmp3_, "!two");
			_data5_->two = TRUE;
		} else {
			const gchar* _tmp4_ = NULL;
			_tmp4_ = str;
			if (g_strcmp0 (_tmp4_, "three") == 0) {
				gboolean _tmp5_ = FALSE;
				_tmp5_ = _data5_->three;
				_vala_assert (!_tmp5_, "!three");
				_data5_->three = TRUE;
			} else {
				g_assert_not_reached ();
			}
		}
	}
	_tmp6_ = cur;
	result = _tmp6_ + 1;
	_g_free0 (str);
	return result;
}


static gpointer ___lambda34__gee_fold_func (gpointer g, gpointer a, gpointer self) {
	gpointer result;
	result = (gpointer) ((gintptr) __lambda34_ (self, (gchar*) g, (gint) ((gintptr) a)));
	return result;
}


void collection_tests_test_scan (CollectionTests* self) {
	Block5Data* _data5_;
	GeeCollection* _tmp0_ = NULL;
	gboolean _tmp1_ = FALSE;
	GeeCollection* _tmp2_ = NULL;
	gboolean _tmp3_ = FALSE;
	GeeCollection* _tmp4_ = NULL;
	gboolean _tmp5_ = FALSE;
	GeeIterator* iter = NULL;
	GeeCollection* _tmp6_ = NULL;
	GeeIterator* _tmp7_ = NULL;
	GeeIterator* _tmp8_ = NULL;
	GeeIterator* _tmp9_ = NULL;
	GeeIterator* _tmp10_ = NULL;
	gint j = 0;
	gint _tmp21_ = 0;
	GeeCollection* _tmp22_ = NULL;
	gint _tmp23_ = 0;
	gint _tmp24_ = 0;
	gboolean _tmp25_ = FALSE;
	gboolean _tmp26_ = FALSE;
	gboolean _tmp27_ = FALSE;
	gboolean _tmp28_ = FALSE;
	gboolean _tmp29_ = FALSE;
	GeeCollection* _tmp30_ = NULL;
	GeeIterator* _tmp31_ = NULL;
	gint _tmp42_ = 0;
	GeeCollection* _tmp43_ = NULL;
	gint _tmp44_ = 0;
	gint _tmp45_ = 0;
	gboolean _tmp46_ = FALSE;
	gboolean _tmp47_ = FALSE;
	gboolean _tmp48_ = FALSE;
	g_return_if_fail (self != NULL);
	_data5_ = g_slice_new0 (Block5Data);
	_data5_->_ref_count_ = 1;
	_data5_->self = g_object_ref (self);
	_tmp0_ = self->test_collection;
	_tmp1_ = gee_collection_add (_tmp0_, "one");
	_vala_assert (_tmp1_, "test_collection.add (\"one\")");
	_tmp2_ = self->test_collection;
	_tmp3_ = gee_collection_add (_tmp2_, "two");
	_vala_assert (_tmp3_, "test_collection.add (\"two\")");
	_tmp4_ = self->test_collection;
	_tmp5_ = gee_collection_add (_tmp4_, "three");
	_vala_assert (_tmp5_, "test_collection.add (\"three\")");
	_data5_->one = FALSE;
	_data5_->two = FALSE;
	_data5_->three = FALSE;
	_tmp6_ = self->test_collection;
	_tmp7_ = gee_iterable_iterator ((GeeIterable*) _tmp6_);
	_tmp8_ = _tmp7_;
	_tmp9_ = gee_traversable_scan ((GeeTraversable*) _tmp8_, G_TYPE_INT, NULL, NULL, ___lambda33__gee_fold_func, _data5_, (gpointer) ((gintptr) 0));
	_tmp10_ = _tmp9_;
	_g_object_unref0 (_tmp8_);
	iter = _tmp10_;
	j = 0;
	{
		gboolean _tmp11_ = FALSE;
		_tmp11_ = TRUE;
		while (TRUE) {
			gint _tmp14_ = 0;
			GeeIterator* _tmp15_ = NULL;
			gpointer _tmp16_ = NULL;
			gint _tmp17_ = 0;
			GeeIterator* _tmp18_ = NULL;
			gpointer _tmp19_ = NULL;
			gint _tmp20_ = 0;
			if (!_tmp11_) {
				GeeIterator* _tmp12_ = NULL;
				gboolean _tmp13_ = FALSE;
				_tmp12_ = iter;
				_tmp13_ = gee_iterator_next (_tmp12_);
				if (!_tmp13_) {
					break;
				}
			}
			_tmp11_ = FALSE;
			_tmp14_ = j;
			_tmp15_ = iter;
			_tmp16_ = gee_iterator_get (_tmp15_);
			_vala_assert (_tmp14_ == ((gint) ((gintptr) _tmp16_)), "j == iter.get ()");
			_tmp17_ = j;
			_tmp18_ = iter;
			_tmp19_ = gee_iterator_get (_tmp18_);
			_vala_assert (_tmp17_ == ((gint) ((gintptr) _tmp19_)), "j == iter.get ()");
			_tmp20_ = j;
			j = _tmp20_ + 1;
		}
	}
	_tmp21_ = j;
	_tmp22_ = self->test_collection;
	_tmp23_ = gee_collection_get_size (_tmp22_);
	_tmp24_ = _tmp23_;
	_vala_assert (_tmp21_ == (_tmp24_ + 1), "j == test_collection.size + 1");
	_tmp25_ = _data5_->one;
	_vala_assert (_tmp25_, "one");
	_tmp26_ = _data5_->two;
	_vala_assert (_tmp26_, "two");
	_tmp27_ = _data5_->three;
	_vala_assert (_tmp27_, "three");
	_data5_->three = FALSE;
	_tmp28_ = _data5_->three;
	_data5_->two = _tmp28_;
	_tmp29_ = _data5_->two;
	_data5_->one = _tmp29_;
	j = 0;
	_tmp30_ = self->test_collection;
	_tmp31_ = gee_traversable_scan ((GeeTraversable*) _tmp30_, G_TYPE_INT, NULL, NULL, ___lambda34__gee_fold_func, _data5_, (gpointer) ((gintptr) 0));
	_g_object_unref0 (iter);
	iter = _tmp31_;
	{
		gboolean _tmp32_ = FALSE;
		_tmp32_ = TRUE;
		while (TRUE) {
			gint _tmp35_ = 0;
			GeeIterator* _tmp36_ = NULL;
			gpointer _tmp37_ = NULL;
			gint _tmp38_ = 0;
			GeeIterator* _tmp39_ = NULL;
			gpointer _tmp40_ = NULL;
			gint _tmp41_ = 0;
			if (!_tmp32_) {
				GeeIterator* _tmp33_ = NULL;
				gboolean _tmp34_ = FALSE;
				_tmp33_ = iter;
				_tmp34_ = gee_iterator_next (_tmp33_);
				if (!_tmp34_) {
					break;
				}
			}
			_tmp32_ = FALSE;
			_tmp35_ = j;
			_tmp36_ = iter;
			_tmp37_ = gee_iterator_get (_tmp36_);
			_vala_assert (_tmp35_ == ((gint) ((gintptr) _tmp37_)), "j == iter.get ()");
			_tmp38_ = j;
			_tmp39_ = iter;
			_tmp40_ = gee_iterator_get (_tmp39_);
			_vala_assert (_tmp38_ == ((gint) ((gintptr) _tmp40_)), "j == iter.get ()");
			_tmp41_ = j;
			j = _tmp41_ + 1;
		}
	}
	_tmp42_ = j;
	_tmp43_ = self->test_collection;
	_tmp44_ = gee_collection_get_size (_tmp43_);
	_tmp45_ = _tmp44_;
	_vala_assert (_tmp42_ == (_tmp45_ + 1), "j == test_collection.size + 1");
	_tmp46_ = _data5_->one;
	_vala_assert (_tmp46_, "one");
	_tmp47_ = _data5_->two;
	_vala_assert (_tmp47_, "two");
	_tmp48_ = _data5_->three;
	_vala_assert (_tmp48_, "three");
	_g_object_unref0 (iter);
	block5_data_unref (_data5_);
	_data5_ = NULL;
}


static Block6Data* block6_data_ref (Block6Data* _data6_) {
	g_atomic_int_inc (&_data6_->_ref_count_);
	return _data6_;
}


static void block6_data_unref (void * _userdata_) {
	Block6Data* _data6_;
	_data6_ = (Block6Data*) _userdata_;
	if (g_atomic_int_dec_and_test (&_data6_->_ref_count_)) {
		CollectionTests* self;
		self = _data6_->self;
		_g_object_unref0 (self);
		g_slice_free (Block6Data, _data6_);
	}
}


static gboolean __lambda35_ (Block6Data* _data6_, const gchar* str) {
	CollectionTests* self;
	gboolean result = FALSE;
	const gchar* _tmp0_ = NULL;
	const gchar* _tmp6_ = NULL;
	self = _data6_->self;
	g_return_val_if_fail (str != NULL, FALSE);
	_tmp0_ = str;
	if (g_strcmp0 (_tmp0_, "one") == 0) {
		gboolean _tmp1_ = FALSE;
		_tmp1_ = _data6_->one;
		_vala_assert (!_tmp1_, "!one");
		_data6_->one = TRUE;
	} else {
		const gchar* _tmp2_ = NULL;
		_tmp2_ = str;
		if (g_strcmp0 (_tmp2_, "two") == 0) {
			gboolean _tmp3_ = FALSE;
			_tmp3_ = _data6_->two;
			_vala_assert (!_tmp3_, "!two");
			_data6_->two = TRUE;
		} else {
			const gchar* _tmp4_ = NULL;
			_tmp4_ = str;
			if (g_strcmp0 (_tmp4_, "three") == 0) {
				gboolean _tmp5_ = FALSE;
				_tmp5_ = _data6_->three;
				_vala_assert (!_tmp5_, "!three");
				_data6_->three = TRUE;
			} else {
				g_assert_not_reached ();
			}
		}
	}
	_tmp6_ = str;
	result = g_strcmp0 (_tmp6_, "two") != 0;
	return result;
}


static gboolean ___lambda35__gee_predicate (gconstpointer g, gpointer self) {
	gboolean result;
	result = __lambda35_ (self, (const gchar*) g);
	return result;
}


static gboolean __lambda36_ (Block6Data* _data6_, const gchar* str) {
	CollectionTests* self;
	gboolean result = FALSE;
	const gchar* _tmp0_ = NULL;
	const gchar* _tmp6_ = NULL;
	self = _data6_->self;
	g_return_val_if_fail (str != NULL, FALSE);
	_tmp0_ = str;
	if (g_strcmp0 (_tmp0_, "one") == 0) {
		gboolean _tmp1_ = FALSE;
		_tmp1_ = _data6_->one;
		_vala_assert (!_tmp1_, "!one");
		_data6_->one = TRUE;
	} else {
		const gchar* _tmp2_ = NULL;
		_tmp2_ = str;
		if (g_strcmp0 (_tmp2_, "two") == 0) {
			gboolean _tmp3_ = FALSE;
			_tmp3_ = _data6_->two;
			_vala_assert (!_tmp3_, "!two");
			_data6_->two = TRUE;
		} else {
			const gchar* _tmp4_ = NULL;
			_tmp4_ = str;
			if (g_strcmp0 (_tmp4_, "three") == 0) {
				gboolean _tmp5_ = FALSE;
				_tmp5_ = _data6_->three;
				_vala_assert (!_tmp5_, "!three");
				_data6_->three = TRUE;
			} else {
				g_assert_not_reached ();
			}
		}
	}
	_tmp6_ = str;
	result = g_strcmp0 (_tmp6_, "two") != 0;
	return result;
}


static gboolean ___lambda36__gee_predicate (gconstpointer g, gpointer self) {
	gboolean result;
	result = __lambda36_ (self, (const gchar*) g);
	return result;
}


void collection_tests_test_filter (CollectionTests* self) {
	Block6Data* _data6_;
	GeeCollection* _tmp0_ = NULL;
	gboolean _tmp1_ = FALSE;
	GeeCollection* _tmp2_ = NULL;
	gboolean _tmp3_ = FALSE;
	GeeCollection* _tmp4_ = NULL;
	gboolean _tmp5_ = FALSE;
	GeeIterator* iter = NULL;
	GeeCollection* _tmp6_ = NULL;
	GeeIterator* _tmp7_ = NULL;
	GeeIterator* _tmp8_ = NULL;
	GeeIterator* _tmp9_ = NULL;
	GeeIterator* _tmp10_ = NULL;
	GeeIterator* _tmp11_ = NULL;
	gboolean _tmp12_ = FALSE;
	gboolean _tmp13_ = FALSE;
	gint j = 0;
	gint _tmp20_ = 0;
	gboolean _tmp21_ = FALSE;
	gboolean _tmp22_ = FALSE;
	gboolean _tmp23_ = FALSE;
	gboolean _tmp24_ = FALSE;
	gboolean _tmp25_ = FALSE;
	GeeCollection* _tmp26_ = NULL;
	GeeIterator* _tmp27_ = NULL;
	GeeIterator* _tmp28_ = NULL;
	gboolean _tmp29_ = FALSE;
	gboolean _tmp30_ = FALSE;
	gint _tmp37_ = 0;
	gboolean _tmp38_ = FALSE;
	gboolean _tmp39_ = FALSE;
	gboolean _tmp40_ = FALSE;
	g_return_if_fail (self != NULL);
	_data6_ = g_slice_new0 (Block6Data);
	_data6_->_ref_count_ = 1;
	_data6_->self = g_object_ref (self);
	_tmp0_ = self->test_collection;
	_tmp1_ = gee_collection_add (_tmp0_, "one");
	_vala_assert (_tmp1_, "test_collection.add (\"one\")");
	_tmp2_ = self->test_collection;
	_tmp3_ = gee_collection_add (_tmp2_, "two");
	_vala_assert (_tmp3_, "test_collection.add (\"two\")");
	_tmp4_ = self->test_collection;
	_tmp5_ = gee_collection_add (_tmp4_, "three");
	_vala_assert (_tmp5_, "test_collection.add (\"three\")");
	_data6_->one = FALSE;
	_data6_->two = FALSE;
	_data6_->three = FALSE;
	_tmp6_ = self->test_collection;
	_tmp7_ = gee_iterable_iterator ((GeeIterable*) _tmp6_);
	_tmp8_ = _tmp7_;
	_tmp9_ = gee_traversable_filter ((GeeTraversable*) _tmp8_, ___lambda35__gee_predicate, block6_data_ref (_data6_), block6_data_unref);
	_tmp10_ = _tmp9_;
	_g_object_unref0 (_tmp8_);
	iter = _tmp10_;
	_tmp11_ = iter;
	_tmp12_ = gee_iterator_get_valid (_tmp11_);
	_tmp13_ = _tmp12_;
	_vala_assert (!_tmp13_, "!iter.valid");
	j = 0;
	while (TRUE) {
		GeeIterator* _tmp14_ = NULL;
		gboolean _tmp15_ = FALSE;
		GeeIterator* _tmp16_ = NULL;
		gpointer _tmp17_ = NULL;
		gchar* _tmp18_ = NULL;
		gint _tmp19_ = 0;
		_tmp14_ = iter;
		_tmp15_ = gee_iterator_next (_tmp14_);
		if (!_tmp15_) {
			break;
		}
		_tmp16_ = iter;
		_tmp17_ = gee_iterator_get (_tmp16_);
		_tmp18_ = (gchar*) _tmp17_;
		_vala_assert (g_strcmp0 (_tmp18_, "two") != 0, "iter.get () != \"two\"");
		_g_free0 (_tmp18_);
		_tmp19_ = j;
		j = _tmp19_ + 1;
	}
	_tmp20_ = j;
	_vala_assert (_tmp20_ == 2, "j == 2");
	_tmp21_ = _data6_->one;
	_vala_assert (_tmp21_, "one");
	_tmp22_ = _data6_->two;
	_vala_assert (_tmp22_, "two");
	_tmp23_ = _data6_->three;
	_vala_assert (_tmp23_, "three");
	_data6_->three = FALSE;
	_tmp24_ = _data6_->three;
	_data6_->two = _tmp24_;
	_tmp25_ = _data6_->two;
	_data6_->one = _tmp25_;
	j = 0;
	_tmp26_ = self->test_collection;
	_tmp27_ = gee_traversable_filter ((GeeTraversable*) _tmp26_, ___lambda36__gee_predicate, block6_data_ref (_data6_), block6_data_unref);
	_g_object_unref0 (iter);
	iter = _tmp27_;
	_tmp28_ = iter;
	_tmp29_ = gee_iterator_get_valid (_tmp28_);
	_tmp30_ = _tmp29_;
	_vala_assert (!_tmp30_, "!iter.valid");
	while (TRUE) {
		GeeIterator* _tmp31_ = NULL;
		gboolean _tmp32_ = FALSE;
		GeeIterator* _tmp33_ = NULL;
		gpointer _tmp34_ = NULL;
		gchar* _tmp35_ = NULL;
		gint _tmp36_ = 0;
		_tmp31_ = iter;
		_tmp32_ = gee_iterator_next (_tmp31_);
		if (!_tmp32_) {
			break;
		}
		_tmp33_ = iter;
		_tmp34_ = gee_iterator_get (_tmp33_);
		_tmp35_ = (gchar*) _tmp34_;
		_vala_assert (g_strcmp0 (_tmp35_, "two") != 0, "iter.get () != \"two\"");
		_g_free0 (_tmp35_);
		_tmp36_ = j;
		j = _tmp36_ + 1;
	}
	_tmp37_ = j;
	_vala_assert (_tmp37_ == 2, "j == 2");
	_tmp38_ = _data6_->one;
	_vala_assert (_tmp38_, "one");
	_tmp39_ = _data6_->two;
	_vala_assert (_tmp39_, "two");
	_tmp40_ = _data6_->three;
	_vala_assert (_tmp40_, "three");
	_g_object_unref0 (iter);
	block6_data_unref (_data6_);
	_data6_ = NULL;
}


void collection_tests_test_chop (CollectionTests* self) {
	GeeCollection* _tmp0_ = NULL;
	gboolean _tmp1_ = FALSE;
	GeeCollection* _tmp2_ = NULL;
	gboolean _tmp3_ = FALSE;
	GeeCollection* _tmp4_ = NULL;
	gboolean _tmp5_ = FALSE;
	GeeIterator* iter = NULL;
	GeeCollection* _tmp6_ = NULL;
	GeeIterator* _tmp7_ = NULL;
	GeeIterator* _tmp8_ = NULL;
	GeeIterator* _tmp9_ = NULL;
	GeeIterator* _tmp10_ = NULL;
	GeeIterator* _tmp11_ = NULL;
	gboolean _tmp12_ = FALSE;
	gboolean _tmp13_ = FALSE;
	GeeIterator* iter2 = NULL;
	GeeCollection* _tmp14_ = NULL;
	GeeIterator* _tmp15_ = NULL;
	GeeIterator* _tmp16_ = NULL;
	gboolean _tmp17_ = FALSE;
	GeeIterator* _tmp18_ = NULL;
	gboolean _tmp19_ = FALSE;
	GeeIterator* _tmp20_ = NULL;
	gboolean _tmp21_ = FALSE;
	GeeIterator* _tmp22_ = NULL;
	gpointer _tmp23_ = NULL;
	gchar* _tmp24_ = NULL;
	GeeIterator* _tmp25_ = NULL;
	gpointer _tmp26_ = NULL;
	gchar* _tmp27_ = NULL;
	GeeIterator* _tmp28_ = NULL;
	gboolean _tmp29_ = FALSE;
	GeeIterator* _tmp30_ = NULL;
	gboolean _tmp31_ = FALSE;
	GeeCollection* _tmp32_ = NULL;
	GeeIterator* _tmp33_ = NULL;
	GeeIterator* _tmp34_ = NULL;
	gboolean _tmp35_ = FALSE;
	gboolean _tmp36_ = FALSE;
	GeeCollection* _tmp37_ = NULL;
	GeeIterator* _tmp38_ = NULL;
	GeeIterator* _tmp39_ = NULL;
	gboolean _tmp40_ = FALSE;
	GeeIterator* _tmp41_ = NULL;
	gboolean _tmp42_ = FALSE;
	GeeIterator* _tmp43_ = NULL;
	gboolean _tmp44_ = FALSE;
	GeeIterator* _tmp45_ = NULL;
	gpointer _tmp46_ = NULL;
	gchar* _tmp47_ = NULL;
	GeeIterator* _tmp48_ = NULL;
	gpointer _tmp49_ = NULL;
	gchar* _tmp50_ = NULL;
	GeeIterator* _tmp51_ = NULL;
	gboolean _tmp52_ = FALSE;
	GeeIterator* _tmp53_ = NULL;
	gboolean _tmp54_ = FALSE;
	g_return_if_fail (self != NULL);
	_tmp0_ = self->test_collection;
	_tmp1_ = gee_collection_add (_tmp0_, "one");
	_vala_assert (_tmp1_, "test_collection.add (\"one\")");
	_tmp2_ = self->test_collection;
	_tmp3_ = gee_collection_add (_tmp2_, "two");
	_vala_assert (_tmp3_, "test_collection.add (\"two\")");
	_tmp4_ = self->test_collection;
	_tmp5_ = gee_collection_add (_tmp4_, "three");
	_vala_assert (_tmp5_, "test_collection.add (\"three\")");
	_tmp6_ = self->test_collection;
	_tmp7_ = gee_iterable_iterator ((GeeIterable*) _tmp6_);
	_tmp8_ = _tmp7_;
	_tmp9_ = gee_traversable_chop ((GeeTraversable*) _tmp8_, 1, 1);
	_tmp10_ = _tmp9_;
	_g_object_unref0 (_tmp8_);
	iter = _tmp10_;
	_tmp11_ = iter;
	_tmp12_ = gee_iterator_get_valid (_tmp11_);
	_tmp13_ = _tmp12_;
	_vala_assert (!_tmp13_, "!iter.valid");
	_tmp14_ = self->test_collection;
	_tmp15_ = gee_iterable_iterator ((GeeIterable*) _tmp14_);
	iter2 = _tmp15_;
	_tmp16_ = iter2;
	_tmp17_ = gee_iterator_next (_tmp16_);
	_vala_assert (_tmp17_, "iter2.next ()");
	_tmp18_ = iter2;
	_tmp19_ = gee_iterator_next (_tmp18_);
	_vala_assert (_tmp19_, "iter2.next ()");
	_tmp20_ = iter;
	_tmp21_ = gee_iterator_next (_tmp20_);
	_vala_assert (_tmp21_, "iter.next ()");
	_tmp22_ = iter2;
	_tmp23_ = gee_iterator_get (_tmp22_);
	_tmp24_ = (gchar*) _tmp23_;
	_tmp25_ = iter;
	_tmp26_ = gee_iterator_get (_tmp25_);
	_tmp27_ = (gchar*) _tmp26_;
	_vala_assert (g_strcmp0 (_tmp24_, _tmp27_) == 0, "iter2.get () == iter.get ()");
	_g_free0 (_tmp27_);
	_g_free0 (_tmp24_);
	_tmp28_ = iter;
	_tmp29_ = gee_iterator_next (_tmp28_);
	_vala_assert (!_tmp29_, "!iter.next ()");
	_tmp30_ = iter2;
	_tmp31_ = gee_iterator_next (_tmp30_);
	_vala_assert (_tmp31_, "iter2.next ()");
	_tmp32_ = self->test_collection;
	_tmp33_ = gee_traversable_chop ((GeeTraversable*) _tmp32_, 1, 1);
	_g_object_unref0 (iter);
	iter = _tmp33_;
	_tmp34_ = iter;
	_tmp35_ = gee_iterator_get_valid (_tmp34_);
	_tmp36_ = _tmp35_;
	_vala_assert (!_tmp36_, "!iter.valid");
	_tmp37_ = self->test_collection;
	_tmp38_ = gee_iterable_iterator ((GeeIterable*) _tmp37_);
	_g_object_unref0 (iter2);
	iter2 = _tmp38_;
	_tmp39_ = iter2;
	_tmp40_ = gee_iterator_next (_tmp39_);
	_vala_assert (_tmp40_, "iter2.next ()");
	_tmp41_ = iter2;
	_tmp42_ = gee_iterator_next (_tmp41_);
	_vala_assert (_tmp42_, "iter2.next ()");
	_tmp43_ = iter;
	_tmp44_ = gee_iterator_next (_tmp43_);
	_vala_assert (_tmp44_, "iter.next ()");
	_tmp45_ = iter2;
	_tmp46_ = gee_iterator_get (_tmp45_);
	_tmp47_ = (gchar*) _tmp46_;
	_tmp48_ = iter;
	_tmp49_ = gee_iterator_get (_tmp48_);
	_tmp50_ = (gchar*) _tmp49_;
	_vala_assert (g_strcmp0 (_tmp47_, _tmp50_) == 0, "iter2.get () == iter.get ()");
	_g_free0 (_tmp50_);
	_g_free0 (_tmp47_);
	_tmp51_ = iter;
	_tmp52_ = gee_iterator_next (_tmp51_);
	_vala_assert (!_tmp52_, "!iter.next ()");
	_tmp53_ = iter2;
	_tmp54_ = gee_iterator_next (_tmp53_);
	_vala_assert (_tmp54_, "iter2.next ()");
	_g_object_unref0 (iter2);
	_g_object_unref0 (iter);
}


static void collection_tests_class_init (CollectionTestsClass * klass) {
	collection_tests_parent_class = g_type_class_peek_parent (klass);
	G_OBJECT_CLASS (klass)->finalize = collection_tests_finalize;
}


static void collection_tests_instance_init (CollectionTests * self) {
}


static void collection_tests_finalize (GObject* obj) {
	CollectionTests * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TYPE_COLLECTION_TESTS, CollectionTests);
	_g_object_unref0 (self->test_collection);
	G_OBJECT_CLASS (collection_tests_parent_class)->finalize (obj);
}


GType collection_tests_get_type (void) {
	static volatile gsize collection_tests_type_id__volatile = 0;
	if (g_once_init_enter (&collection_tests_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (CollectionTestsClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) collection_tests_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (CollectionTests), 0, (GInstanceInitFunc) collection_tests_instance_init, NULL };
		GType collection_tests_type_id;
		collection_tests_type_id = g_type_register_static (GEE_TYPE_TEST_CASE, "CollectionTests", &g_define_type_info, G_TYPE_FLAG_ABSTRACT);
		g_once_init_leave (&collection_tests_type_id__volatile, collection_tests_type_id);
	}
	return collection_tests_type_id__volatile;
}


static void _vala_array_destroy (gpointer array, gint array_length, GDestroyNotify destroy_func) {
	if ((array != NULL) && (destroy_func != NULL)) {
		int i;
		for (i = 0; i < array_length; i = i + 1) {
			if (((gpointer*) array)[i] != NULL) {
				destroy_func (((gpointer*) array)[i]);
			}
		}
	}
}


static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func) {
	_vala_array_destroy (array, array_length, destroy_func);
	g_free (array);
}



